def check_calibration_value_target(calibration_settings, calibration_factors, type_of_calibration, automatic_trim,
                                   flag_trim_successful, path_of_working_directory_rce,
                                   current_workflow_name='UNICADOworkflow'):
    """ check_calibration_value_target checks the the actual calibration value against the target calibration value.

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The input list "calibration_factors" contains all estimated calibration factors.

        The input int "count_of_calibration" contains the execution number of current function.

        The input value "type_of_calibration" contains the string of name of current calibration mode.

        The input integer "automatic_trim" contains the current status of automatic trimming is selected or not.

        The input integer "flag_trim_successful" contains the current status of automatic trimming is successful or not.

        The input string "path_of_working_directory_rce" contains the system path to rce working directory.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default string 'UNICADOworkflow' is used.

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The output list "calibration_factors" contains all estimated calibration factors.

        :param: calibration_settings: input list of lists
        :param: calibration_factors: input list
        :param: type_of_calibration: input value
        :param: automatic_trim: input integer
        :param: flag_trim_successful: input integer
        :param: path_of_working_directory_rce: input int
        :param: current_workflow_name: input string
        :return: calibration_settings: output list of lists, calibration_factors: output list
    """

    ''' imports for python '''
    from datetime import datetime

    ''' read data for script execution '''
    calibration_target_ome = ([item for item in calibration_settings if 'calibration_target_OME' in item])[-1][-1]
    calibration_target_mtom = ([item for item in calibration_settings if 'calibration_target_mtom' in item])[-1][-1]
    calibration_value_act = ([item for item in calibration_settings if 'calibration_value_act' in item])[-1][-1]
    calibration_factor_act = ([item for item in calibration_settings if 'calibration_factor_act' in item])[-1][-1]
    calibration_value_high = ([item for item in calibration_settings if 'calibration_value_high' in item])[-1][-1]
    calibration_factor_high = ([item for item in calibration_settings if 'calibration_factor_high' in item])[-1][-1]
    calibration_value_low = ([item for item in calibration_settings if 'calibration_value_low' in item])[-1][-1]
    calibration_factor_low = ([item for item in calibration_settings if 'calibration_factor_low' in item])[-1][-1]
    free_variable_mtom_calibration = \
        int(([item for item in calibration_settings if 'free_variable_MTOM_calibration' in item])[-1][-1])
    calibration_value_over_target_exist = \
        int(([item for item in calibration_settings if 'calibration_value_over_target_exist' in item])[-1][-1])
    calibration_value_under_target_exist = \
        int(([item for item in calibration_settings if 'calibration_value_under_target_exist' in item])[-1][-1])
    calibration_value_over_target_update_exist = \
        int(([item for item in calibration_settings if 'calibration_value_over_target_update_exist' in item])[-1][-1])
    calibration_value_under_target_update_exist = \
        int(([item for item in calibration_settings if 'calibration_value_under_target_update_exist' in item])[-1][-1])

    ''' initialize local parameter '''
    log_file_list = []

    if type_of_calibration == 'MTOM':
        calibration_value = calibration_target_mtom
    else:
        calibration_value = calibration_target_ome

    if calibration_value_act > calibration_value:
        if calibration_value_over_target_exist == 0:
            print('  Save ' + type_of_calibration + ' (high) = ' + str(calibration_value_act) + ' > '
                  + type_of_calibration + ' (target)')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                 'Save ' + type_of_calibration + ' (high) = ' + str(calibration_value_act) + ' > '
                                 + type_of_calibration + ' (target)')

            calibration_value_high = calibration_value_act
            calibration_factor_high = calibration_factor_act
            calibration_value_over_target_exist = int(1)

        else:
            if calibration_value_act < calibration_value_high:
                print('  Overwrite old ' + type_of_calibration + ' (high) = ' + str(calibration_value_high) + ' by ' +
                      str(calibration_value_act) + ' > ' + type_of_calibration + ' (target)')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                     'Overwrite old ' + type_of_calibration + ' (high) = '
                                     + str(calibration_value_high) + ' by ' + str(calibration_value_act) + ' > '
                                     + type_of_calibration + ' (target)')

                calibration_value_high = calibration_value_act
                calibration_factor_high = calibration_factor_act
                calibration_value_over_target_update_exist = int(1)

                # check if the current calibration mode is equal to MTOM and
                #  the free variable mtom calibration is not equal to engine calibration
                if type_of_calibration == 'MTOM' and not free_variable_mtom_calibration == 1:
                    calibration_factor_high = calibration_factors[-1]

                # Check if the auto trim option is disabled
                #  or if the auto trim option is selected and completed successfully.
                if not automatic_trim == 1 or flag_trim_successful == 1:
                    print('  (upper limit for possible new auxiliary interpolation)')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + '  '
                                         '(upper limit for possible new auxiliary interpolation)')
                else:
                    calibration_value_over_target_update_exist = int(0)

    else:
        if calibration_value_under_target_exist == 0:
            print('  Save ' + type_of_calibration + ' (low) = ' + str(calibration_value_act) + ' < '
                  + type_of_calibration + ' (target)')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                 'Save ' + type_of_calibration + ' (low) = ' + str(calibration_value_act) + ' < '
                                 + type_of_calibration + ' (target)')

            calibration_value_low = calibration_value_act
            calibration_factor_low = calibration_factor_act
            calibration_value_under_target_exist = int(1)

        else:
            if calibration_value_act > calibration_value_low:
                print('  Overwrite old ' + type_of_calibration + ' (low) = ' + str(calibration_value_low) + ' by ' +
                      str(calibration_value_act) + ' < ' + type_of_calibration + ' (target)')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   Overwrite old '
                                     + type_of_calibration + ' (low) = ' + str(calibration_value_low) + ' by '
                                     + str(calibration_value_act) + ' < ' + type_of_calibration + ' (target)')

                calibration_value_low = calibration_value_act
                calibration_factor_low = calibration_factor_act
                calibration_value_under_target_update_exist = int(1)

                # check if the current calibration mode is equal to MTOM and
                #  the free variable mtom calibration is not equal to engine calibration
                if type_of_calibration == 'MTOM' and not free_variable_mtom_calibration == 1:
                    calibration_factor_low = calibration_factors[-1]

                # Check if the auto trim option is disabled
                #  or if the auto trim option is selected and completed successfully.
                if not automatic_trim == 1 or flag_trim_successful == 1:
                    print('  (lower limit for possible new auxiliary interpolation)')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + '  '
                                         '(lower limit for possible new auxiliary interpolation)')
                else:
                    calibration_value_over_target_update_exist = int(0)

    # write output strings to workflow log-file
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    ''' set output parameter for next iteration step '''
    ([item for item in calibration_settings if 'calibration_target_OME' in item])[-1][-1] = calibration_target_ome
    ([item for item in calibration_settings if 'calibration_target_mtom' in item])[-1][-1] = calibration_target_mtom
    ([item for item in calibration_settings if 'calibration_value_act' in item])[-1][-1] = calibration_value_act
    ([item for item in calibration_settings if 'calibration_factor_act' in item])[-1][-1] = calibration_factor_act
    ([item for item in calibration_settings if 'calibration_value_high' in item])[-1][-1] = calibration_value_high
    ([item for item in calibration_settings if 'calibration_factor_high' in item])[-1][-1] = calibration_factor_high
    ([item for item in calibration_settings if 'calibration_value_low' in item])[-1][-1] = calibration_value_low
    ([item for item in calibration_settings if 'calibration_factor_low' in item])[-1][-1] = calibration_factor_low
    ([item for item in calibration_settings if 'calibration_value_over_target_exist' in item])[-1][-1] =\
        calibration_value_over_target_exist
    ([item for item in calibration_settings if 'calibration_value_under_target_exist' in item])[-1][-1] =\
        calibration_value_under_target_exist
    ([item for item in calibration_settings if 'calibration_value_over_target_update_exist' in item])[-1][-1] =\
        calibration_value_over_target_update_exist
    ([item for item in calibration_settings if 'calibration_value_under_target_update_exist' in item])[-1][-1] =\
        calibration_value_under_target_update_exist

    return calibration_settings, calibration_factors
