def extrapolation_failed(calibration_settings, calibration_target_value, path_of_working_directory_rce,
                         current_workflow_name='UNICADOworkflow'):
    """ perform_ome_calibration performs the ome calibration.

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The input string "path_of_working_directory_rce" contains the system path to rce working directory.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default string 'UNICADOworkflow' is used.

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',             [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        :param: calibration_settings: input list of lists
        :param: calibration_target_value: input float
        :param: path_of_working_directory_rce: input string
        :param: current_workflow_name: input string
        :return: calibration_settings: output list of lists
    """

    ''' imports for python '''
    from datetime import datetime

    ''' read data for script execution '''
    calibration_factor_high = ([item for item in calibration_settings if 'calibration_factor_high' in item])[-1][-1]
    calibration_value_high = ([item for item in calibration_settings if 'calibration_value_high' in item])[-1][-1]
    calibration_factor_low = ([item for item in calibration_settings if 'calibration_factor_low' in item])[-1][-1]
    calibration_value_low = ([item for item in calibration_settings if 'calibration_value_low' in item])[-1][-1]

    ''' initialize local parameter '''
    log_file_list = []

    print('  Extrapolation failed. Use auxiliary interpolation:')
    print('  low[' + str(calibration_factor_low) + '; ' + str(calibration_value_low) + '] | high['
          + str(calibration_factor_high) + '; ' + str(calibration_value_high) + ']')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                         'Extrapolation failed. Use auxiliary interpolation:')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                         'low[' + str(calibration_factor_low) + '; ' +
                         str(calibration_value_low) + '] | high[' + str(calibration_factor_high) + '; '
                         + str(calibration_value_high) + ']')

    calibration_factor_temp = (calibration_factor_high - calibration_factor_low) / \
                              (calibration_value_high - calibration_value_low) * \
                              (calibration_target_value - calibration_value_low) + calibration_factor_low

    print('  Corrected calibration factor (new): ' + str(calibration_factor_temp))
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   Corrected calibration factor (new): '
                         + str(calibration_factor_temp))

    ''' set output parameter for next iteration step '''
    ([item for item in calibration_settings if 'aux_interpolation_flag' in item])[-1][-1] = int(1)
    ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] = calibration_factor_temp

    # write function output to workflow log file
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    return calibration_settings
