def perform_ome_iteration(paths_and_names, calibration_settings, ome_loop_vector, parameter_for_design_case,
                          calibration_factors, count_of_calibration):
    """ set_settings_for_ome_calibration initialized calibration variables for OME calibration.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The input list "ome_loop_vector" contains all estimated ome values.

        The input list "calibration_factors" contains all estimated calibration factors.

        The input value "count_of_calibration" contains the number of current calibration step.

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The output list "ome_loop_vector" contains all estimated ome values.

        The output list "calibration_factors" contains all estimated calibration factors.

        :param: paths_and_names: input list of lists
        :param: calibration_settings: input list of lists
        :param: ome_loop_vector: input list
        :param: parameter_for_design_case: input list of lists
        :param: calibration_factors: input list
        :param: count_of_calibration: input value
        :return: calibration_settings: output list of lists, ome_loop_vector: output list, calibration_factors: output list
    """

    ''' imports for python '''
    import os
    import sys
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file
    from calibration.perform_ome_calibration import perform_ome_calibration
    from calibration.save_calibration_results_to_file import save_calibration_results_to_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    calibrate_ome_flag = bool(([item for item in calibration_settings if 'calibrate_ome_flag' in item])[-1][-1])
    calibration_target_ome = ([item for item in calibration_settings if 'calibration_target_OME' in item])[-1][-1]
    last_ome = ([item for item in calibration_settings if 'current_value' in item])[-1][-1]

    damp_ome_iteration = int(([item for item in parameter_for_design_case if 'damp_ome_iteration' in item])[-1][-1])

    ''' initialize local parameter '''
    log_file_list = []
    function_name = getframeinfo(currentframe()).function

    ''' check if damping is activated -> if true: -> print warning and set damping flag to zero '''
    if damp_ome_iteration == 1:
        print('* Warning: Damping in calibration mode is not possible and will not performed! \n  '
              'Only allowed in clean-sheet-design without calibration!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': * Warning: '
                             'Damping in calibration mode is not possible and will not performed! \n'
                             '                       Only allowed in clean-sheet-design without calibration! \n ')

        ([item for item in parameter_for_design_case if 'damp_ome_iteration' in item])[-1][-1] = int(0)

    ''' open and read aircraft exchange file '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name,
                                                             frame_info.lineno, log_file_list, current_workflow_name)

    current_ome = float(root_of_aircraft_exchange_tree.find('./MassesAndLoadings/OME').text)
    ome_loop_vector.append(current_ome)

    # write results of current calibration loop to workflow log-file
    print("* results: ")
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': * results:')

    if last_ome > 0:
        residual_ome = abs(1 - last_ome/current_ome)
        residual_to_target = abs(1 - current_ome / calibration_target_ome)
        print("  (current) OME  = " + str(current_ome) + " kg | Res. OME: " + str(residual_ome) + " | Res. to target = "
              + str(residual_to_target))
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   (current) OME  = '
                             + str(current_ome) + ' kg | Res. OME: ' + str(residual_ome) + " | Res. to target = "
                             + str(residual_to_target))

    else:
        residual_ome = abs(1 - last_ome / current_ome)
        residual_to_target = abs(1 - current_ome / calibration_target_ome)
        print("  (current) OME  = " + str(current_ome) + " kg | Res. OME: " + str(residual_ome) + " | Res. to target = "
              + str(residual_to_target))
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   (current) OME  = '
                             + str(current_ome) + ' kg | Res. OME: ' + str(residual_ome) + " | Res. to target = "
                             + str(residual_to_target))
        print('  After ' + str(count_of_calibration) + '. Iteration Value for OME = ' + str(current_ome)
              + '. Program aborted!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   After '
                             + str(count_of_calibration) + '. Iteration Value for OME = ' + str(current_ome)
                             + '. Program aborted!')

    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    ([item for item in calibration_settings if 'residual_iteration_value' in item])[-1][-1] = residual_ome
    ([item for item in calibration_settings if 'residual_iteration_value_to_target' in item])[-1][-1] = \
        residual_to_target

    # check if current count of calibration is greater than 2 and the calibration flag is equal to 'True'
    #  -> if true: -> perform ome calibration
    if count_of_calibration > 1 and calibrate_ome_flag == 1:
        # call function to perform ome calibration
        calibration_settings, ome_loop_vector, calibration_factors = \
            perform_ome_calibration(calibration_settings, parameter_for_design_case, ome_loop_vector,
                                    calibration_factors, count_of_calibration, path_of_working_directory_rce,
                                    current_workflow_name)

    ''' set output parameter for next iteration step '''
    ([item for item in calibration_settings if 'last_value' in item])[-1][-1] = last_ome
    ([item for item in calibration_settings if 'current_value' in item])[-1][-1] = current_ome

    ''' check if calibration not successful '''
    if calibrate_ome_flag == 1:
        ''' save aircraft exchange file of calibration loop to temporary results directory '''
        aircraft_exchange_files_of_ome_calibration = \
            path_of_working_directory_rce + current_workflow_name \
            + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/OMEcalibration/'
        if not os.path.isdir(aircraft_exchange_files_of_ome_calibration):
            os.makedirs(aircraft_exchange_files_of_ome_calibration)

        # save aircraft exchange file of current loop
        project_file_name = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
            + aircraft_exchange_file
        shutil.copy(project_file_name, aircraft_exchange_files_of_ome_calibration + aircraft_exchange_file[:-4]
                    + '_it' + str(count_of_calibration) + '.xml')

        ''' save calibration results to csv file '''
        if calibrate_ome_flag == 1:
            save_calibration_results_to_file(paths_and_names, count_of_calibration, residual_ome, 'OME')

    ''' check if maximum number of iteration is reached '''
    max_iterations_before_exit_ome_calibration =\
        ([item for item in calibration_settings if 'max_iterations_before_exit_OME_calibration' in item])[-1][-1]
    if count_of_calibration >= max_iterations_before_exit_ome_calibration:
        print('  Maximum number of ' + str(max_iterations_before_exit_ome_calibration)
              + ' Iterations reached during OME calibration. No convergence! Abort program!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Maximum number of ' + str(max_iterations_before_exit_ome_calibration) +
                             ' Iterations reached during OME calibration. No convergence! Abort program!')

        log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
        for row in log_file_list:
            log_file.write(row + '\n')
        log_file.close()
        # abort program
        sys.exit(1)

    return calibration_settings, ome_loop_vector, calibration_factors
