def read_calibration_parameter(root_of_workflow_tree):
    """ read_calibration_parameter read the calibration settings from workflow configuration file.
        Set values to output lists for following workflow components.

        The input element "root_of_workflow_tree" contains the xml-tree of workflow configuration file.


calibration_settings = [['free_variable_OME_calibration', free_variable_ome_calibration],
                            ['free_variable_MTOM_calibration', free_variable_mtom_calibration],
                            ['calibration_target_OME', calibration_target_ome],
                            ['calibration_target_mtom', calibration_target_mtom],
                            ['reset_fuselage_mass_at_start', reset_fuselage_mass_at_start],
                            ['reset_viscous_drag_counts_at_start', reset_viscous_drag_counts_at_start],
                            ['reset_engine_fuel_flow_factor_at_start', reset_engine_fuel_flow_factor_at_start],
                            ['number_of_iterations_before_mtom_calibration',
                             number_of_iterations_before_mtom_calibration],
                            ['max_iterations_before_exit_OME_calibration', max_iterations_before_exit_ome_calibration],
                            ['trunc_Error_factor', trunc_error_factor],
                            ['damp_MTOM_calibration_lever', damp_mtom_calibration_lever],
                            ['x_rel_max_for_MTOM_damp', x_rel_max_for_mtom_damp],
                            ['damp_OME_calibration_lever', damp_ome_calibration_lever],
                            ['x_rel_max_for_OME_damp', x_rel_max_for_ome_damp]]
        The output list of lists "calibration_settings" contains the following values:
            *  [1][0] string: 'free_variable_OME_calibration',                   [1][1] int:   'switch for free variable OME calibration'
            *  [2][0] string: 'free_variable_MTOM_calibration',                  [2][1] int:   'switch for free variable MTOM calibration'
            *  [3][0] string: 'calibration_target_OME',                          [3][1] float: 'target value for OME calibration'
            *  [4][0] string: 'calibration_target_mtom',                         [4][1] float: 'target value for MTOM calibration'
            *  [5][0] string: 'reset_fuselage_mass_at_start',                    [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'reset_viscous_drag_counts_at_start',              [6][1] int:   'switch to reset aerodynamic MTOM calibration value at start'
            *  [7][0] string: 'reset_engine_fuel_flow_factor_at_start',          [7][1] int:   'switch to reset engine MTOM calibration value at start'
            *  [8][0] string: 'number_of_iterations_before_mtom_calibration',    [8][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            *  [9][0] string: 'max_iterations_before_exit_OME_calibration',      [9][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [10][0] string: 'trunc_Error_factor',                             [10][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [11][0] string: 'damp_MTOM_calibration_lever',                    [11][1] int:   'switch for damping MTOM calibration lever arm'
            * [12][0] string: 'x_rel_max_for_MTOM_damp',                        [12][1] float: 'value of relative MTOM calibration lever arm'
            * [13][0] string: 'damp_OME_calibration_lever',                     [13][1] int:   'Switch for damping OME calibration lever arm'
            * [14][0] string: 'x_rel_max_for_OME_damp',                         [14][1] float: 'value of relative OME calibration lever arm'

        :param: root_of_workflow_tree: input element-tree
        :return: calibration_settings: output list of lists
    """

    convert_mode_to_int_dict = {
        'mode_0' : int(0),
        'mode_1' : int(1),
        'mode_2' : int(2),
        'mode_3' : int(3),
        'mode_4' : int(4),
        'mode_5' : int(5)
    }

    ''' read calibration parameters from given elementTree '''
    free_variable_ome_calibration = convert_mode_to_int_dict[root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/ome_calibration_mode/value").text]
    free_variable_mtom_calibration = convert_mode_to_int_dict[root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/mtom_calibration_mode/value").text]
    calibration_target_ome = float(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/target_values/ome/value").text)
    calibration_target_mtom = float(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/target_values/mtom/value").text)
    reset_fuselage_mass_at_start = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/"
        "reset_calibration_factors_at_start/reset_fuselage_mass/value").text.lower() in ['true', 'True', '1', 't'])
    reset_viscous_drag_counts_at_start = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/"
        "reset_calibration_factors_at_start/reset_viscous_drag_counts/value").text.lower() in ['true', 'True', '1', 't'])
    reset_engine_fuel_flow_factor_at_start = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/"
        "reset_calibration_factors_at_start/reset_engine_fuel_flow_factor/value").text.lower() in ['true', 'True', '1', 't'])
    number_of_iterations_before_mtom_calibration = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "number_of_before_new_mtom_calibration_step/value").text)
    max_iterations_before_exit_ome_calibration = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "max_number_of_iterations_before_ome_calibration_exit/value").text)
    trunc_error_factor = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "factor_for_convergence_criteria/value").text)
    damp_mtom_calibration_lever = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "damp_MTOM_calibration/enable/value").text.lower() in ['true', 'True', '1', 't'])
    x_rel_max_for_mtom_damp = float(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "damp_MTOM_calibration/maximum_mtom_extrapolation_lever/value").text)
    damp_ome_calibration_lever = int(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "damp_OME_calibration/enable/value").text.lower() in ['true', 'True', '1', 't'])
    x_rel_max_for_ome_damp = float(root_of_workflow_tree.find(
        "./program_settings/design_case_settings/calibration_settings/iteration_settings/"
        "damp_OME_calibration/maximum_ome_extrapolation_lever/value").text)

    ''' save input parameters as a list of lists '''
    calibration_settings = [['free_variable_OME_calibration', free_variable_ome_calibration],
                            ['free_variable_MTOM_calibration', free_variable_mtom_calibration],
                            ['calibration_target_OME', calibration_target_ome],
                            ['calibration_target_mtom', calibration_target_mtom],
                            ['reset_fuselage_mass_at_start', reset_fuselage_mass_at_start],
                            ['reset_viscous_drag_counts_at_start', reset_viscous_drag_counts_at_start],
                            ['reset_engine_fuel_flow_factor_at_start', reset_engine_fuel_flow_factor_at_start],
                            ['number_of_iterations_before_mtom_calibration',
                             number_of_iterations_before_mtom_calibration],
                            ['max_iterations_before_exit_OME_calibration', max_iterations_before_exit_ome_calibration],
                            ['trunc_Error_factor', trunc_error_factor],
                            ['damp_MTOM_calibration_lever', damp_mtom_calibration_lever],
                            ['x_rel_max_for_MTOM_damp', x_rel_max_for_mtom_damp],
                            ['damp_OME_calibration_lever', damp_ome_calibration_lever],
                            ['x_rel_max_for_OME_damp', x_rel_max_for_ome_damp]]

    return calibration_settings
