def reset_free_calibration_variables(paths_and_names, calibration_settings, log_file_list):
    """ reset_free_calibration_variables resets free calibration variables in tool configuration files.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'

        The input list "log_file_list" contains all system prints of function: set_configuration_parameter.py.

        The output list "log_file_list" contains all system prints of functions: set_configuration_parameter.py and select_engine_from_existing_project.py.

        :param: paths_and_names: input list of lists
        :param: calibration_settings: input list of lists
        :param: log_file_list: input list
        :return: log_file_list: output list of lists
    """

    ''' imports for python '''
    import sys
    from inspect import currentframe, getframeinfo
    from datetime import datetime
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    skip_ome_calibration = int(([item for item in calibration_settings if 'skip_OME_calibration' in item])[-1][-1])
    free_variable_ome_calibration = \
        int(([item for item in calibration_settings if 'free_variable_OME_calibration' in item])[-1][-1])
    free_variable_mtom_calibration = \
        int(([item for item in calibration_settings if 'free_variable_MTOM_calibration' in item])[-1][-1])
    reset_both_variables_at_start = \
        int(([item for item in calibration_settings if 'reset_both_variables_at_start' in item])[-1][-1])
    reset_used_variables_at_start = \
        int(([item for item in calibration_settings if 'reset_used_variables_at_start' in item])[-1][-1])

    function_name = getframeinfo(currentframe()).function

    ''' reset free variables for calibration mode '''
    # reset free OME calibration variables
    if skip_ome_calibration == 0 and free_variable_ome_calibration == 1:
        # try to open weight_and_balance_analysis module configuration file
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/weight_and_balance_analysis_conf.xml'
        root_of_mass_estimation_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'weight_and_balance_analysis',
                                                               function_name, frame_info.lineno, log_file_list,
                                                               current_workflow_name)

        # reset fuselage scaling factor in weight_and_balance_analysis configuration file to 1
        root_of_mass_estimation_tree.find('./ProgramSettings/ScalingFactors/Fuselage').text = str(1)

        # write settings to configuration xml file
        xml_tree.write(path, encoding='utf-8')
        print('For OME calibration fuselage scaling factor in mass estimation configuration file reset to 1.')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'For OME calibration fuselage scaling factor in mass estimation configuration file '
                             'reset to 1.')

    # reset free MTOM calibration variables
    if reset_used_variables_at_start == 1 or reset_both_variables_at_start == 1:
        # case 1 -> fuel flow calibration mode
        if reset_both_variables_at_start == 1 or free_variable_mtom_calibration == 1:
            # try to open propulsion_design module configuration file
            frame_info = getframeinfo(currentframe())
            path = path_of_working_directory_rce + current_workflow_name + '/propulsion_design_conf.xml'
            root_of_engine_sizing_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'propulsion_design',
                                                                 function_name, frame_info.lineno, log_file_list,
                                                                 current_workflow_name)

            # reset fuel flow scaling factor in propulsion_design configuration file to 1
            root_of_engine_sizing_tree.find('./ProgramSettings/ScaleFactorFuelFlow').text = str(1)

            # write settings to configuration xml file
            xml_tree.write(path, encoding='utf-8')
            print('For MTOM calibration fuel flow scaling factor in propulsion_design configuration file reset to 1.')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'For MTOM calibration fuel flow scaling factor in propulsion_design configuration file '
                                 'reset to 1.')

        # case 2 -> drag count reduction or fuel flow calibration mode and drag count reduction
        if free_variable_mtom_calibration == 2 or reset_both_variables_at_start == 1:
            # try to open aerodynamic_assessment module configuration file
            frame_info = getframeinfo(currentframe())
            path = path_of_working_directory_rce + current_workflow_name + '/aerodynamic_assessment_conf.xml'
            root_of_calculate_polar_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                                   'aerodynamic_assessment', function_name, frame_info.lineno,
                                                                   log_file_list, current_workflow_name)

            # reset calibration drag count reduction value in aerodynamic_assessment configuration file to 0
            root_of_calculate_polar_tree.find(
                './ProgramSettings/DragModification/DragCtCorrectionCleanPolar/deltaViscDragWing').text = str(0)

            # write settings to configuration xml file
            xml_tree.write(path, encoding='utf-8')
            print('For MTOM calibration drag count reduction factor in aerodynamic_assessment configuration file reset to 0.')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'For MTOM calibration drag count reduction factor in aerodynamic_assessment configuration '
                                 'file reset to 0.')

        if not free_variable_mtom_calibration == 1 and not free_variable_mtom_calibration == 2:
            print('No correct free variable for MTOM Calibration given in workflow configuration file. '
                  'Entered value for free variable mtom calibration is not correct. Please change the value. '
                  'Program aborted')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'No correct free variable for MTOM Calibration given in workflow configuration file. '
                                 'Entered value for free variable mtom calibration is not correct. '
                                 'Please change the value. Program aborted')
            log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
            for row in log_file_list:
                log_file.write(row + '\n')
            log_file.close()
            sys.exit(1)

    return log_file_list
