def set_new_calibration_factor(calibration_settings, calibration_factors, residual_m_block_fuel, count_of_calibration,
                               convergence_criteria, type_of_calibration, path_of_working_directory_rce,
                               current_workflow_name='UNICADOworkflow'):
    """ check_calibration_value_target checks the the actual calibration value against the target calibration value.

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The input list "calibration_factors" contains all estimated calibration factors.

        The input float "residual_m_block_fuel" contains the residual of mission fuel mass of current iteration loop.

        The input int "count_of_calibration" contains the execution number of current function.

        The input float "convergence_criteria" contains the given convergence criteria for calibration iteration.

        The input value "type_of_calibration" contains the string of name of current calibration mode.

        The input string "path_of_working_directory_rce" contains the system path to rce working directory.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default string 'UNICADOworkflow' is used.

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The output list "calibration_factors" contains all estimated calibration factors.

        :param: calibration_settings: input list of lists
        :param: calibration_factors: input list
        :param: residual_m_block_fuel: input float
        :param: count_of_calibration: input int
        :param: convergence_criteria: input float
        :param: type_of_calibration: input value
        :param: path_of_working_directory_rce: input int
        :param: current_workflow_name: input string
        :return: calibration_settings: output list of lists, calibration_factors: output list
    """

    ''' imports for python '''
    import sys
    from datetime import datetime
    from calibration.set_lever_arm import set_lever_arm
    from calibration.set_new_calibration_flag import set_new_calibration_flag
    from calibration.check_number_of_iterations import check_number_of_iterations

    ''' read data for script execution '''
    calibration_target_ome = ([item for item in calibration_settings if 'calibration_target_OME' in item])[-1][-1]
    calibration_target_mtom = ([item for item in calibration_settings if 'calibration_target_mtom' in item])[-1][-1]
    calibration_value_act = ([item for item in calibration_settings if 'calibration_value_act' in item])[-1][-1]
    calibration_value_last = ([item for item in calibration_settings if 'calibration_value_last' in item])[-1][-1]
    calibration_factor_temp = \
        float(([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1])
    calibration_factor_last = ([item for item in calibration_settings if 'calibration_factor_last' in item])[-1][-1]
    calibration_factor_act = ([item for item in calibration_settings if 'calibration_factor_act' in item])[-1][-1]
    free_variable_mtom_calibration = \
        int(([item for item in calibration_settings if 'free_variable_MTOM_calibration' in item])[-1][-1])

    ''' initialize local parameter '''
    log_file_list = []
    print('  Calibration factor (act) = ' + str(calibration_factor_act) + ' | Calibration factor (last) = '
          + str(calibration_factor_last) + '.')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   Calibration factor (act) = '
                         + str(calibration_factor_act) + ' | Calibration factor (last) = '
                         + str(calibration_factor_last) + '.')

    # write function output to workflow log file
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    log_file_list = []

    ''' set mtom calibration factors '''
    if type_of_calibration == 'MTOM':
        number_of_iterations_before_mtom_calibration = \
            int(([item for item in calibration_settings
                  if 'number_of_iterations_before_mtom_calibration' in item])[-1][-1])

        # check if the current calibration the first mtom calibration of current project
        if (count_of_calibration - 1) == number_of_iterations_before_mtom_calibration:
            calibration_value_flag = calibration_value_act
            if calibration_value_act >= calibration_target_mtom:
                if free_variable_mtom_calibration == 1:
                    calibration_factor_temp *= 0.96
                else:
                    calibration_factor_temp -= 4.0
            else:
                if free_variable_mtom_calibration == 1:
                    calibration_factor_temp *= 1.04
                else:
                    calibration_factor_temp += 4.0

            ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] = \
                float(calibration_factor_temp)
            ([item for item in calibration_settings if 'calibration_value_flag' in item])[-1][-1] = \
                float(calibration_value_flag)

            if free_variable_mtom_calibration == 1:
                print('  FF fact. (new), after 1. Cal.-Run = ' + str(calibration_factor_temp))
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) +
                                     ':   FF fact. (new), after 1. Cal.-Run = ' + str(calibration_factor_temp))
            else:
                print('  Aero fact. (new), after 1. Cal.-Run = ' + str(calibration_factor_temp))
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) +
                                     ':   Aero fact. (new), after 1. Cal.-Run = ' + str(calibration_factor_temp))

            # write function output to workflow log file
            log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
            for row in log_file_list:
                log_file.write(row + '\n')
            log_file.close()

        else:
            if free_variable_mtom_calibration == 1:
                # call function to check which number of mtom calibration iteration is performed
                calibration_settings = check_number_of_iterations(calibration_settings, residual_m_block_fuel,
                                                                  convergence_criteria, 'MTOM',
                                                                  path_of_working_directory_rce, current_workflow_name)

            else:
                if ((calibration_factors[-1] > calibration_factors[-2])
                    and (calibration_value_act < calibration_value_last)) \
                        or ((calibration_factors[-1] < calibration_factors[-2])
                            and (calibration_value_act > calibration_value_last)):
                    print('  Number of iterations after which interpolation/extrapolation is performed, '
                          'possibly too low!')
                    print('  Increase number of mtom calibration iterations in workflow configuration file!')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) +
                                         ':   Number of iterations after which interpolation/extrapolation is '
                                         'performed, possibly too low!')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) +
                                         ':   Increase number of mtom calibration iterations in workflow '
                                         'configuration file!')

                    # write function output to workflow log file
                    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
                    for row in log_file_list:
                        log_file.write(row + '\n')
                    log_file.close()
                    sys.exit(1)

            # call function to set the lever arm for ome calibration
            calibration_settings = set_lever_arm(calibration_settings, 'MTOM', path_of_working_directory_rce)

            # determine new calibration factor
            calibration_value_act = \
                ([item for item in calibration_settings if 'calibration_value_act' in item])[-1][-1]
            calibration_value_flag = \
                ([item for item in calibration_settings if 'calibration_value_flag' in item])[-1][-1]
            calibration_factor_flag = \
                ([item for item in calibration_settings if 'calibration_factor_flag' in item])[-1][-1]
            calibration_factor_act = \
                ([item for item in calibration_settings if 'calibration_factor_act' in item])[-1][-1]
            x_relative = ([item for item in calibration_settings if 'x_relative' in item])[-1][-1]

            if free_variable_mtom_calibration == 1:
                # check if the current running calibration in an infinite loop
                #  -> if true: -> print a warning and perform specific exception handling
                if ((calibration_factor_act > calibration_factor_flag
                     and calibration_value_act < calibration_value_flag)
                        or (calibration_factor_act < calibration_factor_flag
                            and calibration_value_act > calibration_value_flag)):
                    print('  Warning! Reverse effect occurred during inter-/extrapolation.')
                    print('  Warning! Set x_re = -x_rel = -' + str(x_relative) + ' !')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                         'Warning! Reverse effect occurred during inter-/extrapolation.')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                         'Warning! Set x_re = -x_rel = -' + str(x_relative) + ' !')

                    x_relative *= -1

                calibration_factor_temp = (1 - x_relative) * calibration_factor_flag \
                    + x_relative * calibration_factor_act
                print('  FF fact. (new) = ' + str(calibration_factor_temp))
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   FF fact. (new) = '
                                     + str(calibration_factor_temp))

            else:
                calibration_factor_temp = (1 - x_relative) * calibration_factor_flag \
                                          + x_relative * calibration_factors[-1]
                print('  Aero fact. (new) = ' + str(calibration_factor_temp))
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                     'Aero fact. (new) = ' + str(calibration_factor_temp))

            ([item for item in calibration_settings if 'x_relative' in item])[-1][-1] = x_relative
            ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] = \
                calibration_factor_temp

            # write function output to workflow log file
            log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
            for row in log_file_list:
                log_file.write(row + '\n')
            log_file.close()

            # call function to set the values for next run flags for next iteration loop
            calibration_settings = set_new_calibration_flag(calibration_settings, calibration_factors, 'MTOM',
                                                            path_of_working_directory_rce, current_workflow_name)

    ''' set ome calibration factors '''
    if type_of_calibration == 'OME':
        # check if the current calibration the first ome calibration of current project
        if (count_of_calibration - 1) == 1:
            calibration_value_flag = calibration_value_act
            if calibration_value_act >= calibration_target_ome:
                calibration_factor_temp *= 0.96
            else:
                calibration_factor_temp *= 1.04

            ([item for item in calibration_settings if 'calibration_value_flag' in item])[-1][-1] =\
                calibration_value_flag
            ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] =\
                calibration_factor_temp

            print('  Fuselage fact. (new), after 1. Cal.-Run = ' + str(calibration_factor_temp))
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                 'Fuselage fact. (new), after 1. Cal.-Run = ' + str(calibration_factor_temp))

            # write function output to workflow log file
            log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
            for row in log_file_list:
                log_file.write(row + '\n')
            log_file.close()

        else:
            # call function to check which number of ome calibration iteration is performed
            calibration_settings = check_number_of_iterations(calibration_settings, 0.00, convergence_criteria, 'OME',
                                                              path_of_working_directory_rce, current_workflow_name)

            # call function to set the lever arm for ome calibration
            calibration_settings = set_lever_arm(calibration_settings, 'OME', path_of_working_directory_rce,
                                                 current_workflow_name)

            # determine new calibration factor
            calibration_value_act =\
                ([item for item in calibration_settings if 'calibration_value_act' in item])[-1][-1]
            calibration_value_flag =\
                ([item for item in calibration_settings if 'calibration_value_flag' in item])[-1][-1]
            calibration_factor_flag =\
                ([item for item in calibration_settings if 'calibration_factor_flag' in item])[-1][-1]
            calibration_factor_act =\
                ([item for item in calibration_settings if 'calibration_factor_act' in item])[-1][-1]
            x_relative = ([item for item in calibration_settings if 'x_relative' in item])[-1][-1]

            # check if the current running calibration in an infinite loop
            #  -> if true: -> print a warning and perform specific exception handling
            if ((calibration_factor_act > calibration_factor_flag and calibration_value_act < calibration_value_flag) or
               (calibration_factor_act < calibration_factor_flag and calibration_value_act > calibration_value_flag)):
                print('  Warning! Reverse effect occurred during inter-/extrapolation.')
                print('  Warning! Set x_re = -x_rel = -' + str(x_relative) + ' !')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                     'Warning! Reverse effect occurred during inter-/extrapolation.')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                     'Warning! Set x_re = -x_rel = -' + str(x_relative) + ' !')

                x_relative *= -1

            calibration_factor_temp = (1 - x_relative) * calibration_factor_flag + x_relative * calibration_factor_act
            ([item for item in calibration_settings if 'x_relative' in item])[-1][-1] = x_relative
            ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] = \
                calibration_factor_temp

            print('  Fuselage mass fact. (new) = ' + str(calibration_factor_temp))
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   Fuselage mass fact. (new) = '
                                 + str(calibration_factor_temp))

            # write function output to workflow log file
            log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
            for row in log_file_list:
                log_file.write(row + '\n')
            log_file.close()

            # call function to set the values for next run flags for next iteration loop
            calibration_settings = set_new_calibration_flag(calibration_settings, calibration_factors, 'OME',
                                                            path_of_working_directory_rce, current_workflow_name)

    return calibration_settings, calibration_factors
