def post_operation_of_design_sizing(paths_and_names, parameter_for_design_case, design_variables, control_settings,
                                    module_list_of_sizing_loop, calibration_settings, mtom_loop_vector,
                                    calibration_factors, accuracy_list, trim_parameter_list, i_stab, cm_cruise,
                                    design_sizing_iteration_flag):
    """ post_operation_of_design_sizing prepares design variables for converge component of RCE and calculates the residuals of design variables.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The input list of lists "design_variables" contains the following values:
            *  [0][0] string: 'm_take_off_max_last',                     [0][1] float: 'value of maximum take off mass of last iteration step'
            *  [1][0] string: 'm_operating_empty_last',                  [1][1] float: 'value of operating empty mass of last iteration step'
            *  [2][0] string: 'm_block_fuel_last',                       [2][1] float: 'value of block fuel mass of last iteration step'
            *  [3][0] string: 'x_center_of_gravity_last',                [3][1] float: 'value of x position of center of gravity of last iteration step'
            *  [4][0] string: 'cm_cruise',                               [4][1] float: 'value of the current moment coefficient'
            *  [5][0] string: 'i_stab',                                  [5][1] float: 'value of the current trimming angle of horizontal stabiliser'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_ome',                                   [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_ome_to_target',                         [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'final_fuselage_mass_factor',                     [38][1] float: 'value of final fuselage mass factor'
            * [39][0] string: 'current_ome',                                    [39][1] float: 'value of current operating mass empty'
            * [40][0] string: 'last_ome',                                       [40][1] float: 'value of last operating mass empty'
            * [41][0] string: 'iteration_flag'                                  [41][1] int:   'number of the status of calibration successful'

        The input list "mtom_loop_vector" contains all estimated mtom values.

        The input list "calibration_factors" contains all estimated calibration factors of mtom calibration.

        The input list of lists "accuracy_list" contains the following values:
            * [0][0] string: 'accuracy_low',    [0][1] float: 'value of low accuracy condition'
            * [1][0] string: 'accuracy_medium', [1][1] float: 'value of medium accuracy condition'
            * [2][0] string: 'accuracy_high',   [2][1] float: 'value of high accuracy condition'

        The input list of lists "trim_parameter_list" contains the following values:
            * [0][0] string: 'i_stab',                          [0][1] array: 'array of values of angle of incidence of horizontal stabilizer'
            * [1][0] string: 'i_stab_tmp',                      [1][1] float: 'value of temporary angle of incidence of horizontal stabilizer'
            * [2][0] string: 'i_stab_last',                     [2][1] float: 'value of last angle of incidence of horizontal stabilizer'
            * [3][0] string: 'cm_cruise',                       [3][1] array: 'array of values of moment coefficient of cruise flight'
            * [4][0] string: 'cm_cruise_current',               [4][1] float: 'value of temporary moment coefficient of cruise flight'
            * [5][0] string: 'cm_cruise_last',                  [5][1] float: 'value of last moment coefficient of cruise flight'
            * [6][0] string: 'flag_trim_successful',            [6][1] int:   'value to signalize that trim is successful'
            * [7][0] string: 'retries',                         [7][1] int:   'value to count the retries of trim function'
            * [8][0] String: 'trim_accuracy'                    [8][1] float: 'value of trim accuracy if the ohn convergence criterion should be used'
            * [9][0] String: 'use_own_convergence_criterion'    [9][1] int:   'flag to use own convergence criterion for the trim accuracy'

        The input list "i_stab" contains the following values:
            * [count_of_iteration] float: 'values of angle of incidence of horizontal stabilizer'

        The input list "cm_cruise" contains the following values:
            * [count_of_iteration] float: 'values of moment coefficient of cruise flight'

        The input float "design_sizing_iteration_flag" contains the status of the design sizing loop is finished or not.

        The output list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The output list of lists "design_variables" contains the following values:
            *  [0][0] string: 'm_take_off_max_last',                     [0][1] float: 'value of maximum take off mass of last iteration step'
            *  [1][0] string: 'm_operating_empty_last',                  [1][1] float: 'value of operating empty mass of last iteration step'
            *  [2][0] string: 'm_block_fuel_last',                       [2][1] float: 'value of block fuel mass of last iteration step'
            *  [3][0] string: 'x_center_of_gravity_last',                [3][1] float: 'value of x position of center of gravity of last iteration step'
            *  [4][0] string: 'cm_cruise',                               [4][1] float: 'value of the current moment coefficient'
            *  [5][0] string: 'i_stab',                                  [5][1] float: 'value of the current trimming angle of horizontal stabiliser'
            *  [6][0] string: 'm_take_off_max',                          [6][1] float: 'value of maximum take off mass of current iteration step'
            *  [7][0] string: 'm_operating_empty',                       [7][1] float: 'value of operating empty mass of current iteration step'
            *  [8][0] string: 'm_block_fuel',                            [8][1] float: 'value of block fuel mass of current iteration step'
            *  [9][0] string: 'x_center_of_gravity',                     [9][1] float: 'value of x position of center of gravity of current iteration step'
            * [10][0] string: 'residual_m_take_off_max',                [10][1] float: 'value of residual of maximum take off mass of current iteration step'
            * [11][0] string: 'residual_m_operating_empty',             [11][1] float: 'value of residual of operating empty mass of current iteration step'
            * [12][0] string: 'residual_m_block_fuel',                  [12][1] float: 'value of residual of block fuel mass of current iteration step'
            * [13][0] string: 'residual_x_center_of_gravity',           [13][1] float: 'value of residual of x position of center of gravity of current iteration step'
            * [14][0] string: 'status_residual_m_take_off_max',         [14][1] bool:  'status of convergence for maximum take of mass'
            * [15][0] string: 'status_residual_m_operating_empty',      [15][1] bool:  'status of convergence for mass operating empty'
            * [16][0] string: 'status_residual_m_block_fuel',           [16][1] bool:  'status of convergence for mass of block fuel'
            * [17][0] string: 'status_residual_x_center_of_gravity',    [17][1] bool:  'status of convergence for the aft x-position of the center of gravity'

        The output list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_ome',                                   [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_ome_to_target',                         [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'final_fuselage_mass_factor',                     [38][1] float: 'value of final fuselage mass factor'
            * [39][0] string: 'current_ome',                                    [39][1] float: 'value of current operating mass empty'
            * [40][0] string: 'last_ome',                                       [40][1] float: 'value of last operating mass empty'
            * [41][0] string: 'iteration_flag'                                  [41][1] int:   'number of the status of calibration successful'

        The output list "mtom_loop_vector" contains all estimated mtom values.

        The output list "calibration_factors" contains all estimated calibration factors of mtom calibration.

        The input list of lists "trim_parameter_list" contains the following values:
            * [0][0] string: 'i_stab',                          [0][1] array: 'array of values of angle of incidence of horizontal stabilizer'
            * [1][0] string: 'i_stab_tmp',                      [1][1] float: 'value of temporary angle of incidence of horizontal stabilizer'
            * [2][0] string: 'i_stab_last',                     [2][1] float: 'value of last angle of incidence of horizontal stabilizer'
            * [3][0] string: 'cm_cruise',                       [3][1] array: 'array of values of moment coefficient of cruise flight'
            * [4][0] string: 'cm_cruise_current',               [4][1] float: 'value of temporary moment coefficient of cruise flight'
            * [5][0] string: 'cm_cruise_last',                  [5][1] float: 'value of last moment coefficient of cruise flight'
            * [6][0] string: 'flag_trim_successful',            [6][1] int:   'value to signalize that trim is successful'
            * [7][0] string: 'retries',                         [7][1] int:   'value to count the retries of trim function'
            * [8][0] String: 'trim_accuracy'                    [8][1] float: 'value of trim accuracy if the ohn convergence criterion should be used'
            * [9][0] String: 'use_own_convergence_criterion'    [9][1] int:   'flag to use own convergence criterion for the trim accuracy'

        The input list "i_stab" contains the following values:
            * [count_of_iteration] float: 'values of angle of incidence of horizontal stabilizer'

        The input list "cm_cruise" contains the following values:
            * [count_of_iteration] float: 'values of moment coefficient of cruise flight'

        The output float "design_sizing_iteration_flag" contains the status of the design sizing loop is finished or not.

        :param: paths_and_names: input list of lists
        :param: parameter_for_design_case: input list of lists
        :param: design_variables: input list of lists
        :param: control_settings: input list of lists
        :param: calibration_settings: input list of lists
        :param: mtom_loop_vector: input list
        :param: calibration_factors: input list
        :param: accuracy_list: input list of lists
        :param: trim_parameter_list: input list of lists
        :param: i_stab: input list
        :param: cm_cruise: input list
        :param: design_sizing_iteration_flag: input float
        :return: parameter_for_design_case: output list of lists, design_variables: output list of lists,
                 control_settings: output list of lists, mtom_loop_vector: output list,
                 trim_parameter_list: output list of list, i_stab: output list, cm_cruise: output list,
                 design_sizing_iteration_flag: output float
    """

    ''' import for python '''
    import os
    import shutil
    from datetime import datetime
    from design_sizing_loop.trim_function import trim_function
    from calibration.damp_iteration import damp_iteration
    from calibration.perform_mtom_calibration import perform_mtom_calibration
    from calibration.final_ome_calibration_steps import final_ome_calibration_steps
    from calibration.set_settings_for_mtom_calibration import set_settings_for_mtom_calibration
    from design_sizing_loop.estimate_design_sizing_residuals import estimate_design_sizing_residuals
    from design_sizing_loop.save_design_sizing_results_to_file import save_design_sizing_results_to_file
    from design_sizing_loop.activate_plots_and_reports_for_sizing_loop import activate_plots_and_reports_for_sizing_loop

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory = ([item for item in paths_and_names if 'path_of_working_directory' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    automatic_trim = int(([item for item in parameter_for_design_case if 'automatic_trim' in item])[-1][-1])
    convergence_criteria = ([item for item in parameter_for_design_case if 'convergence_criteria' in item])[-1][-1]
    count_of_iteration = ([item for item in parameter_for_design_case if 'count_of_iteration' in item])[-1][-1]
    damp_mtom_iteration = int(([item for item in parameter_for_design_case if 'damp_mtom_iteration' in item])[-1][-1])
    number_of_max_iteration = \
        ([item for item in parameter_for_design_case if 'number_of_max_iteration' in item])[-1][-1]

    flag_trim_successful = int(([item for item in trim_parameter_list if 'flag_trim_successful' in item])[-1][-1])

    calibrate_ome_flag = int(([item for item in calibration_settings if 'calibrate_ome_flag' in item])[-1][-1])
    calibrate_mtom_flag = int(([item for item in calibration_settings if 'calibrate_mtom_flag' in item])[-1][-1])
    calibration_check_flag = int(([item for item in calibration_settings if 'calibration_check_flag' in item])[-1][-1])
    number_of_final_runs = int(([item for item in calibration_settings if 'number_of_final_runs' in item])[-1][-1])
    number_of_iterations_before_mtom_calibration = \
        int(([item for item in calibration_settings if 'number_of_iterations_before_mtom_calibration' in item])[-1][-1])

    ''' initialize local parameter '''
    final_ome_iteration_run = False
    status_flag_to_skip_design_sizing = \
        int(([item for item in control_settings if 'status_flag_to_skip_design_sizing' in item])[-1][-1])

    # check if the final plot and report generation loop should be performed
    if status_flag_to_skip_design_sizing == 0:
        ''' check if ome calibration is performed -> if true: -> perform final steps of ome calibration '''
        if calibrate_ome_flag == 1:
            # call function to perform final ome calibration steps isf selected
            final_ome_calibration_steps(paths_and_names)

            # set perform ome calibration flag to "False"
            ([item for item in calibration_settings if 'calibrate_ome_flag' in item])[-1][-1] = int(0)

            # set flag for final ome iteration run
            final_ome_iteration_run = True

        ''' reset and reinitialize values for mtom calibration if selected in workflow configuration file '''
        if calibration_check_flag == 1 and count_of_iteration == 0:
            # call function to set settings of mtom calibration
            calibration_settings, calibration_factors = set_settings_for_mtom_calibration(paths_and_names,
                                                                                          calibration_settings,
                                                                                          calibration_factors)

        # add iteration flag to list of calibration settings to perform convergence checks of sizing loop
        if count_of_iteration == 0:
            calibration_settings.append(['iteration_flag', int(0)])

        ''' add + 1 to count of iteration '''
        count_of_calibration = count_of_iteration
        count_of_iteration = count_of_iteration + 1
        ([item for item in parameter_for_design_case if 'count_of_iteration' in item])[-1][-1] = count_of_iteration

        ''' estimate relative residuals of iteration variables '''
        # call function to estimate residuals of design sizing loop
        design_variables, mtom_loop_vector, valid_data = \
            estimate_design_sizing_residuals(paths_and_names, design_variables, mtom_loop_vector,
                                             number_of_max_iteration - 1, count_of_iteration, calibration_check_flag,
                                             convergence_criteria)

        ''' perform mtom calibration to target value if selected in workflow configuration file '''
        if not os.path.isfile(path_of_working_directory_rce + current_workflow_name
                              + '/temp/workflowExecutionError.dat'):
            if calibration_check_flag == 1:
                modulo_of_iteration_count = (count_of_calibration - 1) % number_of_iterations_before_mtom_calibration
                if calibrate_mtom_flag == 1 and count_of_calibration > number_of_iterations_before_mtom_calibration \
                        and modulo_of_iteration_count == 0:
                    # call function to perform mtom calibration
                    calibration_settings, mtom_loop_vector, calibration_factors = \
                        perform_mtom_calibration(calibration_settings, parameter_for_design_case, design_variables,
                                                 mtom_loop_vector, calibration_factors, count_of_calibration,
                                                 automatic_trim, flag_trim_successful, path_of_working_directory_rce,
                                                 current_workflow_name)

        ''' initialize local parameter '''
        # date_time_counter is the number of characters of date and time print of workflow logfile
        #  -> should not be printed in the workflow console
        character_length_of_date_and_time = 21
        log_file_list = []

        ''' reload iteration flags after calibration is performed '''
        iteration_flag = int(([item for item in calibration_settings if 'iteration_flag' in item])[-1][-1])
        calibrate_mtom_flag = int(([item for item in calibration_settings if 'calibrate_mtom_flag' in item])[-1][-1])

        ''' check if mtom calibration is finished to perform three final iteration loops '''
        if iteration_flag == 1 and calibrate_mtom_flag == 0:
            if number_of_final_runs == 3:
                ([item for item in calibration_settings if 'calibration_check_flag' in item])[-1][-1] = int(0)
                ([item for item in parameter_for_design_case if 'count_of_iteration' in item])[-1][-1] =\
                    count_of_calibration

            number_of_final_runs += 1
            ([item for item in calibration_settings if 'number_of_final_runs' in item])[-1][-1] = \
                int(number_of_final_runs)

        ''' perform automatic trim if selected '''
        if not final_ome_iteration_run:
            count_for_trimming = count_of_iteration

            # check if calibration mode is selected -> if true: -> reduce iteration counter by 1
            if calibration_check_flag == 1:
                count_for_trimming = count_of_iteration - 1

            # call function to perform automatic trim
            trim_parameter_list, parameter_for_design_case, i_stab, cm_cruise =\
                trim_function(paths_and_names, parameter_for_design_case, accuracy_list, trim_parameter_list, i_stab,
                              cm_cruise, count_for_trimming)

        if calibration_check_flag == 1 and damp_mtom_iteration == 1:
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': * '
                                 'Warning: Damping in calibration mode is not possible and will not performed! \n'
                                 '                       Only allowed in clean-sheet-design without calibration! \n ')
            ([item for item in parameter_for_design_case if 'damp_mtom_iteration' in item])[-1][-1] = int(0)

        ''' save iteration parameter to csv-file '''
        save_design_sizing_results_to_file(paths_and_names, design_variables, count_of_iteration)

        ''' save final aircraft-exchange-file '''
        file_name = aircraft_exchange_file[:len(aircraft_exchange_file) - 4]
        path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
            + aircraft_exchange_file

        file_destination = current_workflow_name \
            + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' + file_name + '_it' \
            + str(count_of_iteration) + '.xml'
        if os.path.isfile(path_of_working_directory_rce + file_destination):
            os.remove(path_of_working_directory_rce + file_destination)
        shutil.copy(path, path_of_working_directory_rce + file_destination)

        # check for last iteration step left
        if number_of_max_iteration - 1 <= 1:
            # create backUp-file from aircraft exchange file
            file_destination = current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' \
                + file_name + '_finalLoop.xml'
            shutil.copy(path, path_of_working_directory_rce + file_destination)

        ''' generate outputs for RCE '''
        # set changed parameter for design case to list of list "parameter_for_design_case"
        number_of_max_iteration -= 1
        ([item for item in parameter_for_design_case if 'number_of_max_iteration' in item])[-1][-1] =\
            number_of_max_iteration

        ''' damp mtom value for the next loop if mtom damping is selected in workflow configuration file '''
        calibration_check_flag = \
            int(([item for item in calibration_settings if 'calibration_check_flag' in item])[-1][-1])
        damp_mtom_iteration = \
            int(([item for item in parameter_for_design_case if 'damp_mtom_iteration' in item])[-1][-1])
        flag_trim_successful = \
            int(([item for item in trim_parameter_list if 'flag_trim_successful' in item])[-1][-1])
        status_residual_m_block_fuel = \
            ([item for item in design_variables if 'status_residual_m_block_fuel' in item])[-1][-1]
        status_residual_m_take_off_max = \
            ([item for item in design_variables if 'status_residual_m_take_off_max' in item])[-1][-1]
        status_residual_m_operating_empty =\
            ([item for item in design_variables if 'status_residual_m_operating_empty' in item])[-1][-1]
        status_residual_x_center_of_gravity = \
            ([item for item in design_variables if 'status_residual_x_center_of_gravity' in item])[-1][-1]

        ''' check if max iteration is reached -> if true: -> set trim successful flag to "true" '''
        if automatic_trim == 1 and not valid_data:
            (([item for item in trim_parameter_list if 'flag_trim_successful' in item])[-1][-1]) = int(1)

        # check if convergence criteria of each iteration variable is reached
        # -> if true: -> send converged output flag to converge module of RCE
        if status_residual_m_block_fuel and status_residual_m_take_off_max and status_residual_m_operating_empty \
                and status_residual_x_center_of_gravity and calibration_check_flag == 0 and flag_trim_successful == 1:

            calibration_target_mtom = \
                ([item for item in calibration_settings if 'calibration_target_mtom' in item])[-1][-1]

            if not os.path.isfile(path_of_working_directory_rce + current_workflow_name
                                  + '/temp/workflowExecutionError.dat'):
                if iteration_flag == 1:
                    ([item for item in parameter_for_design_case if 'count_of_iteration' in item])[-1][-1]\
                        = count_of_iteration
                    log_file_list.append('')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': ---')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':  '
                                         'Convergence successful. Result of the MTOM calibration:')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':  '
                                         'MTOM set point: ' + str(calibration_target_mtom) + ' kg')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':  '
                                         'MTOM actual value: ' + str(mtom_loop_vector[-1]) + ' kg')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': ---')
                    if not flag_trim_successful == 1:
                        log_file_list.append('')

                # activate plot and report generation if selected
                plot_output_on = int(([item for item in control_settings if 'plot_output_on' in item])[-1][-1])
                report_output_on = int(([item for item in control_settings if 'report_output_on' in item])[-1][-1])
                tex_report_on = int(([item for item in control_settings if 'tex_report_on' in item])[-1][-1])
                status_flag_to_skip_design_sizing = \
                    int(([item for item in control_settings if 'status_flag_to_skip_design_sizing' in item])[-1][-1])

                # check if the current loop is the last or if the generation of plots and reports should be performed
                if not status_flag_to_skip_design_sizing == 1:

                    if flag_trim_successful == 1:
                        log_file_list.append('')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': ---')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':  '
                                             'Result of the trim:')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':  '
                                             'Angle of incidence Tailplane: ' + str(i_stab[-1]) + ' deg')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':  '
                                             'CM at optimal Cruise-CL: ' + str(cm_cruise[-1]))
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': ---')
                        log_file_list.append('')

                    # check if at least on report should be generated
                    if plot_output_on == 1 or report_output_on == 1 or tex_report_on == 1:
                        status_flag_to_skip = activate_plots_and_reports_for_sizing_loop(paths_and_names,
                                                                                         control_settings,
                                                                                         parameter_for_design_case,
                                                                                         module_list_of_sizing_loop)

                        # check if an error is occurred during plot activation
                        #  -> if true: -> send trigger signal to close loop
                        if status_flag_to_skip:
                            # set trigger signal to close mission study loop
                            design_sizing_iteration_flag = design_sizing_iteration_flag
                        else:
                            design_sizing_iteration_flag += 100.0
                            ([item for item in control_settings
                              if 'status_flag_to_skip_design_sizing' in item])[-1][-1] = int(1)
                            ([item for item in parameter_for_design_case
                              if 'number_of_max_iteration' in item])[-1][-1] = number_of_max_iteration + 1

                    # else condition: plot and report generation disabled -> generate finale aircraft exchange file
                    else:
                        name_of_current_aircraft_exchange_file = \
                            current_workflow_name \
                            + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' \
                            + file_name + '_it' + str(count_of_iteration) + '.xml'
                        shutil.copy(path_of_working_directory_rce + name_of_current_aircraft_exchange_file,
                                    path_of_working_directory_rce + current_workflow_name
                                    + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/'
                                    + file_name + '_finalLoop.xml')

        # else condition: convergence of each iteration variable is not reached
        #  -> add +100 to output flag of converge module and perform mtom damping if selected
        else:
            # check if workflowExecutionError.dat exist in the UNICADOworkflow directory
            #  -> if true: -> any tool has sent a tool execution error -> terminate design sizing loop
            if os.path.isfile(path_of_working_directory_rce + 'UNICADOworkflow/temp/workflowExecutionError.dat'):
                # print error message on the workflow console and save the message to workflow log file
                log_file_list.append('')
                log_file_list.append('------------------------------ Current loop of iteration: '
                                     + str(count_of_iteration) + ' ---------')
                log_file_list.append('')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'Error in design tool execution!')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'At least one of the enabled design tools has send an error. '
                                     'The actual design loop is failed and will be canceled!')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'If parameter study or optimization is selected, '
                                     'current loop of iteration will skipped and the next iteration will be performed!')

            elif not valid_data:
                # generate convergence error flag
                if not os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/temp/'):
                    os.mkdir(path_of_working_directory_rce + current_workflow_name + '/temp/')

                convergence_error_dat = open(path_of_working_directory_rce + current_workflow_name
                                             + '/temp/convergenceError.dat', 'a+')
                convergence_error_dat.close()

                # print error message on the workflow console and save the message to workflow log file
                log_file_list.append('')
                log_file_list.append('------------------------------ Current loop of iteration: '
                                     + str(count_of_iteration) + ' ---------')
                log_file_list.append('')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': Warning!')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'Maximum number of iterations reached, but no convergence achieved!')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'Please check the maximum number of iterations and the '
                                     'convergence criterion in the UNICADOworkflow configuration file!')

            else:
                design_sizing_iteration_flag += 100.0
                ''' damp mtom iteration value if mode is selected in configuration file '''
                if count_of_iteration > 1 and damp_mtom_iteration == 1 and valid_data:
                    # call function to damp mtom value for the next loop
                    mtom_loop_vector[-1] = damp_iteration(paths_and_names, mtom_loop_vector, 'MTOM')
                    ([item for item in design_variables if 'm_take_off_max' in item])[-1][-1] = mtom_loop_vector[-1]

        ''' write log-file to system '''
        log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
        # loop across all elements of log-file list to print to workflow console and write to workflow log-file
        for row in log_file_list:
            # print current log-file list entry to workflow console
            print(row[character_length_of_date_and_time:])

            # write current entry of log-file list to workflow log-file
            log_file.write(row + '\n')
        log_file.close()

    # else condition -> the final plot and report generation loop was performed
    else:
        design_sizing_iteration_flag = design_sizing_iteration_flag

    return parameter_for_design_case, design_variables, calibration_settings, control_settings, mtom_loop_vector, \
        calibration_factors, trim_parameter_list, i_stab, cm_cruise, design_sizing_iteration_flag
