def trim_function(paths_and_names, parameter_for_design_case, accuracy_list, trim_parameter_list, i_stab, cm_cruise,
                  count_for_trimming):
    """ trim_function calculates the angle of incidence and moment coefficient of cruise flight.
        Attention: Automatically trimming must be selected otherwise trimming will skipped.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The input list of lists "accuracy_list" contains the following values:
            * [0][0] string: 'accuracy_low',    [0][1] float: 'value of low accuracy condition'
            * [1][0] string: 'accuracy_medium', [1][1] float: 'value of medium accuracy condition'
            * [2][0] string: 'accuracy_high',   [2][1] float: 'value of high accuracy condition'

        The input list of lists "trim_parameter_list" contains the following values:
            * [0][0] string: 'i_stab',                          [0][1] array: 'array of values of angle of incidence of horizontal stabilizer'
            * [1][0] string: 'i_stab_tmp',                      [1][1] float: 'value of temporary angle of incidence of horizontal stabilizer'
            * [2][0] string: 'i_stab_last',                     [2][1] float: 'value of last angle of incidence of horizontal stabilizer'
            * [3][0] string: 'cm_cruise',                       [3][1] array: 'array of values of moment coefficient of cruise flight'
            * [4][0] string: 'cm_cruise_current',               [4][1] float: 'value of temporary moment coefficient of cruise flight'
            * [5][0] string: 'cm_cruise_last',                  [5][1] float: 'value of last moment coefficient of cruise flight'
            * [6][0] string: 'flag_trim_successful',            [6][1] int:   'value to signalize that trim is successful'
            * [7][0] string: 'retries',                         [7][1] int:   'value to count the retries of trim function'
            * [8][0] String: 'trim_accuracy'                    [8][1] float: 'value of trim accuracy if the ohn convergence criterion should be used'
            * [9][0] String: 'use_own_convergence_criterion'    [9][1] int:   'flag to use own convergence criterion for the trim accuracy'

        The input list "i_stab" contains the following values:
            * [count_of_iteration] float: 'values of angle of incidence of horizontal stabilizer'

        The input list "cm_cruise" contains the following values:
            * [count_of_iteration] float: 'values of moment coefficient of cruise flight'

        The output list of lists "trim_parameter_list" contains the following values:
            * [0][0] string: 'i_stab',                          [0][1] array: 'array of values of angle of incidence of horizontal stabilizer'
            * [1][0] string: 'i_stab_tmp',                      [1][1] float: 'value of temporary angle of incidence of horizontal stabilizer'
            * [2][0] string: 'i_stab_last',                     [2][1] float: 'value of last angle of incidence of horizontal stabilizer'
            * [3][0] string: 'cm_cruise',                       [3][1] array: 'array of values of moment coefficient of cruise flight'
            * [4][0] string: 'cm_cruise_current',               [4][1] float: 'value of temporary moment coefficient of cruise flight'
            * [5][0] string: 'cm_cruise_last',                  [5][1] float: 'value of last moment coefficient of cruise flight'
            * [6][0] string: 'flag_trim_successful',            [6][1] int:   'value to signalize that trim is successful'
            * [7][0] string: 'retries',                         [7][1] int:   'value to count the retries of trim function'
            * [8][0] String: 'trim_accuracy'                    [8][1] float: 'value of trim accuracy if the ohn convergence criterion should be used'
            * [9][0] String: 'use_own_convergence_criterion'    [9][1] int:   'flag to use own convergence criterion for the trim accuracy'

        The output list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The output list "i_stab" contains the following values:
            * [count_of_iteration] float: 'value of angle of incidence of horizontal stabilizer'

        The output list "cm_cruise" contains the following values:
            * [count_of_iteration] float: 'value of moment coefficient of cruise flight'

        :param: paths_and_names: input list of lists
        :param: parameter_for_design_case: input list of lists
        :param: accuracy_list: input list of lists
        :param: trim_parameter_list: list of lists
        :param: i_stab: input list
        :param: cm_cruise: input list
        :param: count_for_trimming: input integer
        :return: trim_parameter_list: output list of lists, parameter_for_design_case: output list of lists, i_stab: output list, cm_cruise: output: list
    """

    ''' import for python '''
    import math
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    automatic_trim = int(([item for item in parameter_for_design_case if 'automatic_trim' in item])[-1][-1])

    accuracy_low = ([item for item in accuracy_list if 'accuracy_low' in item])[-1][-1]
    accuracy_medium = ([item for item in accuracy_list if 'accuracy_medium' in item])[-1][-1]

    i_stab_last = ([item for item in trim_parameter_list if 'i_stab_last' in item])[-1][-1]
    cm_cruise_last = ([item for item in trim_parameter_list if 'cm_cruise_last' in item])[-1][-1]
    flag_trim_successful = ([item for item in trim_parameter_list if 'flag_trim_successful' in item])[-1][-1]
    retries = ([item for item in trim_parameter_list if 'retries' in item])[-1][-1]
    trim_accuracy = ([item for item in trim_parameter_list if 'trim_accuracy' in item])[-1][-1]
    use_own_convergence_criterion = ([item for item in trim_parameter_list if 'use_own_convergence_criterion' in item])[-1][-1]

    ''' initialize local parameter '''
    # date_time_counter is the number of characters of date and time print of workflow logfile
    #  -> should not be printed in the workflow console
    character_length_of_date_and_time = 21
    log_file_list = []
    function_name = getframeinfo(currentframe()).function

    ''' open and read aircraft exchange file '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name, frame_info.lineno,
                                                             log_file_list, current_workflow_name)

    ''' check if automatic trim is enabled and the use own convergence criterion is set to true 
     -> if true: -> overwrite local accuracy_low requirement by user input value '''
    if automatic_trim == 1 and use_own_convergence_criterion == 1:
        accuracy_low = trim_accuracy

    ''' check if auto trim is disabled in workflow configuration 
    file or the current cm is lower than the given accuracy requirement '''
    cm_cruise.append(float(root_of_aircraft_exchange_tree.find(
        "./Aerodynamics/MomentCoefficients/C_M_total").text))

    # if condition one or condition two is true
    #  -> check if the trim successful flag has to set to 1 to skip auto trim function
    if automatic_trim == 0 or abs(cm_cruise[-1]) <= accuracy_low:
        if abs(cm_cruise[-1]) <= accuracy_low:
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': * '
                                 'Trim successful (current CM =' + str(cm_cruise[-1]) + ')!')

        flag_trim_successful = 1

    # Else condition: no condition is true -> check if the trim successful flag is set to 1
    #  -> if true: -> after successful trimming, again deviation in the CM -> restart auto trim function
    else:
        if flag_trim_successful == 1:
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                 'WARNING: After successful trimming, again deviation in the CM (current CM ='
                                 + str(cm_cruise[-1]) + ')!')
            flag_trim_successful = 0

    cm_cruise_current = cm_cruise[-1]
    i_stab_tmp = float(root_of_aircraft_exchange_tree.find(
        '*/LiftingSurface[@ID="Stabiliser"]/SurfaceParameters/i_Surface').text)

    ''' calculate trim parameter if automatic trim is active '''
    if flag_trim_successful == 0:
        # set current cruise CM for output file
        if count_for_trimming == 1:
            i_stab = []

        if count_for_trimming == 2:
            trim_adjustment_tmp = float(0.0)
            cm_cruise_last = cm_cruise_current
            # set trim adjustment value according to RWTH-Aachen convergenceLoop
            if abs(cm_cruise_current) < accuracy_low:
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
                                     + ': * Trim: CM already in 1st run smaller than limit value 0.0001.')

            elif (abs(cm_cruise_current) <= 0.001) and (abs(cm_cruise_current) > 0.0001):
                trim_adjustment_tmp = round(float(0.1), 1)

            elif (abs(cm_cruise_current) <= 0.01) and (abs(cm_cruise_current) > 0.001):
                trim_adjustment_tmp = round(float(0.5), 1)

            elif (abs(cm_cruise_current) <= 0.1) and (abs(cm_cruise_current) > 0.01):
                trim_adjustment_tmp = round(float(1.0), 1)

            else:
                trim_adjustment_tmp = round(float(2.0), 1)

            if cm_cruise_current > 0:
                i_stab_tmp += trim_adjustment_tmp
            else:
                i_stab_tmp -= trim_adjustment_tmp

        if count_for_trimming > 2:
            if abs(cm_cruise_current - cm_cruise_last) <= accuracy_medium:
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                     'ERROR during Trim: Change of moment coefficient too small at CM = '
                                     + str(cm_cruise_current))
                if abs(cm_cruise_current) <= 0.001:
                    if retries <= 2:
                        retries += 1
                    else:
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                             'Finish trim with CM = ' + str(cm_cruise_current) + '.')
                        flag_trim_successful = 1
                else:
                    if retries <= 4:
                        retries += 1
                        i_stab_tmp *= 0.001
                    else:
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                             'Trim not successful. Finish trim with CM = '
                                             + str(cm_cruise_current) + '.')
                        flag_trim_successful = 1
            else:
                x_rel = float((0 - cm_cruise_last) / (cm_cruise_current - cm_cruise_last))
                i_stab_tmp = (1 - x_rel) * i_stab_last + x_rel * i_stab[-1]

                # Handling regarding high i_Tailplane values (not quite clear how this is created)
                if abs(cm_cruise_last) < 0.01 and abs(i_stab_tmp - i_stab_last) > 2:
                    i_stab_tmp *= 1.05
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                         'WARNING: Change of the i_Tailplane = ' + str(i_stab_tmp) +
                                         ' too big at trim regarding last value (i_Tailplane_last = '
                                         + str(i_stab_last) + ').')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                         'WARNING: Use new value i_Tailplane = ' + str(i_stab_tmp)
                                         + ' (Amount increased by 5%).')

                # set the penultimate value
                if abs(cm_cruise_current) > abs(cm_cruise[-1]):
                    cm_cruise_last = cm_cruise[-1]
                    i_stab_last = i_stab[-2]
                else:
                    cm_cruise_last = cm_cruise_current
                    i_stab_last = i_stab[-1]

        check_nan = math.isnan(i_stab_tmp)
        if not check_nan:
            i_stab.append(i_stab_tmp)
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': * Trim: CM (current) = '
                                 + str(cm_cruise[-1]) + ' | i_Tailplane (new) = ' + str(i_stab_tmp))
            root_of_aircraft_exchange_tree.find(
                '*/LiftingSurface[@ID="Stabiliser"]/SurfaceParameters/i_Surface').text = str(i_stab_tmp)
            # write settings to configuration xml file
            xml_tree.write(path, encoding='utf-8')
        else:
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                                 'Angle of incidence for tailplane is NaN. Automatic trim aborted!')
            automatic_trim = 0

    ''' set current trim parameter to trim parameter list '''
    ([item for item in trim_parameter_list if 'i_stab_tmp' in item])[-1][-1] = round(i_stab_tmp, 4)
    ([item for item in trim_parameter_list if 'i_stab_last' in item])[-1][-1] = i_stab_last
    ([item for item in trim_parameter_list if 'cm_cruise_current' in item])[-1][-1] = round(cm_cruise_current, 5)
    ([item for item in trim_parameter_list if 'cm_cruise_last' in item])[-1][-1] = cm_cruise_last
    ([item for item in trim_parameter_list if 'flag_trim_successful' in item])[-1][-1] = int(flag_trim_successful)
    ([item for item in trim_parameter_list if 'retries' in item])[-1][-1] = retries

    ''' set current value of automatic_trim to list parameter_for_design_case '''
    ([item for item in parameter_for_design_case if 'automatic_trim' in item])[-1][-1] = int(automatic_trim)

    ''' write log-file to system '''
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    # loop across all elements of log-file list to print to workflow console and write to workflow log-file
    for row in log_file_list:
        # print current log-file list entry to workflow console
        print(row[character_length_of_date_and_time:])

        # write current entry of log-file list to workflow log-file
        log_file.write(row + '\n')
    log_file.close()

    return trim_parameter_list, parameter_for_design_case, i_stab, cm_cruise
