def activate_plots_and_reports_for_mission_study(paths_and_names, control_settings, count_of_mission_study_loop):
    """ activate_plots_and_reports_for_mission_study sets switches in configuration files to activate plot- and report generation of mission study loop.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The input integer "count_of_mission_study_loop" contains the following values:
            * int: 'value of temporary count of iteration of mission study loop'

        :param: paths_and_names: input list of lists
        :param: control_settings: input list of lists
        :param: count_of_mission_study_loop: integer
        :return: none
    """

    ''' imports for python '''
    import os
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory = ([item for item in paths_and_names if 'path_of_working_directory' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    write_info_files = ([item for item in control_settings if 'write_info_files' in item])[-1][-1]
    write_info_files_only_at_last_step_of_iteration = \
        ([item for item in control_settings if 'write_info_files_only_at_last_step_of_iteration' in item])[-1][-1]
    plot_output_on = int(([item for item in control_settings if 'plot_output_on' in item])[-1][-1])
    report_output_on = int(([item for item in control_settings if 'report_output_on' in item])[-1][-1])
    tex_report_on = int(([item for item in control_settings if 'tex_report_on' in item])[-1][-1])

    ''' initialize local parameter '''
    # date_time_counter is the number of characters of date and time print of workflow logfile
    #  -> should not be printed in the workflow console
    character_length_of_date_and_time = 21
    status_flag_to_skip = False
    function_name = getframeinfo(currentframe()).function

    ''' create list for log-file string '''
    if not os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/workflowExecutionError.dat'):
        ''' create list for log-file string '''
        log_file_list = ['********************* End of mission study iteration: Convergence reached after '
                         + str(count_of_mission_study_loop) + ' iterations! **********************',
                         '',
                         '*********************************** activate plots and reports for mission study '
                         '***********************************']
    else:
        log_file_list = ['',
                         '*************************** Convergence could not be reached due to a design tool error! '
                         '***************************',
                         '',
                         '*********************************** activate plots and reports for mission study '
                         '***********************************']

    ''' restore aircraft-exchange-file of last loop '''
    file_name = aircraft_exchange_file[:len(aircraft_exchange_file) - 4]

    ''' save final aircraft exchange file of mission analysis loop to results '''
    name_of_current_aircraft_exchange_file = current_workflow_name \
        + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfStudyLoop/' + file_name + '_it' \
        + str(count_of_mission_study_loop) + '.xml'
    destination = current_workflow_name + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' \
        + file_name + '_final_study_loop_file.xml'
    shutil.copy(path_of_working_directory_rce + name_of_current_aircraft_exchange_file,
                path_of_working_directory_rce + destination)

    # Check if the tool execution error flag is not existing and plot or report generation is not disabled
    #  -> if true: -> prepare module configuration files to generate plots and reports by restoring
    #   the pre last mission study aircraft exchange file
    if not os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/workflowExecutionError.dat') \
            and (plot_output_on == 1 or report_output_on == 1 or tex_report_on == 1):
        count = count_of_mission_study_loop - 1
        if count < 0:
            count = 0
        name_of_current_aircraft_exchange_file = current_workflow_name \
            + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfStudyLoop/' + file_name + '_it' \
            + str(count) + '.xml'
        destination = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
            + aircraft_exchange_file
        shutil.copy(path_of_working_directory_rce + name_of_current_aircraft_exchange_file, destination)
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Aircraft exchange file for output generation restored!')

        ''' create list of files in working directory '''
        files_in_working_directory = os.listdir(path_of_working_directory)
        # loop for all elements in list of files
        for file_name in files_in_working_directory:
            if (file_name == 'mission_analysis') or (file_name == 'systems_design') or (file_name == 'create_mission_xml'):
                frame_info = getframeinfo(currentframe())
                path = path_of_working_directory_rce + current_workflow_name + '/' + file_name + '_conf.xml'
                file_name_tree_root, xml_tree = read_xml_file(path, path_of_working_directory_rce, file_name,
                                                              function_name, frame_info.lineno, log_file_list,
                                                              current_workflow_name)

                # enable plot and/or report generation for mission study if selected in workflow configuration file
                if plot_output_on == 1:
                    file_name_tree_root.find('./ControlSettings/PlotOutputOn').text = str(int(1))
                if report_output_on == 1:
                    file_name_tree_root.find('./ControlSettings/ReportOutputOn').text = str(int(1))
                if tex_report_on == 1:
                    file_name_tree_root.find('./ControlSettings/TexReportOn').text = str(int(1))

                if write_info_files_only_at_last_step_of_iteration == 1 and write_info_files == 1:
                    file_name_tree_root.find('./ControlSettings/WriteInfoFiles').text = str(1)
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                         'Switch of WriteInfoFile only for last loop of study mission in ' + file_name
                                         + '_conf.xml successfully set to active!')

                # write settings to configuration xml file
                xml_tree.write(path, encoding='utf-8')

        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'All switches set to generate plots and reports!')

        # delete temporary mission study flag
        if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/perform_mission_study.dat'):
            os.remove(path_of_working_directory_rce + current_workflow_name + '/temp/perform_mission_study.dat')

    else:
        status_flag_to_skip = True
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Plots and reports of mission study loop were not generated!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Error in study tool execution or generate plots or reports is disabled in '
                             'workflow configuration file.')

    ''' write log-file to system '''
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    # check if error in tool execution has occurred
    #  -> if true: initialize loop counter with zero to skip the first four entries of log-file list
    #   to print to workflow console
    if status_flag_to_skip:
        i = 0
    # Else condition: no error in tool execution has occurred -> skip only the first three lines of log-file list
    else:
        i = 1

    # loop across all elements of log-file list to print to workflow console and write to workflow log-file
    for row in log_file_list:
        # check if the actual loop counter is greater than 3
        #  -> if true: -> print log-file list entry to workflow console
        if i > 3:
            print(row[character_length_of_date_and_time:])

        # write current entry of log-file list to workflow log-file
        log_file.write(row + '\n')
        i += 1
    log_file.close()

    return status_flag_to_skip
