def estimate_mission_study_residuals(paths_and_names, mission_study_variables, count_of_mission_study_loop,
                                     convergence_criteria):
    """ estimate_mission_study_residuals calculates the residuals of design variables of mission study loop

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "mission_study_variables" contains the following values:
            * [0][0] string: 'm_take_off_max_study_last',       [0][1] float: 'value of maximum take of mass of last mission study loop'
            * [1][0] string: 'm_block_fuel_study_last',         [1][1] float: 'value of block fuel mass of last mission study loop'
            * [2][0] string: 'range_study_last',                [2][1] float: 'value of range of of last mission study loop'
            * [3][0] string: 'fl_initial_cruise_study_last',    [3][1] float: 'value of cruise flight level of last mission study loop'

        The input int "count_of_iteration" contains the current number of iteration loop.

        The input float "convergence_criteria" contains the convergence criteria of current iteration process.

        The output list of lists "mission_study_variables" contains the following values:
            *  [0][0] string: 'm_take_off_max_study',                    [0][1] float: 'value of maximum take off mass of current mission study loop'
            *  [1][0] string: 'm_block_fuel_study',                      [1][1] float: 'value of block fuel mass of current mission study loop'
            *  [2][0] string: 'range_study',                             [2][1] float: 'value of range of current mission study loop'
            *  [3][0] string: 'fl_initial_cruise_study',                 [3][1] float: 'value of cruise flight level of current mission study loop'
            *  [4][0] string: 'residual_m_take_off_max_study',           [4][1] float: 'value of residual of maximum take off mass of current mission study loop'
            *  [5][0] string: 'residual_m_block_fuel_study',             [5][1] float: 'value of residual of block fuel mass of current mission study loop'
            *  [6][0] string: 'residual_range_study',                    [6][1] float: 'value of residual of range of current mission study loop'
            *  [7][0] string: 'residual_fl_initial_cruise_study',        [7][1] float: 'value of residual of cruise flight level of current mission study loop'
            *  [8][0] string: 'status_m_take_off_max_study',             [8][1] bool:  'status of convergence for study take of mass'
            *  [9][0] string: 'status_m_block_fuel_study',               [9][1] bool:  'status of convergence for mass of study block fuel'
            * [10][0] string: 'status_range_study',                     [10][1] bool:  'status of convergence for mission study range'
            * [11][0] string: 'status_fl_initial_cruise_study',         [11][1] bool:  'status of convergence of initial mission study flight level'

        The output list "mtom_loop_vector" contains all estimated mtom values.

        :param: paths_and_names: input list of lists
        :param: mission_study_variables: input list of lists
        :param: count_of_mission_study_loop: input int
        :param: convergence_criteria: input float
        :return: design_variables: output list of lists
    """

    ''' import for python '''
    import os
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    m_take_off_max_study_last = \
        ([item for item in mission_study_variables if 'm_take_off_max_study_last' in item])[-1][-1]
    m_block_fuel_study_last = \
        ([item for item in mission_study_variables if 'm_block_fuel_study_last' in item])[-1][-1]
    range_study_last = \
        ([item for item in mission_study_variables if 'range_study_last' in item])[-1][-1]
    fl_initial_cruise_study_last = \
        ([item for item in mission_study_variables if 'fl_initial_cruise_study_last' in item])[-1][-1]

    ''' initialize local parameter '''
    log_file_list = ['', '------------------------------ Current loop of mission study: '
                     + str(count_of_mission_study_loop + 1) + ' ---------', '* results:']
    status_residual_range_study = False
    status_fl_initial_cruise_study = False
    status_residual_m_block_fuel_study = False
    status_residual_m_take_off_max_study = False

    function_name = getframeinfo(currentframe()).function

    ''' open and read aircraft exchange file '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name, frame_info.lineno,
                                                             log_file_list, current_workflow_name)

    # read iteration variables
    m_take_off_max_study = float(root_of_aircraft_exchange_tree.find(
        "./Performance/mission_analysis/StudyMission/TOM").text)
    m_block_fuel_study = float(root_of_aircraft_exchange_tree.find(
        "./Performance/mission_analysis/StudyMission/Missionfuel").text)
    range_study = round(float(root_of_aircraft_exchange_tree.find(
        "./Performance/mission_analysis/StudyMission/Range").text), 2)
    fl_initial_cruise_study = round(float(root_of_aircraft_exchange_tree.find(
        './Performance/mission_analysis/StudyMission/CruiseStep/FlightLevel').text), 0)

    # rel. residual m_take_off_max_study
    if m_take_off_max_study > 0:
        residual_m_take_off_max_study = round(abs(1 - m_take_off_max_study_last / m_take_off_max_study), 6)
        if residual_m_take_off_max_study < convergence_criteria:
            status_residual_m_take_off_max_study = True
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current mTOM_study: ' + str(m_take_off_max_study)
                             + '; Res. mTOM_study: ' + str(residual_m_take_off_max_study) + '; Convergence: '
                             + str(status_residual_m_take_off_max_study))
    else:
        residual_m_take_off_max_study = 1
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current mTOM_study: ' + str(m_take_off_max_study) + '; Res. mTOM_study: '
                             + str(residual_m_take_off_max_study) + '; Convergence: '
                             + str(status_residual_m_take_off_max_study))

    # rel. residual mission range
    if range_study > 0:
        residual_range_study = round(abs(1 - range_study_last / range_study), 6)
        if residual_range_study < convergence_criteria:
            status_residual_range_study = True
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current missionRange_study: ' + str(range_study) + '; Res. missionRange_study: '
                             + str(residual_range_study) + '; Convergence: ' + str(status_residual_range_study))

    else:
        residual_range_study = 1
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current missionRange_study: ' + str(range_study) + '; Res. missionRange_study: '
                             + str(residual_range_study) + '; Convergence: ' + str(status_residual_range_study))

    # rel. residual fl_initial_cruise_study
    if fl_initial_cruise_study > 0:
        residual_fl_initial_cruise_study = round(abs(1 - fl_initial_cruise_study_last / fl_initial_cruise_study), 6)
        if residual_fl_initial_cruise_study < convergence_criteria:
            status_fl_initial_cruise_study = True
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current initialCruiseFlightLevel_study: ' + str(fl_initial_cruise_study)
                             + '; Res. initialCruiseFlightLevel_study: ' + str(residual_fl_initial_cruise_study)
                             + '; Convergence: ' + str(status_fl_initial_cruise_study))
    else:
        residual_fl_initial_cruise_study = 1
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current initialCruiseFlightLevel_study: ' + str(fl_initial_cruise_study)
                             + '; Res. initialCruiseFlightLevel_study: ' + str(residual_fl_initial_cruise_study)
                             + '; Convergence: ' + str(fl_initial_cruise_study))

    # rel. residual m_block_fuel
    if m_block_fuel_study > 0:
        residual_m_block_fuel_study = round(abs(1 - m_block_fuel_study_last / m_block_fuel_study), 6)
        if residual_m_block_fuel_study < convergence_criteria:
            status_residual_m_block_fuel_study = True
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current mBlockFuel_study: ' + str(m_block_fuel_study)
                             + '; Res. mBlockFuel_study: ' + str(residual_m_block_fuel_study) + '; Convergence: '
                             + str(status_residual_m_block_fuel_study))
    else:
        residual_m_block_fuel_study = 1
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                             'Current mBlockFuel_study: ' + str(m_block_fuel_study) + '; Res. mBlockFuel_study: '
                             + str(residual_m_block_fuel_study) + '; Convergence: '
                             + str(status_residual_m_block_fuel_study))

    ''' save aircraft-exchange-file of each loop '''
    file_name = aircraft_exchange_file[:len(aircraft_exchange_file) - 4]
    file_destination = current_workflow_name \
        + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfStudyLoop/' + file_name + '_it' \
        + str(count_of_mission_study_loop + 1) + '.xml'
    shutil.copy(path, path_of_working_directory_rce + file_destination)

    log_file_list.append('')

    ''' write log-file to system '''
    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/workflowExecutionError.dat'):
        log_file_list = ['', '------------------------------ Current loop of mission study: '
                         + str(count_of_mission_study_loop + 1) + ' ---------', '',
                         str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Error in design tool execution!',
                         str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'At least one of the enabled design tools has send an error. '
                         'The actual design loop is failed and will be canceled!',
                         str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'If parameter study or optimization is selected, '
                         'current loop of iteration will skipped and the next iteration will be performed!']

    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        print(row[21:])
        log_file.write(row + '\n')
    log_file.close()

    ''' append calculated design values to list of list "design_variables" '''
    mission_study_variables.append(['m_take_off_max_study', m_take_off_max_study])
    mission_study_variables.append(['m_block_fuel_study', m_block_fuel_study])
    mission_study_variables.append(['range_study', range_study])
    mission_study_variables.append(['fl_initial_cruise_study', fl_initial_cruise_study])
    mission_study_variables.append(['residual_m_take_off_max_study', residual_m_take_off_max_study])
    mission_study_variables.append(['residual_m_block_fuel_study', residual_m_block_fuel_study])
    mission_study_variables.append(['residual_range_study', residual_range_study])
    mission_study_variables.append(['residual_fl_initial_cruise_study', residual_fl_initial_cruise_study])
    mission_study_variables.append(['status_m_take_off_max_study', status_residual_m_take_off_max_study])
    mission_study_variables.append(['status_m_block_fuel_study', status_residual_m_block_fuel_study])
    mission_study_variables.append(['status_range_study', status_residual_range_study])
    mission_study_variables.append(['status_fl_initial_cruise_study', status_fl_initial_cruise_study])

    return mission_study_variables
