def post_operation_of_mission_study_analysis(paths_and_names, mission_study_variables, control_settings,
                                             count_of_mission_study_loop, convergence_criteria,
                                             mission_study_iteration_flag):
    """ post_operation_of_mission_Study_analysis prepares mission study variables for converge component of RCE and calculates the residuals of study variables.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "mission_study_variables" contains the following values:
            * [0][0] string: 'm_take_off_max_study_last',       [0][1] float: 'value of maximum take of mass of last mission study loop'
            * [1][0] string: 'm_block_fuel_study_last',         [1][1] float: 'value of block fuel mass of last mission study loop'
            * [2][0] string: 'range_study_last',                [2][1] float: 'value of range of of last mission study loop'
            * [3][0] string: 'fl_initial_cruise_study_last',    [3][1] float: 'value of cruise flight level of last mission study loop'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The input float "convergence_criteria" contains the convergence criteria of current iteration process.

        The input float "mission_study_iteration_flag" contains the status of the mission study loop is finished or not.

        The output list of lists "mission_study_variables" contains the following values:
            *  [0][0] string: 'm_take_off_max_study',                    [0][1] float: 'value of maximum take off mass of current mission study loop'
            *  [1][0] string: 'm_block_fuel_study',                      [1][1] float: 'value of block fuel mass of current mission study loop'
            *  [2][0] string: 'range_study',                             [2][1] float: 'value of range of current mission study loop'
            *  [3][0] string: 'fl_initial_cruise_study',                 [3][1] float: 'value of cruise flight level of current mission study loop'
            *  [4][0] string: 'residual_m_take_off_max_study',           [4][1] float: 'value of residual of maximum take off mass of current mission study loop'
            *  [5][0] string: 'residual_m_block_fuel_study',             [5][1] float: 'value of residual of block fuel mass of current mission study loop'
            *  [6][0] string: 'residual_range_study',                    [6][1] float: 'value of residual of range of current mission study loop'
            *  [7][0] string: 'residual_fl_initial_cruise_study',        [7][1] float: 'value of residual of cruise flight level of current mission study loop'
            *  [8][0] string: 'status_m_take_off_max_study',             [8][1] bool:  'status of convergence for study take of mass'
            *  [9][0] string: 'status_m_block_fuel_study',               [9][1] bool:  'status of convergence for mass of study block fuel'
            * [10][0] string: 'status_range_study',                     [10][1] bool:  'status of convergence for mission study range'
            * [11][0] string: 'status_fl_initial_cruise_study',         [11][1] bool:  'status of convergence of initial mission study flight level'

       The output list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The output float "mission_study_iteration_flag" contains the status of the mission study loop is finished or not.

        :param: paths_and_names: input list of lists
        :param: mission_study_variables: input list of lists
        :param: control_settings: input list of lists
        :param: count_of_mission_study_loop: input integer
        :param: convergence_criteria: input float
        :param: mission_study_iteration_flag: input float
        :return: mission_study_variables: output list of lists, control_settings: output list of lists
    """

    ''' import for python '''
    import shutil
    from mission_study_loop.estimate_mission_study_residuals import estimate_mission_study_residuals
    from mission_study_loop.save_mission_study_results_to_file import save_mission_study_results_to_file
    from mission_study_loop.activate_plots_and_reports_for_mission_study import\
        activate_plots_and_reports_for_mission_study

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    ''' initialize local parameter '''
    status_flag_to_skip_study_mission = \
        int(([item for item in control_settings if 'status_flag_to_skip_study_mission' in item])[-1][-1])

    if status_flag_to_skip_study_mission == 0:
        ''' save iteration parameter to csv-file '''
        # call function to estimate residuals of mission study loop
        mission_study_variables = estimate_mission_study_residuals(paths_and_names, mission_study_variables,
                                                                   count_of_mission_study_loop, convergence_criteria)

        ''' estimate relative residuals of iteration variables '''
        save_mission_study_results_to_file(paths_and_names, mission_study_variables, count_of_mission_study_loop)

        ''' damp mtom value for the next loop if mtom damping is selected in workflow configuration file '''
        status_residual_m_take_off_max =\
            ([item for item in mission_study_variables if 'status_m_take_off_max_study' in item])[-1][-1]
        status_residual_m_block_fuel = \
            ([item for item in mission_study_variables if 'status_m_block_fuel_study' in item])[-1][-1]
        status_range_study = \
            ([item for item in mission_study_variables if 'status_range_study' in item])[-1][-1]
        status_fl_initial_cruise_study = \
            ([item for item in mission_study_variables if 'status_fl_initial_cruise_study' in item])[-1][-1]

        # check if convergence criteria of each iteration variable is reached
        #  -> if true: -> send converged output flag to converge module of RCE
        if status_residual_m_take_off_max and status_residual_m_block_fuel and status_range_study \
                and status_fl_initial_cruise_study:

            plot_output_on = int(([item for item in control_settings if 'plot_output_on' in item])[-1][-1])
            report_output_on = int(([item for item in control_settings if 'report_output_on' in item])[-1][-1])
            tex_report_on = int(([item for item in control_settings if 'tex_report_on' in item])[-1][-1])
            status_flag_to_skip_study_mission = \
                int(([item for item in control_settings if 'status_flag_to_skip_study_mission' in item])[-1][-1])

            # check if the current loop is the last one or if the generation of plots and reports should be performed
            if not status_flag_to_skip_study_mission == 1:
                # check if at least on report should be generated
                if plot_output_on == 1 or report_output_on == 1 or tex_report_on == 1:
                    status_flag_to_skip = activate_plots_and_reports_for_mission_study(paths_and_names,
                                                                                       control_settings,
                                                                                       count_of_mission_study_loop)

                    # check if an error is occurred during plot activation
                    #  -> if true: -> send trigger signal to close loop
                    if status_flag_to_skip:
                        # set trigger signal to close mission study loop
                        mission_study_iteration_flag = mission_study_iteration_flag
                    else:
                        # add +100 to iteration flag to prevent the converger-unit closing the loop before finishing it
                        mission_study_iteration_flag += 100.0
                        ([item for item in control_settings if 'status_flag_to_skip_study_mission' in item])[-1][-1] = \
                            int(1)

                # else condition: plot and report generation disabled -> generate finale aircraft exchange file
                else:
                    file_name = aircraft_exchange_file[:len(aircraft_exchange_file) - 4]
                    name_of_current_aircraft_exchange_file =\
                        current_workflow_name \
                        + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfStudyLoop/' \
                        + file_name + '_it' + str(count_of_mission_study_loop) + '.xml'
                    destination = current_workflow_name \
                        + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' \
                        + file_name + '_final_study_loop_file.xml'
                    shutil.copy(path_of_working_directory_rce + name_of_current_aircraft_exchange_file,
                                path_of_working_directory_rce + destination)

            # else condition: send trigger signal to close mission study loop
            else:
                # set trigger signal to close mission study loop
                mission_study_iteration_flag = mission_study_iteration_flag

        # else condition: convergence of each iteration variable is not reached
        #  -> add +100 to output flag to prevent the converger-unit closing the loop before finishing it
        else:
            mission_study_iteration_flag += 100.0

    else:
        count_of_mission_study_loop -= 1
        mission_study_iteration_flag = mission_study_iteration_flag

    return mission_study_variables, control_settings, count_of_mission_study_loop, mission_study_iteration_flag
