"""
A stand-alone module to do execute DoE (Design of Experiments)
The orginal functionalities of the algorithms of generating sample points are assisted by direct use of scipy.stats.

Author: Daigo Maruyama
Technical contact: d.maruyama@tu-braunschweig.de
"""

### standard libraries (includig numpy, scipy) ###
import numpy as np
from scipy.stats import qmc         # latest version


class _DoE:
    def __init__(self, N, bounds):
        self._N = N
        self._D = len(bounds)
        self._bounds = np.asarray(bounds)

    def __getitem__(self, i):
        return self._transform()[i]

    def _gneration(self):
        self._X = self._sampler.random(self._N)

    def _transform(self):
        return qmc.scale(self._X, self._bounds[:,0], self._bounds[:,1])

class LHS(_DoE):
    """
    Generate Latin Hypercube sampling.

    :param N: sample size
    :type N: integer
    :param bounds: bounds of the inputx
    :type bounds: list
    """
    def __init__(self, N, bounds):
        _DoE.__init__(self, N, bounds)
        self._sampler = qmc.LatinHypercube(self._D)
        self._gneration()

class _QMC(_DoE):
    def nextSampling(self, N):
        """
        Additional sample data is generated as a sequence after the current sample data. Same as the method "sampling", the output is kept to be _QMC class.
        This property is peculiar to the quasi Monte Carlo method basically in order to maintain the "low-discrepancy (uniformity)" in the whole set of sample data.
        Note: The property of reproducibility is also important in the quasi monte Carlo.

        :param N: sample size
        :type N: integer
        """
        self._N = N                 # update
        self._gneration()           # next sampling with the method .random
        return self

class QMC(_QMC):
    @classmethod
    def Halton(cls, N, bounds, scramble=False):
        """
        Generate Halton sequence as one of the quasi Monte Carlo methods.

        :param N: sample size
        :type N: integer
        :param bounds: bounds of the inputx
        :type bounds: list
        :param scramble: (see scipy docs) If True, use Owen scrambling. Otherwise no scrambling is done. Default is True.
        :type scramble: boolean
        """
        sample = cls(N, bounds)
        sample._sampler = qmc.Halton(sample._D, scramble=scramble)
        sample._gneration()
        return sample

    @classmethod
    def Sobol(cls, N, bounds, scramble=False):
        """
        Generate Sobol sequence as one of the quasi Monte Carlo methods.

        :param N: sample size
        :type N: integer
        :param bounds: bounds of the inputx
        :type bounds: list
        :param scramble: (see scipy docs) If True, use Owen scrambling. Otherwise no scrambling is done. Default is True.
        :type scramble: boolean
        """
        sample = cls(N, bounds)
        sample._sampler = qmc.Sobol(sample._D, scramble=scramble)
        sample._gneration()
        return sample


if __name__ == "__main__":
    """
    An example of generaiton of sample
    """
    N = 5                           # sample size
    bounds = [ [0, 3], [-1, 5]  ]   # bounds (a hypercube)


    ### --- LHS
    X = LHS(N, bounds)
    print("\nX by LHS=\n", X[:])


    ### --- Sobol (as QMC)
    X = QMC.Sobol(N, bounds)
    Xorg = X[:]                     # store the 1st sample dataset as ndarray

    # the 1st set
    print("\nX by Sobol (1st set)=\n", X[:])

    # the 2nd set
    Xnew = X.nextSampling(N)[:]     # store the 2nd sample dataset as ndarray
    print("\nX by Sobol (2nd set) =\n", Xnew[:])
