"""
A stand-alone module to create a surrogate model (currently only Gaussian Processes)

Author: Daigo Maruyama
Technical contact: d.maruyama@tu-braunschweig.de
"""

### standard libraries (includig numpy, scipy) ###
import numpy as np
import scipy
import scipy.optimize
from scipy.stats import norm
from scipy.special import erf
import sys

### the modules in this package ###
#import updated_optimisation_code.kernel as kernel                  # a kind of submodule of this module
import _kernel           # a kind of submodule of this module


class _GPGeneral:
    """
    A generalized Gaussiap Process, which covers arbitrary kernel functions.
    """
    def __init__(self, X, theta, regularization, kernelmodel, basisFunction):
        self._Xorg = X                                                                                 # basically not used in the algorithm (no need to stock this)
        self._N = X.shape[0]                                                                            # N: sample size, D: dimension (D is not used)
        self.theta = theta
        self.regularization = regularization
        self._kernelmodel = kernelmodel
        self._basisFunction = basisFunction
#        self._M = len(basisFunction)           # = len(w)

        # --- standersized ---
        scales = [(np.min(d), np.max(d)) for d in X.T]
        self._scales = np.array([[xmin, xmax-xmin] for xmin, xmax in scales], dtype=float)
        # --------------------
        self._X = self._standerdized(X)                                                                 # standerdized (X is scaled between 0 and 1)

        if not any(self._kernelmodel.values()):
            raise ValueError("At least one element of kernelmodel has to be True.")

#        if not (trend == "simple" or trend == "ordinary" or callable(trend)):
#            raise ValueError("Please set 'simple' or 'ordinary' or callable function with respect to the input x, for trend.")

        # - Example
        # self._???KernelInfo = _???kernel.Kernel(X, self.theta_???)
        # ...

        """
        stocked values here:

        self._X
        self._N
        self.theta
        self.regularization
        self._kernelmodel
        self._basisFunction
        """

    def _standerdized(self, Xorg):
        X = Xorg.copy()
        X -= self._scales[:, 0]
        X /= self._scales[:, 1]
        return X

    def _computeAnalytical(self, Y):
        self._Ymin = np.min(Y)                                                                          # used only for EI

        # --- only using X
        K = self._gramMatrix()                                                                          # Gram matrix
        self._luK = scipy.linalg.lu_factor(K)                                                           # DIscussion: more precise and faster (the most important part)
#        if any(self._luK[0][i,i] < 0. for i in range(self._N)):
#            print("K is not positive semi-definite.")

        # --- using Y
        # preprocessing of Y (for the trend) issue
        if self._basisFunction == (0.,):        # simple
            self.w = None
            self._Ytrend = lambda x: 0.
        else:
            Phi = np.array( [ [ v(x)[0] if callable(v) else v for v in self._basisFunction ] for x in self._Xorg ] )   # generalized (The element of basisFunction has to be callable (scalar output) or scalr value)
            try: # GLS in general
                luA = scipy.linalg.lu_factor(np.dot( Phi.T, scipy.linalg.lu_solve(self._luK, Phi)))      # usually max size 2 for the invese matrix A, which is computationally very cheap
                self.w = scipy.linalg.lu_solve(luA, np.dot( Phi.T, scipy.linalg.lu_solve(self._luK, Y))).reshape(-1)
#                self.w = scipy.linalg.lu_solve(scipy.linalg.lu_factor(np.dot( Phi.T, scipy.linalg.lu_solve(self._luK, Phi))), np.dot( Phi.T, scipy.linalg.lu_solve(self._luK, Y))).reshape(-1)      # GLS closed-form operation in one line
            except:
                print("GLS in the linear regression trend computation failed.")
                self.w = None
                self._YKY = None
                return
            self._Ytrend = lambda x: sum( [ np.dot( self.w[i], self._basisFunction[i](x) if callable(self._basisFunction[i]) else self._basisFunction[i] ) for i in range(len(self.w)) ] )    # linear regression function (trend) after learning w by the GLS in the above

        Ycentered = Y - self._Ytrend(self._X)                                                           # Ytrend using the data point set X
        self._weights = scipy.linalg.lu_solve(self._luK, Ycentered)                                     # This value corresponds to the weighted parameter in the Kriging perspective.
        self._YKY = np.dot(Ycentered.T, self._weights)                                                  # for likelihood
        """
        stocked values here:

        self.w          # a set of all the hyparameters except for theta, which has a closed-form expression wrt theta
        self._luK
        self._Ytrend
        self._weights
        self._YKY
        """

    def _positiveSemiDefinite(self):
        if any(self._luK[0][i,i] < 0. for i in range(self._N)):
#            print("K is not positive semi-definite.")
            return False
        else:
            return True

    # --- for Learning
    def _gramMatrix(self):
        NotImplementedError("Currently no need to use other kernel types.")
        # - Example -:
        # K = np.zeros((self._N, self._N), dtype=np.float64)
        # if self._kernelmodel["???"]:
        #     K = self._???KernelInfo.covariance(K)
        # ...
        # return K

    def _errorFunction(self):                                                                               # negative log of likelihood (=error function)
        if not self._positiveSemiDefinite():
            return 1e4
        else:
            lnK = np.sum( np.log( np.diag( self._luK[0] ) ) )
            E = self._YKY + lnK
            return E
    # ---

    # --- for Prediction
    def prediction(self, xpre):                                                                             # mean of the predictive distribution
        """
        Predict the output on a new input xpre.
        (More precisely to say, output the mean of the predictive distirbution when the input is xpre.)

        :param xpre: arbitrary single point of the input
        :type xpre: np.ndarray (1D)
        """
        xpre = self._standerdized(xpre)
        ypre = self._Ytrend(xpre) + np.dot( self._corrVector(xpre).T, self._weights )
        return ypre[0,0]
#        return np.squeeze(ypre)

    def uncertainty(self, xpre):                                                                            # variance (not std) of the predictive distribution
        """
        Predict the uncertainty on a new input xpre.
        (More precisely to say, output the variance of the predictive distirbution when the input is xpre.)

        :param xpre: arbitrary single point of the input
        :type xpre: np.ndarray (1D)
        """
        xpre = self._standerdized(xpre)
        k = self._corrVector(xpre)
        yvar = self._corrScalar(xpre) - np.dot( k.T, scipy.linalg.lu_solve( self._luK, k )  )
        return np.squeeze(yvar)

    def _corrVector(self, xpre):         # used for both prediction and uncertainty
        NotImplementedError("Currently no need to use other kernel types.")
        # - Example -:
        # k = np.zeros((self._N, 1), dtype=np.float64)
        # if self._kernelmodel["???"]:
        #     k = self._???KernelInfo.vectorPrediction(xpre, k)
        # ...
        # return k

    def _corrScalar(self, xpre):           # used only for uncertainty
        NotImplementedError("Currently no need to use other kernel types.")
        # - Example -:
        # k = 0.
        # if self._kernelmodel["???"]:
        #     k = self._???KernelInfo.scalarPrediction(xpre, k)
        # ...
        # return k

    def acquisitionFunction(self, x, functionName):              # re-arranged later
        """
        Compute the axquisition function that you specified for your puropose at an arbitrary single input point.

        :param x: arbitrary single point of the input
        :type x: np.ndarray (1D)
        :param functionName: specify the acquisition function from "EI", "PI", ...
        :type functionName: string
        """
        yvar = np.fmax(sys.float_info.epsilon, self.uncertainty(x))           # variance
        if functionName == "EI":
            ypre = self._Ymin - self.prediction(x)           # min - mean
            ystd = np.sqrt(yvar)                                # std
            f = ypre * (0.5 + 0.5 * erf(ypre / (ystd * np.sqrt(2.)))) + ystd / np.sqrt(2. * np.pi) * np.exp(-np.power(ypre, 2) / (2. * yvar))
        elif functionName == "PI":
            raise NotImplementedError("PI is actually on the way to compute EI, but anyway later")
        elif method == "variance":
            f = yvar
        return np.squeeze(f)
    # ---

class _GP(_GPGeneral):
    """
    A conventional Gaussiap Process, which covers conventional kernel functions.
    conventional kernel functions: kernelfunction(x, x', theta) = theta0*Gaussian(x, x', theta1) + theta2*Constant() + theta3*Linear(x, x')
    """
    def __init__(self, X, theta, regularization, kernelmodel, basisFunction):
        _GPGeneral.__init__(self, X, theta, regularization, kernelmodel, basisFunction)

        ### want to modify to make it more generic ###
        if self._kernelmodel["Gaussian"]:
            D = self._X.shape[1]
        else:
            D = 0
        if self._kernelmodel["Constant"]:
            M = 1
        else:
            M = 0
        if self._kernelmodel["Linear"]:
            N = 1
        else:
            N = 0
        if self.regularization is True:
            L = 1
        else:
            L = 0
        self.theta_Gaussian        = theta[0    :D      ]           # used for ARD
        self._theta_Constant       = theta[D    :D+M    ]
        self._theta_Linear         = theta[D+M  :D+M+N  ]
        self._theta_Regularization = theta[D+M+N:D+M+N+L]
        ##############################################
        self._GaussianKernelInfo       = _kernel.GaussianKernel(self._X, self.theta_Gaussian)
        self._ConstantKernelInfo       = _kernel.ConstantKernel(self._X, self._theta_Constant)
        self._LinearKernelInfo         = _kernel.LinearKernel(self._X, self._theta_Linear)
        if self.regularization is True:
            self._RegularizationKernelInfo = _kernel.RegularizationKernel(self._X, self._theta_Regularization)
        else:
            self._RegularizationKernelInfo = _kernel.RegularizationKernel(self._X, self.regularization)

        """
        stocked values here:

        self._X
        self._N
        self.theta
        self.regularization
        self._kernelmodel
        self._basisFunction
        self.theta_Gaussian
        self._theta_Constant
        self._theta_Linear
        self._theta_Regularization
        """

    def _computeAnalytical(self, Y):
        _GPGeneral._computeAnalytical(self, Y)
        if self._YKY is None:
            self._variance = None
        else:
            self._variance = self._YKY / float(self._N)
        """
        stocked values here:

        self._luK
        self._Ytrend
        self._weights
        self._YKY
        self._variance
        """

    # --- for Learning
    def _gramMatrix(self):
        K = np.zeros((self._N, self._N), dtype=np.float64)
        if self._kernelmodel["Gaussian"]:
            K = self._GaussianKernelInfo.covariance(K)
        if self._kernelmodel["Constant"]:
            K = self._ConstantKernelInfo.covariance(K)
        if self._kernelmodel["Linear"]:
            K = self._LinearKernelInfo.covariance(K)
        if self.regularization:
            K = self._RegularizationKernelInfo.covariance(K)
        return K

    def _errorFunction(self):      # negative log of likelihood (=error function)
        if self._variance is None:
            return 1e4
        else:
            self._variance = max(self._variance, sys.float_info.epsilon)
            lnK = np.sum( np.log( np.diag( self._luK[0] ) ) )
            E = self._N*np.log(self._variance) + lnK
            if E != E:  # NaN
               return 1e4
            else:
               return np.squeeze(E)
    # ---

    # --- for prediction
    def uncertainty(self, xpre):    # variance (not std) of the predictive distribution
        """
        Predict the uncertainty on a new input xpre.
        (More precisely to say, output the variance of the predictive distirbution when the input is xpre.)

        :param xpre: arbitrary single point of the input
        :type xpre: np.ndarray (1D)
        """
        return self._variance * _GPGeneral.uncertainty(self, xpre)

    def _corrVector(self, xpre):         # used for both prediction and uncertainty
        k = np.zeros((self._N, 1), dtype=np.float64)
        if self._kernelmodel["Gaussian"]:
            k = self._GaussianKernelInfo.vectorPrediction(xpre, k)
        if self._kernelmodel["Constant"]:
            k = self._ConstantKernelInfo.vectorPrediction(xpre, k)
        if self._kernelmodel["Linear"]:
            k = self._LinearKernelInfo.vectorPrediction(xpre, k)
#        if self.regularization:                                                   # theoretically meaningless
#            k = self._RegularizationKernelInfo.vectorPrediction(xpre, k)
        return k

    def _corrScalar(self, xpre):           # used only for uncertainty
        k = 0.
        if self._kernelmodel["Gaussian"]:
            k = self._GaussianKernelInfo.scalarPrediction(xpre, k)
        if self._kernelmodel["Constant"]:
            k = self._ConstantKernelInfo.scalarPrediction(xpre, k)
        if self._kernelmodel["Linear"]:
            k = self._LinearKernelInfo.scalarPrediction(xpre, k)
        if self.regularization:
            k = self._RegularizationKernelInfo.scalarPrediction(xpre, k)
        return k
    # ---

    # --- postprocess
    def automatic_relevance_determination(self):
        if not self._kernelmodel == {"Gaussian": True, "Constant": False, "Linear": False}:
#            raise ValueError("To be fair for the global sensitivity analysis, the kernel should be only Gaussian.")
            print("To be fair for the global sensitivity analysis, the kernel should be only Gaussian.")
            return None
        else:
            return self.theta_Gaussian
    # ---

class GP(_GP):
    """
    A class on how to define the hyperparameters (theta)
    """
    def __init__(self, X, Y, theta, regularization, kernelmodel, basisFunction):
        """
        Create a Gaussian Process regression model with specifying the values of the hyperparameter theta (usually not used by users).
        """
        _GP.__init__(self, X, theta, regularization, kernelmodel, basisFunction)
        self._computeAnalytical(Y)

    @classmethod
    def MLE(cls, X, Y, regularization=np.log10(sys.float_info.epsilon), kernelmodel={"Gaussian": True, "Constant": False, "Linear": False}, basisFunction=(0.,), multiStart=1, maxiter=1000, tol=1e-3, disp=True):
        """
        Create a Gaussian Process regression model. The hyperparameters to fix/control the model is determined by the maximum liklhood estimation (MLE).

        :param X: A set of input values
        :type X: np.ndarray(2D)
        :param Y: A set of output (function) values, copposponding to the input values. The dimensionality of each samplint has to be 1 (a scaler value).
        :type Y: np.ndarray(2D)

        :param regularization: A noise is considered or not. If it is, the model is not guaranteed to pass throgh all the data points. (More strictly to say, assume the existance of aleatory uncertainty or not. The noise is the variance with homoscedasticity in a monovariate Gaussian distribution)
        :type regularization: True or scalr (log10 scale)
        :param kernelmodel: switchin on/off each kernel function "Gaussian", "Constant", "Linear"
        :type kernelmodel: dictionary
        :param trend: Specify on which model the basic Gaussian Process regression model (whoise mean is 0) is defined.
        :type trend: String

        :param multiStart: Number of trials of the oprimization algorithm with randomness
        :type multiStart: integer
        :param maxiter: Number of iteration of the optimization
        :type maxiter: integer
        :param tol: Tolerance for the optimizaiton
        :type tol: float
        :param disp: If the iteration of the optimization is displayed or not
        :type disp: boolean
        """
        args = (X, Y, regularization, kernelmodel, basisFunction)

        bounds = []
        if kernelmodel["Gaussian"]:
            boundsTheta_Gaussian = [ [-4, 3 ] ]*X.shape[1]          # serch in log scale with base 10
#            boundsTheta_Gaussian = [ [-3, 2 ] ]*X.shape[1]
            bounds += boundsTheta_Gaussian
        if kernelmodel["Constant"]:
            boundsTheta_Linear = [ [0, 10 ] ]                       # the original scale
            bounds += boundsTheta_Linear
        if kernelmodel["Linear"]:
            boundsTheta_Linear = [ [0, 10 ] ]                       # the original scale
            bounds += boundsTheta_Linear
        if regularization is True:
            boundsReg = [ [-10, 0] ]                                # serch in log scale with base 10
            bounds += boundsReg

        fopt = 1e3      # large value
        xopt = None
        for i in range(multiStart):
            opt = scipy.optimize.differential_evolution(cls._MLEobjective, bounds=bounds, args=args, maxiter=maxiter, tol=tol, disp=disp)
            if opt.fun < fopt:                                      # update only when it is better
                fopt = opt.fun
                xopt = opt.x

#        xopt = np.array([2.])
        return cls(X, Y, xopt, regularization, kernelmodel, basisFunction)

    @classmethod
    def _MLEobjective(cls, theta, X, Y, regularization, kernelmodel, basisFunction):
        return cls(X, Y, theta, regularization, kernelmodel, basisFunction)._errorFunction()



if __name__ == "__main__":

    """
    An example of construction of a surrogate model and predictions using a test case of UNICADO
    (the dataset is red by "DoE" for X, "Missionfuel_Data" for Y)
    """

    import doe
    from matplotlib import pyplot as plt
    from mpl_toolkits.mplot3d import Axes3D     # for 3D figures

    def plotting1D(name, function, xbounds, Npre=100, sigma_ratio=1.):
        Xpre = np.linspace(xbounds[0][0], xbounds[0][1], Npre, dtype=np.float64)
        Xpre = Xpre.reshape(len(Xpre),-1)
        Ypre = np.empty(Npre)
        Yvar = np.empty(Npre)
        for j in range(Npre):
            Ypre[j] = surrogate.prediction(Xpre[j])
            Yvar[j] = surrogate.uncertainty(Xpre[j])
        YpreU = Ypre + sigma_ratio*np.sqrt(Yvar)
        YpreL = Ypre - sigma_ratio*np.sqrt(Yvar)

        Yref = function(Xpre)
        fig = plt.figure()
        plt.plot(Xpre, Yref, linestyle="dashed")
        plt.plot(Xdata, Ydata, "o", color="b")
        plt.plot(Xpre, Ypre, color="g")
        plt.fill_between(Xpre.reshape(len(Xpre)), YpreU, YpreL, facecolor='y',alpha=0.5)
#        plt.ylim(-12.5, 17.5)
        plt.savefig("1D.jpg")
        plt.close()

    def plotting2D(name, Npre=100, sigma_ratio=1):
        x1 = np.linspace(xbounds[0][0], xbounds[0][1], Npre, dtype=np.float64)
        x2 = np.linspace(xbounds[1][0], xbounds[1][1], Npre, dtype=np.float64)
        X1, X2 = np.meshgrid(x1, x2)
        Y = np.empty( (Npre, Npre), dtype=np.float64 )
        for i in range(Npre):
            for j in range(Npre):
                xpre = np.array( ( x1[i], x2[j] ), dtype=np.float64)
                Y[j,i] = surrogate.prediction(xpre)

        fig = plt.figure()
        ax1 = Axes3D(fig)
        ax1.plot_surface(X1, X2, Y, cmap = "summer", alpha = 0.5)
        ax1.scatter(Xdata[ :,0], Xdata[ :,1], Ydata    , c="k")
        fig.suptitle("theta, E = {} {}".format(surrogate.theta, surrogate._errorFunction()))
        ax1.set_zlim([5950, 6150])
        plt.savefig("2D,jpg")
        plt.close()



    def highFidelityFunction(x):
        y = np.power( (6.*x-2.), 2 ) * np.sin(12.*x-4.)
        return np.squeeze(y)

    def lowFidelityFunction(x, A=0.5, B=10., C=-5.):
        y = A*highFidelityFunction(x) + B*(x-0.5) + C
        return np.squeeze(y)


    # --- process
    function = highFidelityFunction
    xbounds = [ [0., 1.] ]

    N = 4
#    X = doe.QMC.Sobol(N, xbounds)
#    Xdata = X[:]

    Xdata = np.array( [0, 0.4, 0.6, 1.] ).reshape(-1, 1)
    Ydata = function(Xdata).reshape(-1, 1)
    print("Xdata =", Xdata)
    print("Ydata =", Ydata)
#    exit(1)

    # regularization true or log scale value
    # to make the computation (of the inverse of the covariance matrix) stable, a small amount of value is intentionally added. If it is still not stable, please increase the value (e.g. regularization = -10.) or "regularization=True"
    regularization = True#np.log10(sys.float_info.epsilon)#=-16  # all lthe hyperparameters including regularization are in log scale in the operation in the code.
#    regularization = True

    """ example of design of basisFunction ###
    basisFunction = (1., NN)
    basisFunction = (1., lambda x: x, lambda x: np.power(x,2), lambda x: np.power(x,3))         # polynomial functions for 1D input x
    """
    trendset = "manual"
    ### useful package for user ###
    if trendset == "simple":
        basisFunction = (0.,)
    elif trendset == "ordinary":
        basisFunction = (1.,)
    elif trendset == "NN":
        basisFunction = (lowFidelityFunction,)
    elif trendset == "manual":
        basisFunction = (1, lowFidelityFunction)
    ###############################

    multiStart = 5
    surrogate = GP.MLE(Xdata, Ydata, regularization, basisFunction=basisFunction, multiStart=multiStart)

    print("surrogate.theta =", surrogate.theta)
    print("surrogate.w =", surrogate.w)
    print("surrogate.regularization =", surrogate.regularization)
    print("surrogate._errorFunction =", surrogate._errorFunction())
    plotting1D("{}".format(str(function)), function, xbounds, sigma_ratio=1.)
