"""
This module is a kind of API, which is directly called from main.py

Surrogate-based optimization (Bayesian optimization) itself is an application of fundamental methods distributed in other modules.
Therefore, this module is a bit more hard-codded than the stand-alone modules.

Author: Daigo Maruyama
Technical contact: d.maruyama@tu-braunschweig.de
"""

### standard libraries (includig numpy, scipy) ###
import numpy as np
import scipy.optimize
from scipy.optimize import NonlinearConstraint#, Bounds
import concurrent.futures                    # for running in parallel
from matplotlib import pyplot as plt         # for visualization
from mpl_toolkits.mplot3d import Axes3D      # for 3D visualization
import functools                             # used only for ordinary optimization
import sys

### the modules in this package ###
import gaussianProcess, doe                  # stand-alone modules in the package


class Formulation:
    def __init__(self, functions, xbounds, gbounds=[]):
        """
        Fix required information "in the generalized formulation":
         - the functions f(x), g(x)                         : functions
         - the search domain of the input x                 : xbounds
         - the ranges of the constraint output ranges g(x)  : gbounds

        :param functions: simulation function which outputs the function evaluation (f and multiple g)
        :type functions: callable
        :param xbounds: bounds of search in design variables in global optimization
        :type xbounds: list
        :param gbounds: bounds to define constraints on the constraints functions
        :type gbounds: list
        """
        self._functions = functions
        self._xbounds = xbounds
        self._gbounds = gbounds
#        self._D = len(xbounds)                                                         # number of design variables, not used (maybe used when doe.py code is changed.)
        self._M = len(gbounds)                                                          # number of constraints

    def runSingle(self, x):
        """
        Run the functions defined in the userinput module.

        :param x: design variables
        :type x: np.ndarray (1D)
        """
        return self._functions(x)

    def runParallel(self, X, proc):
        """
        Run the functions defined in the userinput module, with parallelization specified by proc number.

        :param X: The set of design variables
        :type X: np.ndarray (2D)
        :param proc: Number of Processors used
        :type proc: integer greater than 0
        """
        N = X.shape[0]                                                                                              # sample size
        Y = []
        Del_x = []  #--- To store the index of Failed Data samples ---
        with concurrent.futures.ThreadPoolExecutor(max_workers=proc) as Executor:                                   ### be aware of Thread-Safe ###
            for i, (y, status) in zip(range(N), Executor.map(self.runSingle, X)):
                if status == 'Success':
                    Y.append(y)
                else:
                    print('Failed point is omitted')
                    Del_x.append(i)
        return np.array(Y), Del_x

    def _optimization(self, func, constraints, args=(), multiStart=1, maxiter=1000, tol=1e-3, disp=True):         # Note: intentionally hard-coded only when the search space is in the domain of the design variables X
        fopt = 1e3
        xopt = None
        for i in range(multiStart):
            opt = scipy.optimize.differential_evolution(func, bounds=self._xbounds, constraints=constraints, args=args, maxiter=maxiter, tol=tol, disp=disp)
            if opt.fun < fopt:   # update only when it is better
                fopt = opt.fun
                xopt = opt.x
        return xopt, fopt

    def ordinary(self, multiStart=1, maxiter=1000, tol=1e-3, disp=True):
        """
        Conduct optimization with direct evaluation of the cost function at each iteration of the optimization process (named ordinary optimization here).

        :param multiStart: Number of trials of the oprimization algorithm with randomness
        :type multiStart: integer
        :param maxiter: Number of iteration of the optimization
        :type maxiter: integer
        :param tol: Tolerance for the optimizaiton
        :type tol: float
        :param disp: If the iteration of the optimization is displayed or not
        :type disp: boolean
        """
        output = Functions(self._functions)
        nlc = [ scipy.optimize.NonlinearConstraint( functools.partial(output.constraintFunction, i=i), self._gbounds[i][0], self._gbounds[i][1] ) for i in range(self._M) ]
        return self._optimization(output.costFunction, nlc, args=(), multiStart=multiStart, maxiter=maxiter, tol=tol, disp=disp)

    def EGO(self, N, Nimposed, proc, activeLearningMethod="EI", regularization=np.log10(sys.float_info.epsilon), basisFunction=(0.,), multiStart=5, doeMethod="Sobol", kernelmodel={"Gaussian": True, "Constant": False, "Linear": False}, maxiter=1000, tol=1e-3, disp=True):
        """
        Conduct EGO: Efficient Global Optimization (by Bayesian optimization with approximation of the cost function by using surrogate models).

        :param N: Samle size. Or if it is 0, read a (X, Y) data file (this approach will be modified to be more userfriendly)
        :type N: integer
        :param Nimposed: Additional sample size derived by the aquisition function
        :type Nimposed: integer

        :param doeMethod: Method of DoE (Design of Experiments)
        :type doeMethod: string

        :param regularization: Whether the regurlarization kernel is considered or not in all the surrogate model construction processes here
        :type regularization: boolean
        :param kernelmodel:
        :type kernelmodel:
        :param activeLearningMethod: The type of the acquisition function
        :type activeLearningMethod: string

        :param gradientOptSurrogate: method of tuning the hyperparameter of the surrogate models, True: differential evolution, False: BFGS
        :type gradientOptSurrogate: boolean
        :param multiStart: Number of trials of the oprimization algorithm with randomness
        :type multiStart: integer
        :param maxiter: Number of iteration of the optimization
        :type maxiter: integer
        :param tol: Tolerance for the optimizaiton
        :type tol: float
        :param disp: If the iteration of the optimization is displayed or not
        :type disp: boolean
        """
        self._regularization = regularization
        self._basisFunction = basisFunction
        self._doeMethod = doeMethod
        self._kernelmodel = kernelmodel
        self._multiStart = multiStart
        self._trend = 0.

        # temporary for my graph
        self._N = N
        self._Nimposed = Nimposed
        self._activeLearningMethod = activeLearningMethod
        #

        # 1. --- DoE ---
        self._dataGeneration(N, proc)                                                                                                                                   # self._X, self._Y are created.

        # 2. --- surrogate construction ---
        self._surrogateConstruction()                                                                                                                                   # self.surrogate, which is a list (many surrogate models inside), is created.

        # 3. --- surrogate update - update self.surrogate --- (Bayesian Optimization)
        self._surrogateUpdate(Nimposed, activeLearningMethod)                                                                                                                         # self.surrogate is updated.

        # 4. --- optimization on the surrogates ---                                                                                                                                       # find the optimal solution on the surrogate models
        args = ()
        nlc = [ NonlinearConstraint(_ConstraintsSurrogate(self.surrogate[1+i]).predict, self._gbounds[i][0], self._gbounds[i][1]) for i in range(self._M) ]            # constraints (TLARs in the UNICADO case)
        multiStart = 1                                                                                                                                                  # only 1 trial on the surrogate models
        while True:
            self.xopt, self.yopt_tilda = self._optimization(self.surrogate[0].prediction, nlc, args, multiStart, maxiter, tol, disp)
            yopt = self.runSingle(self.xopt)      # overwrite f on f_tilda
            if yopt[1] == 'Success':
                self.yopt = yopt[0]
                break
        return self.xopt, self.yopt


    def _dataGeneration(self, N, DoEmethod="Sobol", proc=1):
        if N is False:                                                                                                                                                  # will be replaced by more intuitive way.
            """
            read data files of X, Y
            """
            self._X = np.loadtxt("DoE")
            self._Y = np.loadtxt("Missionfuel_Data").reshape(-1, 1)
            self._N = self._Y.shape[0]


        else:
            if N == 4:
                self._X = np.array( [0., 0.4, 0.6, 1.] ).reshape(-1, 1)
            else:
                if self._doeMethod == "Sobol":
                    X = doe.QMC.Sobol(N, self._xbounds)
                elif self._doeMethod == "Halton":
                    X = doe.QMC.Halton(N, self._xbounds)
                elif self._doeMethod == "LHS":
                    X = doe.LHS(N, self._xbounds)
                self._X = X[:]
            print("self._X =", self._X)
            self._Y, delX = self.runParallel(self._X, proc)                                                                                                             # run the simulation in parallel
            self._N = self._Y.shape[0]                                                                                                                                  # the sample size is adjusted to the simulation results with success

            if len(delX) > 0:
                print("Several simulations failed due to violations of some values of the design variables.")
                for i in range(len(delX)):
                    print("The simulation at the design variable:\n{}\nfailed.".format(self._X))
                self._X = np.array([i for j, i in enumerate(self._X) if j not in delX])                                                                                 # Writing the DoE sample file again with the valid samples

            if self._N < 2:
                print("The actual sample size is too small. Please use a greater number for the original sample size N")
                exit(1)

        self._Xorg = self._X.copy()
        self._Yorg = self._Y.copy()

        print("self._Y =", self._Y)
        print(type(self._Y))

    def _surrogateConstruction(self):
#        if S == 1:
#        self.surrogate = [ gaussianProcess.GP.MLE(self._X, self._Y.T[i].reshape(-1,1), self._regularization, self._kernelmodel, self._trend, self._gradientOptSurrogate, self._multiStart) for i in range (1+self._M) ]
        self.surrogate = [ gaussianProcess.GP.MLE(self._X, self._Y.T[i].reshape(-1,1), self._regularization, self._kernelmodel) for i in range (1+self._M) ]

        """
        else:
            Ydata = []
            for i in range(1+self._M):
                Ydata.append([])
                Ydata[i].extend( [ Y[j].T[i] for j in range(self._S) ] )
            self.surrogate = [ gaussianProcess.MFGP(S, self._X , Ydata[i], basisFunction, BayesFunction, b, regularization, kernelmodel,
                               Xdomain=Xdomain, multiStart=multiStart,
                               trueFunctions=(lowFidelityFunction, highFidelityFunction), independent=independent, NNGP=NNGP)
                               for i in range (1+self._M) ]
        """
        self.sensitivity = [ self.surrogate[i].automatic_relevance_determination() for i in range (1+self._M) ]                                                         # just as by-product: sensitivity analysis (only when only the Gaussian kernel is used)




    def _surrogateUpdate(self, Nimposed, activeLearningMethod, maxiter=1000, tol=1e-3, disp=True):
        self._Xadp = []
        self._Yadp = []
        for i in range(Nimposed):
            if activeLearningMethod == "EI" or activeLearningMethod == "PI" or activeLearningMethod == "variance":        # use the info from only the cost function
                args = (self.surrogate[0], activeLearningMethod)
                xnew, _ = self._optimization(negAcquisitionFunction, (), args, self._multiStart, maxiter, tol, disp)
            elif activeLearningMethod == "EIPI":                                              # use the info of both the cost function and the constraints
                args = (self.surrogate, self._gbounds)
                xnew, _ = self._optimization(negComposedAcquisitionFunction, (), args, self._multiStart, maxiter, tol, disp)
            else:
                raise ValueError("Please set 'EI' or 'EIPI' or 'variance' for 'method'.")
            ynew, status = self.runSingle(xnew)
            if status != "Success":
                continue
            self._X = np.vstack((self._X, xnew))            # Data X,Y is updated.
            self._Y = np.vstack((self._Y, ynew))
            self._Xadp.append(xnew)
            self._Yadp.append(ynew)
            self._surrogateConstruction()                   # a new surrogate based on the update data
        self._Xadp = np.array(self._Xadp)
        self._Yadp = np.array(self._Yadp)

    def visualization(self, Npre):
        """
        Visualize the data, the surrogate models and the optimum solution.

        :param Npre: Number of predicted points (per one dimension)
        :type Npre: integer greater than 0
        """
        sigma_ratio = 1.#10.            # tmp parameter to visualize "sigma_ratio" times sigma (instead of one sigma)
        proc = 1                        # runnig simulation functions to make a reference (a series of this process will not be used for expensive simulations, e.g. UNICADO cases )

        D = len(self._xbounds)
        if D == 1:
            Xpre = np.linspace(self._xbounds[0][0], self._xbounds[0][1], Npre, dtype=np.float64)
            Xpre = Xpre.reshape(-1,1)
            Ypre = np.empty((1+self._M, Npre))
            Yvar = np.empty((1+self._M, Npre))

            for i in range(self._M+1):
                for j in range(Npre):
                    Ypre[i,j] = self.surrogate[i].prediction(Xpre[j])
                    Yvar[i,j] = self.surrogate[i].uncertainty(Xpre[j])

            YpreU = Ypre + sigma_ratio*np.sqrt(Yvar)
            YpreL = Ypre - sigma_ratio*np.sqrt(Yvar)

            color_dataOrg = ["b", "b"]
            color_dataAdp = ["r", "r"]
            color_pred = ["g", "c"]

            Yref = self.runParallel(Xpre, proc=proc)[0].T
            fig = plt.figure()
            for l in range(1+self._M):
                plt.plot(Xpre, Yref[i], linestyle="dashed")                                             # Reference: only when analytical function is used.
                plt.plot(self._Xorg, self._Yorg[:,l], "o", color=color_dataOrg[l])                       # data points (only original)
                if len(self._Xadp) != 0:# np.array([]):
                    plt.plot(self._Xadp, self._Yadp[:,l], "o", color=color_dataAdp[l])                   # data points (only adaptive)
                plt.plot(Xpre, Ypre[l], color=color_pred[l])                                             # surrogate models (prediction)
                plt.fill_between(Xpre.reshape(len(Xpre)), YpreU[l], YpreL[l], facecolor='y',alpha=0.5)   # surrogate models (uncertainty - one sigma)
                plt.plot(self.xopt, self.yopt[l])                                                            # the point of the optimum solution
                plt.savefig("figure_{}.jpg".format(l))
                plt.close()

        elif D == 2:
            for l in range(1+self._M):                                                                      # make a graphs for each output (one cost function + other constraint functions)
                x1 = np.linspace(self._xbounds[0][0], self._xbounds[0][1], Npre, dtype=np.float64)
                x2 = np.linspace(self._xbounds[1][0], self._xbounds[1][1], Npre, dtype=np.float64)
                X1, X2 = np.meshgrid(x1, x2)
                Y = np.empty( (Npre, Npre), dtype=np.float64 )
                if l != 0:
                    YboundsL = np.empty( (Npre, Npre), dtype=np.float64 )
                    YboundsU = np.empty( (Npre, Npre), dtype=np.float64 )
                for i in range(Npre):
                    for j in range(Npre):
                        xpre = np.array( ( x1[i], x2[j] ), dtype=np.float64)
                        Y[j,i] = self.surrogate[l].prediction(xpre)
                        if l != 0:
                            YboundsL[j,i] = self._gbounds[l-1][0]
                            YboundsU[j,i] = self._gbounds[l-1][1]

                fig = plt.figure()
                ax1 = Axes3D(fig)
                ax1.plot_surface(X1, X2, Y, cmap = "summer", alpha = 0.5)
                if l != 0:
                    if not np.isinf(self._gbounds[l-1][0]):
                        print("showing the lower bound")
                        ax1.plot_surface(X1, X2, YboundsL, cmap = "plasma_r", alpha = 0.5)
                    if not np.isinf(self._gbounds[l-1][1]):
                        print("showing the upper bound")
                        ax1.plot_surface(X1, X2, YboundsU, cmap = "plasma_r", alpha = 0.5)
                ax1.scatter(self._Xorg[ :,0], self._Xorg[ :,1], self._Yorg[:,l], c="k", s=18)                          # original sample points by DoE (black)
                if self._Xadp.size != 0:
                    ax1.scatter(self._Xadp[ :,0], self._Xadp[ :,1], self._Yadp[:,l], c="b", s=36)                      # adaptive sample points (blue)
                ax1.scatter(self.xopt[0]    , self.xopt[1]    , self.yopt[l], c="r", s=36)                             # opt point (red)
                fig.suptitle("ACq={}, xopt={}, yopt={}, gradientOptSurrogate={}, theta={}, E={}".format(self._method, self.xopt, self.yopt[l], self._gradientOptSurrogate, self.surrogate[l].theta, self.surrogate[l]._errorFunction()))
#                plt.savefig("N={}, Ni={}, method={}, xopt={}, yopt={}, gradientOptSurrogate={}, theta={}, E={}.jpg".format(self._N, self._Nimposed, self._method, self.xopt, self.yopt[l], self._gradientOptSurrogate, self.surrogate[l].theta, self.surrogate[l]._errorFunction()))
                plt.show()
                plt.close()

        else:
            raise NotImplementedError("no visalization for this dimension of the input variables")


class _ConstraintsSurrogate:
    def __init__(self, surrogate):                                                                          # surrogate: _GP class (not a list of models)
        self._surrogate = surrogate
    def predict(self, x):
        return self._surrogate.prediction(x)


class Functions:
    """
    used only for the method "ordinary" to separately treat the output values of userinput.functions
    """
    def __init__(self, functions):
        self._functions = functions
        self._last_x = None
    def compute(self, x):
        if self._last_x is None or not np.all(self._last_x==x):
            self.fg = self._functions(x)                                                                    # "Success" or "Failure" is ignored in the current version (since this class is used only for the method "ordinary").
            self._last_x = x
    def costFunction(self, x):
        self.compute(x)
        return self.fg[0][0]
    def constraintFunction(self, x, i):
        self.compute(x)
        return self.fg[0][i+1]


def negAcquisitionFunction(x, surrogate, functionName):
    """
    Return the negative value of the acquisition function computed in gaussianProcess.py

    :param x: input variables
    :type x: np.ndarray(2D)
    :param surrogate: a surrogate model instance created by the GP class in gaussianProcess.py
    :type surrogate: class GP
    :param functionName: specify the acquisition function from "EI", "PI", "variance"
    :type functionName: string
    """
    return -surrogate.acquisitionFunction(x, functionName)

def negComposedAcquisitionFunction(x, surrogates, gbounds):
    """
    Compute a composed acquisition function used for constrained optimization. For the precision of the computations for optimal solution of product of several acquisiton funcitons, the log scale is used.

    :param x: input variables
    :type x: np.ndarray(2D)
    :param surrogates: list of surrogate model instances, each of which is created by the GP class in gaussianProcess.py
    :type surrogates: list
    :param gbounds: min and max values of each of the constraint functions
    :type gbounds: list
    """
    M = len(gbounds)
    f = np.log(np.fabs(surrogates[0].acquisitionFunction(x, "EI")))
    for i in range(M):
        if gbounds[i][0] == gbounds[i][1]:
            continue
        f += np.log(np.fabs(surrogates[i+1].acquisitionFunction(x, "PI", gbounds[i][0], gbounds[i][1])))
    return -f
