def estimate_input_value_from_configuration_file(root_of_study_xml_file, input_parameter_settings,
                                                 path_to_current_study, corrected_xml_path, log_file_list):
    """ Function to set study counter dependent input parameter from given parameter study configuration file.

        The input elementTree 'root_of_study_xml_file' contains the parameter of study configuration file as element tree.

        The input list of lists "input_parameter_settings" contains ato following values:
            *  [0][0] string: 'parameter_name',                  [0][1] string: 'name of the current study input parameter'
            *  [1][0] string: 'input_directory_name',            [1][1] string: 'name of the input directory of current study parameter'
            *  [2][0] string: 'input_file_name'                  [2][1] string: 'name of the input file of the current study parameter'
            *  [3][0] string: 'path_in_xml_file'                 [3][1] string: 'path to the study parameter in the input xml-file'
            *  [4][0] string: 'read_values_from_text_file',      [4][1] int:    'switch to read iteration values from an external data file'
            *  [5][0] String: 'row_number'                       [5][1] int:    'number of row inside of the external data file where the current parameter are listed'
            *  [6][0] String: 'values_as_abs_step_size'          [6][1] int:    'switch to set parameter from external data file to absolute values'
            *  [7][0] string: 'relative_to_reference',           [7][1] int:    'switch to activate relative step sizes according to reference values'
            *  [8][0] string: 'step_size',                       [8][1] float:  'value of step size of current study parameter'
            *  [9][0] string: 'number_of_steps_up',              [9][1] int:    'value of maximum iteration steps upwards are to be performed'
            * [10][0] string: 'number_of_steps_down',           [10][1] int:    'value of maximum iteration steps downwards are to be performed'
            * [11][0] string: 'study_counter'                   [11][1] int:    'number of iteration loop of current input parameter'

        The input string 'path_to_current_study' contains the absolute path to the working directory of current parameter study.

        The input string 'corrected_xml_path' contains the corrected absolute xml-path of current input parameter.

        The input list "log_file_list" contains all system prints of function: perform_parameter_study.py.

        The output float 'new_value_of_input' contains the new value of current input parameter of current parameter study loop.

        The output bool 'xml_path_status' contains the current status "True" or "False" of current xml-path.

        The output list "log_file_list" contains all system prints of functions: perform_parameter_study.py and read_parameter_study_settings.py.

        :param: root_of_study_xml_file: input string
        :param: input_parameter_settings: input list of lists
        :param: path_to_current_study: input string
        :param: corrected_xml_path: input string
        :param: log_file_list: input list
        :return: new_value_of_input: output float, xml_path_status: output bool, log_file_list: output list
    """

    ''' imports for python '''
    import os
    from datetime import datetime

    ''' initialize local parameter '''
    current_parameter_values = str()
    file_value = 1.0
    find_flag = False
    number_of_steps_up = 0
    number_of_steps_down = 0
    number_of_runs_to_perform = 1
    relative_to_reference = 1
    relative_to_reference_csv_file = 1
    use_values_as_absolute = 0
    step_size = 0

    ''' read data for script execution '''
    parameter_name = ([item for item in input_parameter_settings if 'parameter_name' in item])[-1][-1]
    read_values_from_text_file = \
        int(([item for item in input_parameter_settings if 'read_values_from_text_file' in item])[-1][-1])
    study_counter = int(([item for item in input_parameter_settings if 'study_counter' in item])[-1][-1])

    # check if the switch of current parameter is selected to read values from csv file -> if true:
    #  -> initialize parameter to perform study from csv file
    if read_values_from_text_file == 1:
        relative_to_reference_csv_file = \
            int(([item for item in input_parameter_settings if 'relative_to_reference_csv_file' in item])[-1][-1])
        use_values_as_absolute = \
            int(([item for item in input_parameter_settings if 'use_values_as_absolute' in item])[-1][-1])

        if os.path.isfile(path_to_current_study + '/referenceAircraft/parameterStudyValues.csv'):
            with open(path_to_current_study + '/referenceAircraft/parameterStudyValues.csv', 'r') as input_file:
                for line in input_file:
                    if parameter_name in line:
                        index = line.find(';')
                        current_parameter_values = line[index+1:]
                        find_flag = True
                        number_of_runs_to_perform = current_parameter_values.count(';')
                        break
                input_file.close()

                # error handling if the current parameter does not exist in the parameter study value csv-file
                if not find_flag:
                    read_values_from_text_file = 0
                    ([item for item in input_parameter_settings if 'read_values_from_text_file' in item])[-1][-1] =\
                        str(read_values_from_text_file)
                    print('Error: Current parameter "' + parameter_name
                          + '" does not exist in parameter study value csv-file!\n '
                          '      Step up and step down study will be performed!')
                    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                         'Error: Current parameter "' + parameter_name
                                         + '" does not exist in parameter study value csv-file!\n '
                                         '      Step up and step down study will be performed!')

        else:
            read_values_from_text_file = 0
            print('Error: CSV-file for read values for parameter study does not exist!\n'
                  '       For current parameter "' + parameter_name
                  + '" step up and step down study will be performed!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Error: CSV-file for read values for parameter study does not exist!\n'
                                 '       For current parameter "' + parameter_name
                                 + '" step up and step down study will be performed!')

    # check if the switch of current parameter is not selected to read values from csv file
    #  -> initialize parameter to perform step up and step down study
    if not read_values_from_text_file == 1:
        step_size = float(([item for item in input_parameter_settings if 'step_size' in item])[-1][-1])
        number_of_steps_up = int(([item for item in input_parameter_settings if 'number_of_steps_up' in item])[-1][-1])
        number_of_steps_down = \
            int(([item for item in input_parameter_settings if 'number_of_steps_down' in item])[-1][-1])
        relative_to_reference =\
            int(([item for item in input_parameter_settings if 'relative_to_reference' in item])[-1][-1])

    ''' set local parameters '''
    xml_path_status = True
    new_value_of_input = float(0.0)
    current_value_of_input = float(0.0)
    reference_value_of_input = float(0.0)

    ''' set study count dependent input value '''
    # check if current study counter is equal to 1 -> if true: -> set new reference value to temporary *.dat file
    if study_counter == 1:
        current_value_of_input = float(root_of_study_xml_file.find(corrected_xml_path).text)
        # check for existing temporary reference value file
        if os.path.isdir(path_to_current_study + '/temp/'):
            if os.path.isfile(path_to_current_study + '/temp/reference_value_of_current_input.dat'):
                os.remove(path_to_current_study + '/temp/reference_value_of_current_input.dat')
        # else condition: create temporary directory
        else:
            os.mkdir(path_to_current_study + '/temp/')

        # write reference value to temporary *.dat file
        reference_file = open(path_to_current_study + '/temp/reference_value_of_current_input.dat', 'a')
        reference_file.write(str(current_value_of_input))
        reference_file.close()

    # else condition: current study counter is greater than 1
    #  -> read reference value from temporary reference *.dat file
    else:
        reference_file = open(path_to_current_study + '/temp/reference_value_of_current_input.dat', 'r')
        reference_value_of_input = float(reference_file.read())
        reference_file.close()

    # check if the given step size of study is relative: -> if true: -> set new relative input value to xml-file
    if relative_to_reference == 1 and not read_values_from_text_file == 1:
        # check if the first run of current input parameter should be performed
        if study_counter == 1:
            # check if any steps-up have to be performed -> estimate the highest step change as new input study value
            if number_of_steps_up > 0:
                new_value_of_input = current_value_of_input * (1 + (number_of_steps_up * step_size))
            # else if condition: # check if any steps-down have to be performed
            #  -> estimate the lowest step change as new input study value
            elif number_of_steps_down > 0:
                new_value_of_input = current_value_of_input * (1 - step_size)
            # else condition: no steps up and no steps down are set in the parameter study configuration file
            #  -> input parameter will be skipped
            else:
                xml_path_status = False
        # else condition: current run ist not the first one of current input parameter
        else:
            # check if any steps up have to be performed -> if true: -> estimate new input value for step up case
            if (number_of_steps_up - (study_counter-1)) > 0:
                new_value_of_input = \
                    reference_value_of_input * (1 + ((number_of_steps_up - (study_counter-1)) * step_size))
            # else condition: no more steps up have to be performed -> estimate new input value for step down case
            else:
                diff = (number_of_steps_up - number_of_steps_down)
                new_value_of_input = \
                    reference_value_of_input * (1 - ((number_of_steps_down - study_counter + diff) * -1) * step_size)

    # else if condition: the given step size of study is absolute -> set new absolute input value to xml-file
    elif relative_to_reference == 0 and not read_values_from_text_file == 1:
        # check if the first run of current input parameter should be performed
        if study_counter == 1:
            # check if any steps-up have to be performed -> estimate the highest step change as new input study value
            if number_of_steps_up > 0:
                new_value_of_input = current_value_of_input + (number_of_steps_up * step_size)
            # else if condition: # check if any steps-down have to be performed
            #  -> estimate the lowest step change as new input study value
            elif number_of_steps_down > 0:
                if study_counter == 1:
                    new_value_of_input = current_value_of_input - step_size
            # else condition: no steps up and no steps down are set in the parameter study configuration file
            #  -> input parameter will be skipped
            else:
                xml_path_status = False

        # else condition: current run is not the first one of current input parameter
        else:
            # check if any steps up have to be performed -> if true: -> estimate new input value for step up case
            if (number_of_steps_up - (study_counter - 1)) > 0:
                new_value_of_input = \
                    reference_value_of_input + ((number_of_steps_up - (study_counter - 1)) * step_size)
            # else condition: no more steps up have to be performed -> estimate new input value for step down case
            else:
                diff = (number_of_steps_up - number_of_steps_down)
                new_value_of_input = \
                    reference_value_of_input - (((number_of_steps_down - study_counter + diff) * -1) * step_size)

    # else if condition: check if the read_values_from_text_file and use_values_as_absolute switches are selected
    #  -> if true: -> use absolute value from parameter study csv-file
    elif use_values_as_absolute == 1 and read_values_from_text_file == 1:
        i = 1
        while i <= study_counter:
            index = current_parameter_values.find(';')
            file_value = current_parameter_values[:index]
            current_parameter_values = current_parameter_values[index + 1:]
            i += 1

            new_value_of_input = float(file_value)

    # else if condition: check if the read_values_from_text_file and relative_to_reference switches are selected
    #  -> if true: -> estimate new value as a relative value from csv file
    elif relative_to_reference_csv_file == 1 and read_values_from_text_file == 1:
        i = 1
        while i <= study_counter:
            index = current_parameter_values.find(';')
            file_value = current_parameter_values[:index]
            current_parameter_values = current_parameter_values[index + 1:]
            i += 1

        if study_counter == 1:
            new_value_of_input = round(current_value_of_input * (1 + float(file_value)), 4)
        else:
            new_value_of_input = round(reference_value_of_input * (1 + float(file_value)), 4)

    # else if condition: check if the read_values_from_text_file and relative_to_reference switches are selected
    #  -> if true: -> estimate new value as an absolute value from csv file
    elif relative_to_reference_csv_file == 0 and read_values_from_text_file == 1:
        i = 1
        while i <= study_counter:
            index = current_parameter_values.find(';')
            file_value = current_parameter_values[:index]
            current_parameter_values = current_parameter_values[index + 1:]
            i += 1

        if study_counter == 1:
            new_value_of_input = round(current_value_of_input + float(file_value), 4)
        else:
            new_value_of_input = round(reference_value_of_input + float(file_value), 4)

    return new_value_of_input, xml_path_status, number_of_runs_to_perform, log_file_list
