def initialize_parameter_study(paths_and_names, log_file_list):
    """ Function to prepare parameter study output folder and generate back-up data.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list "log_file_list" contains all system prints of function: set_configuration_parameter.py.

        The output bool "abort_parameter_study_flag" contains the status to abort the parameter study or not.

        The output list "log_file_list" contains all system prints of functions: set_configuration_parameter.py and initialize_parameter_study.py.

        :param: paths_and_names: input list of lists
        :param: log_file_list: input list
        :return: abort_parameter_study_flag: output bool, log_file_list: output list
    """

    ''' imports of python '''
    import os
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.path_check import path_check
    from sub_function.read_xml_file import read_xml_file
    from parameter_study.prepare_resume_of_parameter_study import prepare_resume_of_parameter_study
    from parameter_study.set_parameter_for_resume_parameter_study import set_parameter_for_resume_parameter_study

    ''' read data for script execution '''
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory = ([item for item in paths_and_names if 'path_of_working_directory' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    ''' initialize local parameter '''
    number_of_total_steps = 0
    abort_parameter_study_flag = False
    function_name = getframeinfo(currentframe()).function

    ''' open and read parameter from parameterStudy_conf.xml configuration file to element tree '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/parameterStudy_conf.xml'
    root_of_parameter_study_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'parameterStudy',
                                                           function_name, frame_info.lineno, log_file_list,
                                                           current_workflow_name)

    reproduce_output_file_from_old_study = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/SensitivityStudySettings/ReproduceOutputFileFromOldStudy").text)
    path_to_folder_old_study = str(root_of_parameter_study_tree.find(
        "./ProgramSettings/SensitivityStudySettings/PathToFolderOldStudy").text)
    save_results = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/SensitivityStudySettings/SaveResults").text)
    save_only_aircraft_exchange_files = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/SensitivityStudySettings/SaveResults").get('OnlyAiXFile'))
    ''' estimate necessary working folder size '''
    maximum_allowed_folder_size = float(root_of_parameter_study_tree.find(
        "./ProgramSettings/SensitivityStudySettings/MaxFolderSize").text)
    number_of_input_parameter = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameters").text)
    number_of_output_parameter = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/OutputParameters").text)

    ''' set paths of current working directory to the configuration file of to the parameter study mode '''
    i = 1
    # loop across all input parameter to set paths
    while i <= number_of_input_parameter:
        path_in_xml_file = str(root_of_parameter_study_tree.find(
            "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(i) + "'"
            + "]PathInXmlFile").text)

        # check if the string "AcftExchangeFile" in the given xml-path -> if true: -> set path to aircraft exchange file
        if "AcftExchangeFile" in path_in_xml_file:
            root_of_parameter_study_tree.find(
                "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(i) + "'" + "]RelDirectory").text \
                = str('../workingDirectoryRCE/' + current_workflow_name + '/' + aircraft_project)

        # check if the string "ConfigFile" in the given xml-path -> if true: -> set path to module configuration file
        elif "ConfigFile" in path_in_xml_file:
            root_of_parameter_study_tree.find(
                "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(i) + "'" + "]RelDirectory").text \
                = str('../workingDirectoryRCE/' + current_workflow_name)
        i += 1

    i = 1
    # loop across all output parameter to set paths
    while i <= number_of_output_parameter:
        path_in_xml_file = str(root_of_parameter_study_tree.find(
            "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'"
            + "]PathInXmlFile").text)

        # check if the string "AcftExchangeFile" in the given xml-path -> if true: -> set path to aircraft exchange file
        if "AcftExchangeFile" in path_in_xml_file:
            root_of_parameter_study_tree.find(
                "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'" + "]RelDirectory").text\
                = str('../workingDirectoryRCE/' + current_workflow_name + '/' + aircraft_project)

        # check if the string "ConfigFile" in the given xml-path -> if true: -> set path to module configuration file
        elif "ConfigFile" in path_in_xml_file:
            root_of_parameter_study_tree.find(
                "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'" + "]RelDirectory").text\
                = str('../workingDirectoryRCE/' + current_workflow_name)
        i += 1

    xml_tree.write(path, encoding='utf-8')

    ''' initialize working directory of parameter study '''
    # check if the reproduce output from old study switch is selected
    #  -> if true: -> use working directory of old study if it exists
    if reproduce_output_file_from_old_study == 1:
        # check if the working directory of old study is existing
        #  -> if true: -> set path of old study to path of current
        if os.path.isdir(path_to_folder_old_study):
            # call function to check the path of old study
            _, path_to_folder_old_study = path_check(path_to_folder_old_study)

            # set path to reference case of old parameter study to resume
            path_to_folder_old_reference = path_to_folder_old_study + 'referenceAircraft/'

            # check if the reference aircraft directory exist -> if true perform the resume of the parameter study
            if os.path.isdir(path_to_folder_old_reference):
                temporary_working_directory = path_of_working_directory_rce + current_workflow_name
                # call function to prepare resuming of old parameter study
                paths_and_names, abort_parameter_study_flag, log_file_list =\
                    prepare_resume_of_parameter_study(paths_and_names, path_to_folder_old_reference,
                                                      temporary_working_directory, log_file_list)

                # call function to check which parameter is next to analyse
                abort_parameter_study_flag, number_of_total_steps, log_file_list = \
                    set_parameter_for_resume_parameter_study(paths_and_names, path_to_folder_old_study,
                                                             log_file_list)

            # else condition: the reference aircraft directory does not exist -> abort parameter study
            else:
                abort_parameter_study_flag = True
                print('Error: The entered path to the folder of old parameter study does not exist! \n'
                      'After finishing the reference aircraft estimation the parameter study will be aborted!')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
                                     + ': Error: The entered path to the folder of old parameter study does not exist!'
                                       '\n'
                                       'After finishing the reference aircraft estimation the parameter study will be'
                                       ' aborted!')

        # else condition: entered path to old study does not exist
        else:
            abort_parameter_study_flag = True
            print('Error: The entered path to the folder of old parameter study does not exist! \n'
                  'After finishing the reference aircraft estimation the parameter study will be aborted!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
                                 + ': Error: The entered path to the folder of old parameter study does not exist! \n'
                                 'After finishing the reference aircraft estimation the parameter study will be'
                                 ' aborted!')

    # else condition: reproduce output from old study switch is not selected
    #  -> create new output working directory for parameter study
    else:
        # generate working dir
        working_dir_name = path_of_working_directory + 'workflowResults/' + current_workflow_name + '_' \
                           + aircraft_project + '_parameterStudy'
        # set path of parameter study working directory to parameter study configuration file
        root_of_parameter_study_tree.find(
            "./ProgramSettings/SensitivityStudySettings/PathToCurrentStudy").text = working_dir_name
        xml_tree.write(path, encoding='utf-8')
        # check if the working_dir_name directory is not existing
        #  -> if true: -> create parameter study working and output directory
        if not os.path.isdir(working_dir_name):
            # create parameter study working and output directory
            os.makedirs(working_dir_name + '/output_csv/')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Path to parameter study working directory: ' + working_dir_name)

            # copy module pre-execution configuration files to reference directory
            shutil.copytree(path_of_working_directory_rce + current_workflow_name + '/temporaryResults',
                            working_dir_name + '/referenceAircraft/')

            # copy engineData to reference directory
            #  -> if an engineData directory exist in the current project directory copy that
            if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                             + '/engineData/'):
                shutil.copytree(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                + '/engineData/', working_dir_name + '/referenceAircraft/engineData')
            # else copy from engine tool directory
            else:
                shutil.copytree(path_of_working_directory + 'propulsion_design/Engines/',
                                working_dir_name + '/referenceAircraft/engineData')

            # copy aero data if retrofit data exist
            if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                             + '/aeroData/'):
                shutil.copytree(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                + '/aeroData/', working_dir_name + '/referenceAircraft/aeroData')

            # copy geometry data if retrofit data exist
            if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                             + '/geometryData/'):
                shutil.copytree(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                + '/geometryData/', working_dir_name + '/referenceAircraft/geometryData')

            # copy mission data if retrofit data exist
            if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                             + '/missionData/'):
                shutil.copytree(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                + '/missionData/', working_dir_name + '/referenceAircraft/missionData')

            # copy aircraft exchange file of current project to reference directory
            shutil.copyfile(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/'
                            + aircraft_project + '.xml',
                            working_dir_name + '/referenceAircraft/' + aircraft_project + '_start.xml')

            # copy cpacs file of current project to reference directory
            shutil.copyfile(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/'
                            + aircraft_project + '_CPACS.xml',
                            working_dir_name + '/referenceAircraft/' + aircraft_project + '_CPACS.xml')

            # copy parameter study configuration file of current project to reference directory
            shutil.copyfile(path_of_working_directory_rce + current_workflow_name + '/parameterStudy_conf.xml',
                            working_dir_name + '/referenceAircraft/' + 'parameterStudy_conf.xml')

            # copy parameter study value file of current project to reference directory
            shutil.copyfile(path_of_working_directory_rce + current_workflow_name + '/parameterStudyValues.csv',
                            working_dir_name + '/referenceAircraft/' + 'parameterStudyValues.csv')

            # copy starting workflow configuration file of current project as back up file to reference directory
            shutil.copyfile(path_of_working_directory_rce + current_workflow_name + '/UNICADOworkflow_conf.xml',
                            working_dir_name + '/referenceAircraft/' + 'UNICADOworkflow_conf_start.xml')

            # read workflow configuration file as element tree to set necessary switches to avoid outer manipulation
            frame_info = getframeinfo(currentframe())
            path = path_of_working_directory_rce + current_workflow_name + '/UNICADOworkflow_conf.xml'
            root_of_workflow_tree, xml_workflow_tree = read_xml_file(path, path_of_working_directory_rce,
                                                                     'UNICADOworkflow', function_name,
                                                                     frame_info.lineno, log_file_list,
                                                                     current_workflow_name)

            root_of_workflow_tree.find(
                "./ControlSettings/ProgramSpecific/autoUpdate/allowAutoUpdate").text = str(0)
            root_of_workflow_tree.find(
                "./ControlSettings/ProgramSpecific/preSettings/setProjectFolderToDefault").text = str(0)
            root_of_workflow_tree.find(
                "./ControlSettings/ProgramSpecific/preSettings/DeleteEnginesBeforeRun").text = str(0)
            root_of_workflow_tree.find(
                "./ControlSettings/ProgramSpecific/useSettings/UseConfigsFromExistingProject/configCopyMode").text =\
                str(0)
            root_of_workflow_tree.find(
                "./ControlSettings/ProgramSpecific/useSettings/UseEngineFromExistingProject/engineCopyMode").text =\
                str(0)
            xml_workflow_tree.write(path, encoding='utf-8')

            # copy new parameter loop starting workflow configuration file to reference directory
            shutil.copyfile(path_of_working_directory_rce + current_workflow_name + '/UNICADOworkflow_conf.xml',
                            working_dir_name + '/referenceAircraft/' + 'UNICADOworkflow_conf.xml')

            # copy range type specific factor file to reference directory if it exists
            if os.path.isfile(path_of_working_directory_rce + current_workflow_name
                              + '/rangeTypeSpecificFactors.xml'):
                shutil.copyfile(path_of_working_directory_rce + current_workflow_name
                                + '/rangeTypeSpecificFactors.xml',
                                working_dir_name + '/referenceAircraft/' + 'rangeTypeSpecificFactors.xml')

            print('All necessary aircraft reference files have successfully been copied to parameter study working '
                  'directory.')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'All necessary aircraft reference files have successfully been copied to parameter'
                                 ' study working directory.')

        # loop across the number of input parameters to estimate total number of necessary workflow loops
        i = 1
        while i <= number_of_input_parameter:
            number_of_steps_up = int(root_of_parameter_study_tree.find(
                "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(i) + "'"
                + "]ParametricStudy/NumberOfStepsUp").text)
            number_of_steps_down = int(root_of_parameter_study_tree.find(
                "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(i) + "'"
                + "]ParametricStudy/NumberOfStepsDown").text)
            number_of_total_steps = number_of_total_steps + number_of_steps_up + number_of_steps_down
            i += 1

        # Add + 1 to number of total steps for reference calculation
        number_of_total_steps += 1

        # check necessary disk space if the save results switch is set to 1
        if save_results == 1:
            # result folder size is temporary set to 35 mb -> temporary hard coded
            #  -> should be dynamic in a future version
            size_of_results_folder_in_mb = 35
            # check if only the aircraft exchange file and the final csv-file should be stored
            if save_only_aircraft_exchange_files == 1:
                # result folder size is temporary set to 0.5 mb -> temporary hard coded
                #  -> should be dynamic in a future version
                size_of_results_folder_in_mb = 0.5
            total_necessary_disk_space_in_gb = float((number_of_total_steps * size_of_results_folder_in_mb)/1024)
            if total_necessary_disk_space_in_gb <= maximum_allowed_folder_size:
                print('For planned parameter study the necessary disk space in GB is: '
                      + str(total_necessary_disk_space_in_gb))
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'For planned parameter study the necessary disk space in GB is: '
                                     + str(total_necessary_disk_space_in_gb))
            else:
                abort_parameter_study_flag = True
                print('ERROR: For planned parameter study required disk space ( '
                      + str(total_necessary_disk_space_in_gb) + 'GB) is greater than the maximum allowed of '
                      + str(maximum_allowed_folder_size) + 'GB! \n'
                      ' * After finishing the reference aircraft estimation the parameter study will be aborted!')
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'ERROR: For planned parameter study required disk space ( '
                                     + str(total_necessary_disk_space_in_gb)
                                     + 'GB) is greater than the maximum allowed of '
                                     + str(maximum_allowed_folder_size) + 'GB! \n '
                                     '* After finishing the reference aircraft estimation the parameter study will be'
                                     ' aborted!')

        # else condition: no results should be saved
        #  -> only one single csv-file with results and the reference data will be generated
        else:
            print('No results of parameter study will be saved! Only one single csv-file with results and the reference'
                  ' data will be generated!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'No results of parameter study will be saved! Only one single csv-file with results '
                                 'and the reference data will be generated!')

    return abort_parameter_study_flag, number_of_total_steps, log_file_list
