def perform_parameter_study(install_path_directory, study_counter, outer_loop_counter, global_loop_counter,
                            perform_workflow_execution, current_workflow_name='UNICADOworkflow'):
    """ Function to perform the parameter study mode.

        The input string "install_path_directory" contains the absolute path to the UNICADO install directory.

        The input integer "study_counter" contains the current number of parameter study of current input parameter.

        The input integer "outer_loop_counter" contains the maximum number of parameter studies to perform.

        The input integer "global_loop_counter" contains the current number of parameter study loop.

        The input integer "perform_workflow_execution" contains the status to perform the parameter study or not.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default string 'UNICADOworkflow' is used.

        The output integer "outer_loop_counter" contains the maximum number of parameter studies to perform.

        The output integer "study_counter" contains the current number of parameter study of current input parameter.

        The output string "parameter_name" contains the name of the current parameter study input.

        The output float 'new_value_of_input' contains the new parameter iteration value of current loop.

        :param: install_path_directory: input string
        :param: study_counter: input integer
        :param: outer_loop_counter: input integer
        :param: global_loop_counter: input integer
        :param: perform_workflow_execution: input integer
        :param: current_workflow_name: input string
        :return: outer_loop_counter: output integer, study_counter: output integer, parameter_name: output string, new_value_of_input: output float
    """

    ''' imports for python '''
    import os
    import shutil
    from datetime import datetime
    from parameter_study.reset_parameter_study_files import reset_parameter_study_files
    from parameter_study.set_input_parameter_settings import set_input_parameter_settings
    from parameter_study.read_parameter_study_settings import read_parameter_study_settings
    from parameter_study.read_input_parameter_settings import read_input_parameter_settings

    ''' initialize local parameter '''
    log_file_list = ['']
    xml_path_status = False
    parameter_name = str('no parameter')
    new_value_of_input = float(0.0)
    number_of_current_parameter = 0

    ''' read parameter study parameter from configuration file '''
    # call function to read configuration file of parameter study
    parameter_study_list, log_file_list = read_parameter_study_settings(install_path_directory, log_file_list,
                                                                        current_workflow_name)

    ''' read configuration parameter for current input parameter '''
    path_to_current_study = \
        str(([item for item in parameter_study_list if 'path_to_current_study' in item])[-1][-1])
    number_of_input_parameter = \
        int(([item for item in parameter_study_list if 'number_of_input_parameter' in item])[-1][-1])
    start_every_run_with_ref_file = \
        int(([item for item in parameter_study_list if 'start_every_run_with_ref_file' in item])[-1][-1])

    ''' check if the parameter study should be performed -> if true: -> perform parameter study '''
    if perform_workflow_execution == 1:
        ''' reset project files to default '''
        if start_every_run_with_ref_file == 1:
            # call function to reset project files if selected in parameter study configuration file
            log_file_list = reset_parameter_study_files(install_path_directory, path_to_current_study,
                                                        perform_workflow_execution, log_file_list,
                                                        current_workflow_name)
        else:
            print('Switch to run every loop with reference files is set to 0! -> No files will be reset to default!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Switch to run every loop with reference files is set to 0! '
                                 '-> No files will be reset to default!')

        ''' preparation of input parameter settings of current loop execution '''
        # loop across the status of current xml-path -> if the status is equal to "False"
        #  -> current input parameter is skipped and the next one will be used
        while not xml_path_status:
            xml_path_status = True
            if study_counter == 0:
                # check for existing temp directory
                if os.path.isdir(path_to_current_study + '/temp/'):
                    if os.path.isfile(path_to_current_study + '/temp/number_of_current_parameter.dat'):
                        parameter_file = open(path_to_current_study + '/temp/number_of_current_parameter.dat', 'r')
                        number_of_current_parameter = int(parameter_file.read())
                        parameter_file.close()

                    # delete old temporary directory
                    shutil.rmtree(path_to_current_study + '/temp/')

                # create new temporary directory for current input parameter of study
                os.mkdir(path_to_current_study + '/temp/')
                parameter_file = open(path_to_current_study + '/temp/number_of_current_parameter.dat', 'a')
                parameter_file.write(str(number_of_current_parameter + 1))
                parameter_file.close()
                log_file_list.append(' --- Parameter study of input parameter ' + str(number_of_current_parameter + 1)
                                     + ' will performed. --- ')
                print(' --- Parameter study of input parameter ' + str(number_of_current_parameter + 1)
                      + ' will performed. --- ')
                number_of_current_parameter += 1

            # check if number of current parameter is not greater than the total number of input parameter
            #  -> read and set study input parameter settings
            if not number_of_current_parameter > number_of_input_parameter:
                # call function to read configuration parameter of current study input parameter
                study_counter += 1
                input_parameter_settings, log_file_list = read_input_parameter_settings(install_path_directory,
                                                                                        path_to_current_study,
                                                                                        study_counter, log_file_list,
                                                                                        current_workflow_name)

                parameter_name = \
                    str(([item for item in input_parameter_settings if 'parameter_name' in item])[-1][-1])
                number_of_steps_up = \
                    int(([item for item in input_parameter_settings if 'number_of_steps_up' in item])[-1][-1])
                number_of_steps_down = \
                    int(([item for item in input_parameter_settings if 'number_of_steps_down' in item])[-1][-1])

                if study_counter == 1:
                    print(path_to_current_study + '/' + parameter_name)
                    if os.path.isdir(path_to_current_study + '/' + parameter_name):
                        shutil.rmtree(path_to_current_study + '/' + parameter_name)

                # call function to set input study parameter to necessary xml-files
                xml_path_status, new_value_of_input, number_of_runs_to_perform, log_file_list = \
                    set_input_parameter_settings(install_path_directory, path_to_current_study,
                                                 input_parameter_settings, xml_path_status, log_file_list,
                                                 current_workflow_name)

                read_values_from_text_file = \
                    int(([item for item in input_parameter_settings if 'read_values_from_text_file' in item])[-1][-1])

                if not read_values_from_text_file == 1:
                    # check if number of max studies of current input parameter are be performed
                    #  or the current parameter study will be skipped -> if true: -> reset study counter to zero
                    if (number_of_steps_up + number_of_steps_down) == study_counter or not xml_path_status:
                        # check if the current parameter study will be skipped
                        #  -> if true: -> reduce outer loop counter by the summation of steps up and down of current
                        #   study input parameter
                        if not xml_path_status:
                            outer_loop_counter = outer_loop_counter - (number_of_steps_up + number_of_steps_down)

                        study_counter = 0

                else:
                    # check if number of max studies of current input parameter are be performed
                    #  or the current parameter study will be skipped -> if true: -> reset study counter to zero
                    if number_of_runs_to_perform == study_counter or not xml_path_status:
                        # check if the current parameter study will be skipped
                        #  -> if true: -> reduce outer loop counter by the summation of steps up and down of current
                        #   study input parameter
                        if not xml_path_status:
                            outer_loop_counter = outer_loop_counter - number_of_runs_to_perform

                        study_counter = 0

            # else condition: number of current parameter is greater than the total number of input parameter
            #  -> parameter study is finished -> terminate workflow after final run
            else:
                outer_loop_counter = 1

    # else condition: parameter study is finished or should not be performed -> reset all files to initial status
    else:
        log_file_list = reset_parameter_study_files(install_path_directory, path_to_current_study,
                                                    perform_workflow_execution, log_file_list, current_workflow_name)
        path_to_temp = install_path_directory + 'workingDirectoryRCE/' + current_workflow_name + '/temp/'
        if global_loop_counter == 2 and (os.path.isfile(path_to_temp + 'convergenceError.dat')
                                         or os.path.isfile(path_to_temp + 'workflowExecutionError.dat')):
            print('Error in the calculation of the reference case!')
            print('No valid design!')
            print('Parameter study is canceled and workflow is terminated!')
            log_file_list.append('Error in the calculation of the reference case!')
            log_file_list.append('No valid design!')
            log_file_list.append('Parameter study is canceled and workflow is terminated!')

        if os.path.isdir(path_to_current_study + '/temp/'):
            shutil.rmtree(path_to_current_study + '/temp/')
            print('Temporary working directory of parameter study successfully deleted!')

    ''' write log-file to system '''
    log_file = open(install_path_directory + '/workingDirectoryRCE/' + current_workflow_name
                    + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    return outer_loop_counter, study_counter, parameter_name, new_value_of_input
