def read_input_parameter_settings(install_path_directory, path_to_current_study, study_counter, log_file_list,
                                  current_workflow_name='UNICADOworkflow'):
    """ Function to read parameters from parameter study configuration file.

        The input string 'install_path_directory' contains the absolute path to the UNICADO install directory.

        The input string 'path_to_current_study' contains the absolute path to the working directory of current parameter study.

        The input integer 'study_counter' contains the current loop number of current study parameter.

        The input list "log_file_list" contains all system prints of function: perform_parameter_study.py.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default sting 'UNICADOworkflow' is used.

        The output list of lists "input_parameter_settings" contains ato following values:
            *  [0][0] string: 'parameter_name',                  [0][1] string: 'name of the current study input parameter'
            *  [1][0] string: 'input_directory_name',            [1][1] string: 'name of the input directory of current study parameter'
            *  [2][0] string: 'input_file_name'                  [2][1] string: 'name of the input file of the current study parameter'
            *  [3][0] string: 'path_in_xml_file'                 [3][1] string: 'path to the study parameter in the input xml-file'
            *  [4][0] string: 'read_values_from_text_file',      [4][1] int:    'switch to read iteration values from an external data file'
            *  [5][0] String: 'row_number'                       [5][1] int:    'number of row inside of the external data file where the current parameter are listed'
            *  [6][0] String: 'values_as_abs_step_size'          [6][1] int:    'switch to set parameter from external data file to absolute values'
            *  [7][0] string: 'relative_to_reference',           [7][1] int:    'switch to activate relative step sizes according to reference values'
            *  [8][0] string: 'step_size',                       [8][1] float:  'value of step size of current study parameter'
            *  [9][0] string: 'number_of_steps_up',              [9][1] int:    'value of maximum iteration steps upwards are to be performed'
            * [10][0] string: 'number_of_steps_down',           [10][1] int:    'value of maximum iteration steps downwards are to be performed'
            * [11][0] string: 'study_counter'                   [11][1] int:    'number of iteration loop of current input parameter'

        The output list "log_file_list" contains all system prints of functions: perform_parameter_study.py and read_parameter_study_settings.py.

        :param: install_path_directory: input string
        :param: path_to_current_study: input string
        :param: study_counter: input integer
        :param: log_file_list: input list
        :param: current_workflow_name: input string
        :return: input_parameter_settings: output list of lists, log_file_list: output list
    """

    ''' imports for python '''
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' initialize local parameter '''
    function_name = getframeinfo(currentframe()).function
    parameter_file = open(path_to_current_study + '/temp/number_of_current_parameter.dat', 'r')
    number_of_current_parameter = int(parameter_file.read())
    parameter_file.close()

    ''' open and read parameter from parameterStudy_conf.xml configuration file to element tree '''
    frame_info = getframeinfo(currentframe())
    path_of_working_directory_rce = install_path_directory + 'workingDirectoryRCE/'
    path = path_of_working_directory_rce + current_workflow_name + '/parameterStudy_conf.xml'
    root_of_parameter_study_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'parameterStudy',
                                                           function_name, frame_info.lineno, log_file_list,
                                                           current_workflow_name)

    ''' read configuration settings of current study input parameter from root_of_parameter_study_tree '''
    parameter_name = root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParameterName").text
    input_directory_name = root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/RelDirectory").text
    input_file_name = root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/FileName").text
    path_in_xml_file = root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/PathInXmlFile").text
    read_values_from_text_file = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/ReadValuesFromTextFile").text)
    use_values_as_absolute = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/ReadValuesFromTextFile").get('UseValuesAsAbsolute'))
    relative_to_reference_csv_file = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/ReadValuesFromTextFile").get('RelativeToReference'))
    step_size = float(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/StepSize").text)
    relative_to_reference = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/StepSize").get('RelativeToReference'))
    number_of_steps_up = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/NumberOfStepsUp").text)
    number_of_steps_down = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/InputParameter[" + "@ID='" + str(number_of_current_parameter) + "'"
        + "]/ParametricStudy/NumberOfStepsDown").text)

    input_parameter_settings = [['parameter_name', parameter_name],
                                ['input_directory_name', input_directory_name],
                                ['input_file_name', input_file_name],
                                ['path_in_xml_file', path_in_xml_file],
                                ['read_values_from_text_file', read_values_from_text_file],
                                ['use_values_as_absolute', use_values_as_absolute],
                                ['relative_to_reference_csv_file', relative_to_reference_csv_file],
                                ['relative_to_reference', relative_to_reference],
                                ['step_size', step_size],
                                ['number_of_steps_up', number_of_steps_up],
                                ['number_of_steps_down', number_of_steps_down],
                                ['study_counter', study_counter]]

    log_file_list.append(' --- Iteration number of current study input parameter is: ' + str(study_counter) + ' --- ')
    print(' --- Iteration number of current study input parameter is: ' + str(study_counter) + ' --- ')

    return input_parameter_settings, log_file_list
