def write_parameter_study_csv_output(path_of_working_directory_rce, path_of_working_directory, copy_target_path,
                                     parameter_for_design_case, log_file_list, current_workflow_name='UNICADOworkflow'):
    """ Function to write the parameter study outputs to the output csv-file.

        The input string "path_of_working_directory_rce" contains the absolute path to the rce working directory.

        The input string "path_of_working_directory" contains the absolute system path of unicado working directory.

        The input string "copy_target_path" contains the absolute path to the current parameter study output directory.

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The input list "log_file_list" contains all system prints of function: post_operations_of_workflow.py.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default string 'UNICADOworkflow' is used.

        :param: path_of_working_directory_rce: input string
        :param: path_of_working_directory: input string
        :param: copy_target_path: input string
        :param: parameter_for_design_case: input list of lists
        :param: log_file_list: input list
        :param: current_workflow_name: input string
    """

    ''' imports for python '''
    import os
    from inspect import currentframe, getframeinfo
    from datetime import datetime
    from sub_function.path_check import path_check
    from sub_function.read_xml_file import read_xml_file
    from sub_function.xml_path_check import xml_path_check

    ''' read data for script execution '''
    study_counter = int(([item for item in parameter_for_design_case if 'study_counter' in item])[-1][-1])
    parameter_name = str(([item for item in parameter_for_design_case if 'parameter_name' in item])[-1][-1])
    new_value_of_input = float(([item for item in parameter_for_design_case if 'new_value_of_input' in item])[-1][-1])
    global_loop_counter = int(([item for item in parameter_for_design_case if 'global_loop_counter' in item])[-1][-1])

    ''' initialize local parameter '''
    lines = []
    value_list = []
    parameter_list = []
    header_string = str()
    status_csv_output = False
    tool_error_flag = os.path.isfile(path_of_working_directory_rce + current_workflow_name
                                     + '/temp/workflowExecutionError.dat')
    convergence_error_flag = os.path.isfile(path_of_working_directory_rce + current_workflow_name
                                            + '/temp/convergenceError.dat')
    function_name = getframeinfo(currentframe()).function

    ''' read output parameter from parameter study configuration file as elementTree '''
    if global_loop_counter == 1:
        index = copy_target_path.find('referenceAircraft')
    else:
        index = copy_target_path.find(parameter_name)
    path = copy_target_path[:index] + 'referenceAircraft/parameterStudy_conf.xml'

    # call function to read the parameter study configuration file
    frame_info = getframeinfo(currentframe())
    root_of_parameter_study_tree, _ = read_xml_file(path, path_of_working_directory_rce, 'parameterStudy',
                                                    function_name, frame_info.lineno, log_file_list,
                                                    current_workflow_name)

    number_of_outputs_to_write = int(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/OutputParameters").text)

    ''' write header to output csv-file of current parameter '''
    if global_loop_counter == 1 or study_counter == 1:
        if global_loop_counter == 1:
            header_string = '# ID;' + 'reference aircraft;'
            print('Header string of reference case successfully writen to parameter study output csv-file!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Header string of reference case successfully writen to parameter study '
                                 'output csv-file!')

        if study_counter == 1:
            header_string = '# ID;' + parameter_name + ';'
            print('Header string of current input parameter successfully writen to parameter study output csv-file.')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Working copy of gnuplot has been successfully created!')

        # list comprehension to generate header string for output csv-file
        parameter_list.append(header_string + ';'.join([str(root_of_parameter_study_tree.find(
            "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'" + "]/ParameterName").text)
                                                        for i in range(1, number_of_outputs_to_write + 1)]))

    ''' write reference case of current input parameter to output csv-file '''
    if os.path.isfile(copy_target_path[:index] + 'temp/reference_value_of_current_input.dat') \
            and not os.path.isfile(copy_target_path[:index] + 'temp/output_status.dat'):
        # read current input parameter reference value from temporary file
        with open(copy_target_path[:index] + 'temp/reference_value_of_current_input.dat', 'r') as file:
            first_line = float(file.readlines()[0])
        file.close()
        # check if the current input parameter value is lower than the current input parameter reference value
        #  -> if true: -> generate status flag file and add reference case to current output csv-file string
        if new_value_of_input < first_line:
            output_status_dat = open(copy_target_path[:index] + 'temp/output_status.dat', 'a+')
            output_status_dat.close()
            # read reference value string from output csv-file
            with open(copy_target_path[:index] + 'output_csv/parameter_study_output.csv', 'r') as file:
                reference_line = file.readlines()[1]
            file.close()
            # id_ref_x are string positions of the first to ";"
            #  -> the positions are necessary to manipulate the reference string into the correct csv-output string
            id_ref_1 = reference_line.find(';')
            id_ref_2 = reference_line[id_ref_1+1:].find(';')
            reference_string = 'refCase;' + str(first_line) + reference_line[id_ref_1+id_ref_2+1:]
            parameter_list.append(reference_string.rstrip())

    ''' write output values of current run to output csv-file '''
    # read all output parameter directories from elementTree
    output_parameter_directory_list = []
    for i in range(1, number_of_outputs_to_write + 1):
        _, relative_path_of_output_parameter = path_check(str(root_of_parameter_study_tree.find(
            "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'" + "]/RelDirectory").text))
        output_parameter_directory_list.append(path_of_working_directory + relative_path_of_output_parameter)

    # read all output parameter file names from elementTree
    file_name_list = [str(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'" + "]/FileName").text)
                      for i in range(1, number_of_outputs_to_write + 1)]

    # read all output parameter xml-file paths from elementTree
    xml_path_list = [str(root_of_parameter_study_tree.find(
        "./ProgramSettings/ParameterSettings/OutputParameter[" + "@ID='" + str(i) + "'" + "]/PathInXmlFile").text)
                     for i in range(1, number_of_outputs_to_write + 1)]

    # generate the first two entries of output string
    if global_loop_counter == 1:
        value_string = 'run_' + str(global_loop_counter) + ';' + 'refCase;'
    else:
        value_string = 'run_' + str(study_counter) + ';' + str(new_value_of_input) + ';'

    # file_name_list[0][:-4] cuts the postfix ".xml" from given string
    frame_info = getframeinfo(currentframe())
    print(output_parameter_directory_list[0])
    root_of_output_parameter_tree, _ = read_xml_file(output_parameter_directory_list[0] + file_name_list[0],
                                                     path_of_working_directory_rce, file_name_list[0][:-4],
                                                     function_name, frame_info.lineno, log_file_list,
                                                     current_workflow_name)

    # add first output parameter value to list
    value_list.append(str(root_of_output_parameter_tree.find(xml_path_check(xml_path_list[0])).text))

    # call function to read the output parameter xml-file
    for i in range(1, number_of_outputs_to_write):
        # check if the current entry of file name and output parameter directory are not equal to the last one
        #  -> if true: -> read new elementTree
        if not ((output_parameter_directory_list[i] == output_parameter_directory_list[i-1])
                or file_name_list[i] == file_name_list[i-1]):
            frame_info = getframeinfo(currentframe())
            print(output_parameter_directory_list[i])
            root_of_output_parameter_tree, _ = read_xml_file(output_parameter_directory_list[i] + file_name_list[i],
                                                             path_of_working_directory_rce, file_name_list[i][:-4],
                                                             function_name, frame_info.lineno, log_file_list,
                                                             current_workflow_name)

        xml_string = xml_path_check(xml_path_list[i])
        # check if the current xml path includes an '@' -> if true: -> generate dynamic python xml path
        if '@' in xml_string:
            idx = xml_string.find('@')
            idx_2 = xml_string[idx:].find('/')
            python_xml_string = xml_string[:idx] + '[' + "@ID='" + xml_string[idx + 1:idx + 1 + idx_2 - 1] + "'" + "]" \
                + xml_string[idx + idx_2:]

        # else condition:  the current xml path includes no '@' -> use current string from list as python xml path
        else:
            python_xml_string = xml_string

        # check if convergence of current loop is reached -> if true: -> add current output value to list
        if not convergence_error_flag and not tool_error_flag:
            value_list.append(str(root_of_output_parameter_tree.find(python_xml_string).text))
        # else condition: convergence of current loop is not reached -> add N/A to value list
        else:
            value_list.append('N/A')

    # exception handling if the current study counter is equal to zero
    #  -> if true: read number of last run from csv-file and add +1 for current loop
    if study_counter == 0 and global_loop_counter > 1:
        # read all lines from output csv-file to extract last two lines
        with open(copy_target_path[:index] + 'output_csv/parameter_study_output.csv', 'r') as file:
            for line in file:
                lines.append(line)
        file.close()
        # id_ref_x are string positions of "_" and ";" in the last line of csv-file
        #  -> the positions are necessary to manipulate the reference string into the correct csv-output string
        idx_3 = lines[-1].find('_')
        idx_4 = lines[-1].find(';')
        # check if the last line of output csv-file starts with 'run_' -> if true: -> extract number of previous run
        if lines[-1][:idx_3+1] == 'run_':
            value_string = 'run_' + str(int(lines[-1][idx_3+1:idx_4]) + 1) + ';' + str(new_value_of_input) + ';'
        # check if the last line of output csv-file starts with 'refCase'
        #  -> if true: -> extract number of previous run from pre last line of output csv-file
        elif lines[-1][:idx_4] == 'refCase':
            value_string = 'run_' + str(int(lines[-2][idx_3+1:idx_4]) + 1) + ';' + str(new_value_of_input) + ';'
        # check if the last line of output csv-file is empty
        #  -> if true: -> set current run counter to study counter + 1
        elif lines[-1] == '':
            value_string = 'run_' + str(study_counter + 1) + ';' + str(new_value_of_input) + ';'

    # generate output string of current run
    parameter_list.append(value_string + ';'.join(value_list))

    # add blank line after the last loop of each input parameter
    if global_loop_counter == 1 or study_counter == 0:
        parameter_list.append('')

    output_file = open(copy_target_path[:index] + 'output_csv/parameter_study_output.csv', 'a')
    for row in parameter_list:
        output_file.write(row + '\n')
    output_file.close()

    print('Output parameter value string of current run successfully writen to parameter study output csv-file!')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Output parameter value string of current run successfully writen to parameter study '
                         'output csv-file!')

    return status_csv_output, log_file_list
