def check_tlars_and_gradients(paths_and_names, parameter_for_design_case):
    """ check_tlars_and_gradients checks whether the tlars and gradients have been observed.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [0][0] string: 'design_mode',                      [0][1] int:   'value to check which design mode is selected'
            *  [1][0] string: 'automatic_trim',                   [1][1] int:   'value to switch off and on the automatic trim function of the workflow'
            *  [2][0] string: 'convergence_criteria',             [2][1] float: 'value of convergence criteria of ome and mtom iteration'
            *  [3][0] string: 'number_of_max_iteration',          [3][1] int:   'value to set maximum number of design sizing iteration steps'
            *  [4][0] string: 'damp_mtom_iteration'               [4][1] bool:  'switch to activate damping of mtom iteration loop'
            *  [5][0] String: 'damp_ome_iteration'                [5][1] bool:  'switch to activate damping of ome iteration loop'
            *  [6][0] string: 'parallel_execution'                [6][1] int:   'switch to activate the parallel execution mode'
            *  [7][0] string: 'count_of_iteration',               [7][1] int:   'current number of iteration of design sizing loop'
            *  [8][0] string: 'count_of_mission_study_loop',      [8][1] int:   'current number of iteration of mission study loop'
            *  [9][0] string: 'parameter_name',                   [9][1] string: 'name of the current input parameter if parameter study will be performed'
            * [10][0] string: 'global_loop_counter',             [10][1] int:    'global loop counter for parameter study mode'
            * [11][0] string: 'study_counter',                   [11][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [12][0] string: 'new_value_of_input',              [12][1] float:  'value of current parameter study input parameter'

        :param: paths_and_names: input list of lists
        :param: parameter_for_design_case: input list of lists
        :return: none
     """

    ''' imports for python '''
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    function_name = getframeinfo(currentframe()).function

    ''' create list for log-file string '''
    log_file_list = ['',
                     '***************************************** check tlars and climb gradients '
                     '*****************************************']

    ''' open and read aircraft exchange file '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name, frame_info.lineno,
                                                             log_file_list, current_workflow_name)

    ''' check TLARs for fulfilled '''
    #TOFL
    tofl_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_takeoff_distance/'
        'checked/value')
    if tofl_checked is not None:
        tofl_checked = tofl_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        tofl_checked = False
    tofl_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_takeoff_distance/'
        'maintainable/value')
    if tofl_fulfilled is not None:
        tofl_fulfilled = tofl_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        tofl_fulfilled = False
    #LDN
    ldn_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_landing_field_length/'
        'checked/value')
    if ldn_checked is not None:
        ldn_checked = ldn_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        ldn_checked = False
    ldn_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_landing_field_length/'
        'maintainable/value')
    if ldn_fulfilled is not None:
        ldn_fulfilled = ldn_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        ldn_fulfilled = False
    #v_approach
    v_approach_speed_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_approach_speed/'
        'checked/value')
    if v_approach_speed_checked is not None:
        v_approach_speed_checked = v_approach_speed_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        v_approach_speed_checked = False
    v_approach_speed_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_approach_speed/'
        'maintainable/value')
    if v_approach_speed_fulfilled is not None:
        v_approach_speed_fulfilled = v_approach_speed_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        v_approach_speed_fulfilled = False
    #intial cruise altitude
    h_initial_cruise_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/initial_cruise_altitude/'
        'checked/value')
    if h_initial_cruise_checked is not None:
        h_initial_cruise_checked = h_initial_cruise_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        h_initial_cruise_checked = False
    h_initial_cruise_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/initial_cruise_altitude/'
        'maintainable/value')
    if h_initial_cruise_fulfilled is not None:
        h_initial_cruise_fulfilled = h_initial_cruise_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        h_initial_cruise_fulfilled = False
    #maximum operating altitude (all engines operating)
    h_max_operating_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/maximum_operating_altitude/'
        'checked/value')
    if h_max_operating_checked is not None:
        h_max_operating_checked = h_max_operating_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        h_max_operating_checked = False
    h_max_operating_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/maximum_operating_altitude/'
        'maintainable/value')
    if h_max_operating_fulfilled is not None:
        h_max_operating_fulfilled = h_max_operating_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        h_max_operating_fulfilled = False
    #maximum operating altitude (one engine inoperative)
    h_max_oei_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/maximum_one_engine_operating_altitude/'
        'checked/value')
    if h_max_oei_checked is not None:
        h_max_oei_checked = h_max_oei_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        h_max_oei_checked = False
    h_max_oei_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/maximum_one_engine_operating_altitude/'
        'maintainable/value')
    if h_max_oei_fulfilled is not None:
        h_max_oei_fulfilled = h_max_oei_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        h_max_oei_fulfilled = False
    #Initial cruise Mach number
    mach_initial_cruise_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/initial_cruise_mach_number/'
        'checked/value')
    if mach_initial_cruise_checked is not None:
        mach_initial_cruise_checked = mach_initial_cruise_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        mach_initial_cruise_checked = False
    mach_initial_cruise_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/initial_cruise_mach_number/'
        'maintainable/value')
    if mach_initial_cruise_fulfilled is not None:
        mach_initial_cruise_fulfilled = mach_initial_cruise_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        mach_initial_cruise_fulfilled = False
    #TTC
    ttc_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_time_to_climb/'
        'checked/value')
    if ttc_checked is not None:
        ttc_checked = ttc_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        ttc_checked = False
    ttc_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/design_time_to_climb/'
        'maintainable/value')
    if ttc_fulfilled is not None:
        ttc_fulfilled = ttc_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        ttc_fulfilled = False
    #Span limit
    span_limit_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/span_limit/'
        'checked/value')
    if span_limit_checked is not None:
        span_limit_checked = span_limit_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        span_limit_checked = False
    span_limit_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/top_level_aircraft_requirements/span_limit/'
        'maintainable/value')
    if span_limit_fulfilled is not None:
        span_limit_fulfilled = span_limit_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        span_limit_fulfilled = False

    ''' check climb gradients for fulfilled '''
    #second T/O climb segment
    climb_gradient_second_to_segment_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_of_second_takeoff_segment/'
        'checked/value')
    if climb_gradient_second_to_segment_checked is not None:
        climb_gradient_second_to_segment_checked = climb_gradient_second_to_segment_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        climb_gradient_second_to_segment_checked = False
    climb_gradient_second_to_segment_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_of_second_takeoff_segment/'
        'maintainable/value')
    if climb_gradient_second_to_segment_fulfilled is not None:
        climb_gradient_second_to_segment_fulfilled = climb_gradient_second_to_segment_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        climb_gradient_second_to_segment_fulfilled = False
    #final T/O climb segment
    climb_gradient_final_to_segment_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_of_final_takeoff_segment/'
        'checked/value')
    if climb_gradient_final_to_segment_checked is not None:
        climb_gradient_final_to_segment_checked = climb_gradient_final_to_segment_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        climb_gradient_final_to_segment_checked = False
    climb_gradient_final_to_segment_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_of_final_takeoff_segment/'
        'maintainable/value')
    if climb_gradient_final_to_segment_fulfilled is not None:
        climb_gradient_final_to_segment_fulfilled = climb_gradient_final_to_segment_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        climb_gradient_final_to_segment_fulfilled = False
    #approach segment (one engine inoperative)
    climb_gradient_approach_oei_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_approach_one_engine_inoperative/'
        'checked/value')
    if climb_gradient_approach_oei_checked is not None:
        climb_gradient_approach_oei_checked = climb_gradient_approach_oei_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        climb_gradient_approach_oei_checked = False
    climb_gradient_approach_oei_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_approach_one_engine_inoperative/'
        'maintainable/value')
    if climb_gradient_approach_oei_fulfilled is not None:
        climb_gradient_approach_oei_fulfilled = climb_gradient_approach_oei_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        climb_gradient_approach_oei_fulfilled = False
    #approach segment (all engines operating)
    climb_gradient_approach_aeo_checked = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_all_engines_operative/'
        'checked/value')
    if climb_gradient_approach_aeo_checked is not None:
        climb_gradient_approach_aeo_checked = climb_gradient_approach_aeo_checked.text.lower() in ['true', 'True', '1', 't']
    else:
        climb_gradient_approach_aeo_checked = False
    climb_gradient_approach_aeo_fulfilled = root_of_aircraft_exchange_tree.find(
        './requirement_compliance/certification/climb_gradient_all_engines_operative/'
        'maintainable/value')
    if climb_gradient_approach_aeo_fulfilled is not None:
        climb_gradient_approach_aeo_fulfilled = climb_gradient_approach_aeo_fulfilled.text.lower()  in ['true', 'True', '1', 't']
    else:
        climb_gradient_approach_aeo_fulfilled = False

    ''' store TLARs to check to table checkTLARs '''
    check_tlars = [['TOFL_Design', int(tofl_checked), int(tofl_fulfilled)],
                   ['TTC_Design', int(ttc_checked), int(ttc_fulfilled)],
                   ['h_initialCruise_Design', int(h_initial_cruise_checked), int(h_initial_cruise_fulfilled)],
                   ['M_initialCruise_Design', int(mach_initial_cruise_checked), int(mach_initial_cruise_fulfilled)],
                   ['V_ApproachSpeed_Design', int(v_approach_speed_checked), int(v_approach_speed_fulfilled)],
                   ['LDN_Design', int(ldn_checked), int(ldn_fulfilled)],
                   ['h_maxOperating', int(h_max_operating_checked), int(h_max_operating_fulfilled)],
                   ['h_maxOEI', int(h_max_oei_checked), int(h_max_oei_fulfilled)],
                   ['SpanLimit', int(span_limit_checked), int(span_limit_fulfilled)],
                   ['climbGradientSecondTOSegment', int(climb_gradient_second_to_segment_checked),
                    int(climb_gradient_second_to_segment_fulfilled)],
                   ['climbGradientFinalTOSegment', int(climb_gradient_final_to_segment_checked),
                    int(climb_gradient_final_to_segment_fulfilled)],
                   ['climbGradientApproachOEI', int(climb_gradient_approach_oei_checked),
                    int(climb_gradient_approach_oei_fulfilled)],
                   ['climbGradientApproachAEO', int(climb_gradient_approach_aeo_checked),
                    int(climb_gradient_approach_aeo_fulfilled)]]

    ''' check TLARs for fulfilled '''
    one_tlar_checked = 0
    all_tlars_checked = 1
    req_check_failed = 0
    req_err_code = int(600)

    for TLAR in check_tlars:
        if TLAR[1]:
            one_tlar_checked = 1
            if not (TLAR[2]):
                print('Error: Requirement check failed for: ' + TLAR[0])
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'Error: Requirement check failed for: ' + TLAR[0])
                req_check_failed = 1
                # generate error code of requirement check
                if TLAR[0] == 'TOFL_Design':
                    req_err_code += 1
                if TLAR[0] == 'LDN_Design':
                    req_err_code += 2
                if TLAR[0] == 'V_ApproachSpeed_Design':
                    req_err_code += 4
                if TLAR[0] == 'TTC_Design':
                    req_err_code += 8

            else:
                print('Requirement check successful for: ' + TLAR[0])
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'Requirement check successful for: ' + TLAR[0])
        else:
            all_tlars_checked = 0
            print('Error: Requirement check not possible for: ' + TLAR[0])
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Error: Requirement check not possible for: ' + TLAR[0])

    # report of requirement check
    if req_check_failed:
        print('Warning: TLARs check failed with error code ' + str(req_err_code) + ' due to failed requirement checks.')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'WARNING: TLARs check failed with error code ' + str(req_err_code)
                             + ' due to failed requirement checks.')

    else:
        if one_tlar_checked:
            print('No tested TLAR was violated.')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': No tested TLAR was violated.')

        if all_tlars_checked:
            print('All existing TLARs were checked and complied with. Good design!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'All existing TLARs were checked and complied with. Good design!')

    ''' check tank volume for design mission and study mission '''
    #maximum fuel mass
    m_fuel_max = root_of_aircraft_exchange_tree.find(
        './analysis/masses_cg_inertia/maximum_fuel_mass/mass_properties/mass/value')
    if m_fuel_max is not None:
        m_fuel_max = float(m_fuel_max.text)
    else:
        m_fuel_max = 0.0

    #mission fuel mass design mission
    consumed_mission_energy_mission_design = root_of_aircraft_exchange_tree.find(
        './analysis/mission/design_mission/mission_energy/consumed_energy/value')
    if consumed_mission_energy_mission_design is not None:
        used_energy_carrier = root_of_aircraft_exchange_tree.find(
            './analysis/mission/design_mission/mission_energy/energy_carrier_ID/value').text
        gravimetrical_density_used_energy_carrier = root_of_aircraft_exchange_tree.find(
            './requirements_and_specifications/design_specification/energy_carriers/'
            'energy_carrier[' + "@ID='" + used_energy_carrier + "'" + ']/gravimetric_density/value')
        m_mission_fuel_mission_design = float(consumed_mission_energy_mission_design.text) \
                                        / float(gravimetrical_density_used_energy_carrier.text)
    else:
        m_mission_fuel_mission_design = 0.0

    #mission fuel mass study mission
    consumed_mission_energy_mission_study = root_of_aircraft_exchange_tree.find(
        './analysis/mission/study_mission/mission_energy/consumed_energy/value')
    if consumed_mission_energy_mission_study is not None:
        used_energy_carrier = root_of_aircraft_exchange_tree.find(
            './analysis/mission/study_mission/mission_energy/energy_carrier_ID/value').text
        gravimetrical_density_used_energy_carrier = root_of_aircraft_exchange_tree.find(
            './requirements_and_specifications/design_specification/energy_carriers/'
            'energy_carrier[' + "@ID='" + used_energy_carrier + "'" + ']/gravimetric_density/value')
        m_mission_fuel_mission_study = float(consumed_mission_energy_mission_study.text) \
                                       / float(gravimetrical_density_used_energy_carrier.text)
    else:
        m_mission_fuel_mission_study = 0.0

    check_fuel_mass = [['design', m_mission_fuel_mission_design],
                       ['study', m_mission_fuel_mission_study]]

    for fuelMass in check_fuel_mass:
        if fuelMass[1] > m_fuel_max:
            print('Error: Fuel mass on ' + str(fuelMass[0]) + ' mission (' + str(fuelMass[1])
                  + ' kg) exceeds tank capacity (' + str(m_fuel_max) + ' kg)!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'ERROR: Fuel mass on ' + str(fuelMass[0]) + ' mission (' + str(fuelMass[1])
                                 + ' kg) exceeds tank capacity (' + str(m_fuel_max) + ' kg)!')

    ''' check reserve fuel for design mission '''
    consumed_trip_energy_mission_design = root_of_aircraft_exchange_tree.find(
        './analysis/mission/design_mission/trip_energy/consumed_energy/value')
    consumed_taxi_out_energy_mission_design = root_of_aircraft_exchange_tree.find(
        './analysis/mission/design_mission/taxi_energy/consumed_energy/value')
    
    if consumed_mission_energy_mission_study is not None and consumed_trip_energy_mission_design is not None and \
       consumed_taxi_out_energy_mission_design is not None:
        reserve_energy_mission_design = float(consumed_mission_energy_mission_study.text) \
                                        - float(consumed_trip_energy_mission_design.text) \
                                        - float(consumed_taxi_out_energy_mission_design.text)
    else:
        reserve_energy_mission_design = 0.0

    if reserve_energy_mission_design < 0:
        print('Error: Loaded mission energy on design mission smaller than consumed energy (neg. reserve energy).')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'ERROR: Loaded mission energy on design mission smaller than consumed energy '
                             '(neg. reserve energy).')

    ''' check take-off mass of study mission '''
    #maximum take off mass
    m_take_off_max = root_of_aircraft_exchange_tree.find(
        './analysis/masses_cg_inertia/maximum_takeoff_mass/mass_properties/mass/value')
    if m_take_off_max is not None:
        m_take_off_max = float(m_take_off_max.text)
    else:
        m_take_off_max = 0.0
    #study mission take off mass
    m_take_off_mission_study = root_of_aircraft_exchange_tree.find(
        './analysis/mission/study_mission/takeoff_mass/value')
    if m_take_off_mission_study is not None:
        m_take_off_mission_study = float(m_take_off_mission_study.text)
    else:
        m_take_off_mission_study = 0.0

    if m_take_off_max < m_take_off_mission_study:
        print('Error: Calculated TOM on Study Mission (' + str(m_take_off_mission_study) + 'kg) exceeded MTOM ('
              + str(m_take_off_max) + ' kg)!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'ERROR: Calculated TOM on Study Mission (' + str(m_take_off_mission_study)
                             + 'kg) exceeded MTOM (' + str(m_take_off_max) + ' kg)!')

    ''' write log-file to system '''
    log_file_list.append('*************************************** end check tlars and climb gradients '
                         '***************************************')
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()
