def generate_paths(paths_and_names, current_workflow_name):
    """ generate_paths imports and generates all paths are needed to following workflow steps.

        The input list of lists "paths_and_names" contains the following values:
            * [0][0] string: 'path_to_python_scripts',        [0][1] string: 'the system path to python scripts'

        The input string "current_workflow_name" contains the name of the current executed workflow.

        The output list of lists "paths_and_names" contains the following values:
            * [0][0] string: 'path_to_python_scripts',        [0][1] string: 'the system path to python scripts'
            * [1][0] string: 'path_of_working_directory',     [1][1] string: 'the system path of working directory'
            * [2][0] string: 'path_of_working_directory_rce', [2][1] string: 'the system path of working directory for rce'
            * [3][0] string: 'path_of_origin_tool_directory', [3][1] string: 'the system path to the root directory of UNICADO repositories'
            * [4][0] string: 'current_workflow_name',         [4][1] string: 'workflow name of the current workflow execution'
            * [5][0] string: 'path_to_aircraft_projects',     [5][1] string: 'the system path to the repository of aircraft design projects'
            * [6][0] string: 'path_to_aircraft_design_tools', [6][1] string: 'the system path to the repository of aircraft design tools'
            * [7][0] string: 'path_to_software_tools',        [7][1] string: 'the system path to the repository of software tools'
            * [8][0] string: 'path_to_json_files',            [8][1] string: 'the path to module json files in .rce system folder'

        :param: paths_and_names: input list of lists
        :param: current_workflow_name: input String
        :return: paths_and_names: output list of lists
    """

    ''' import for python '''
    import configparser
    import os
    import sys
    import shutil
    from datetime import datetime

    ''' create list for log-file string '''
    log_file_list = []

    ''' read user path of local user '''
    user_path_string = os.path.expanduser("~")
    # convert path of current working directory to a python path -> \ to /
    user_path_string = user_path_string.replace(os.sep, '/')

    ''' generate paths from file in .rce-directory '''
    # path to UNICADO repository
    if os.path.isfile(user_path_string
                      + '/.rce/default/integration/tools/common/absolutPathToUNICADOrepositoryDirectory.txt'):
        absolut_path_to_unicado_git = open(user_path_string
                                           + '/.rce/default/integration/tools/common/'
                                             'absolutPathToUNICADOrepositoryDirectory.txt', 'r')
        root_directory_of_unicado = str(absolut_path_to_unicado_git.read())
        root_directory_of_unicado = root_directory_of_unicado.replace(os.sep, '/')
    elif os.path.isfile(user_path_string + '/.rce/default/integration/tools/common/standAloneInstallationFlag.dat'):
        root_directory_of_unicado = user_path_string + '/.rce/default/integration/tools/common/'

    else:
        print('UNICADO workflow is not installed correctly. Please reinstall UNICADOworkflow! Program aborted!')
        sys.exit(1)

    # path to UNICADO working directory
    absolut_path_to_working_dir = open(
        user_path_string + '/.rce/default/integration/tools/common/absolutPathToUNICADOInstallDirectory.txt', 'r')
    root_directory_of_working_dir = str(absolut_path_to_working_dir.read())
    root_directory_of_working_dir = root_directory_of_working_dir.replace(os.sep, '/')

    # path of origin tool directory
    path_of_origin_tool_directory = root_directory_of_unicado
    print(path_of_origin_tool_directory)
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Aircraft Design Repository: ' + path_of_origin_tool_directory)

    # path of UNICADO working directory
    path_of_working_directory = root_directory_of_working_dir
    print(path_of_working_directory)
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Install / Working Directory: ' + path_of_working_directory)

    # check if workingDirectory exist
    check_flag_working_directory = os.path.isdir(path_of_working_directory)
    if not check_flag_working_directory:
        os.makedirs(path_of_working_directory)

    # path of RCE working directory
    path_of_working_directory_rce = path_of_working_directory + 'workingDirectoryRCE/'
    print(path_of_working_directory_rce)
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'RCE Working Directory: ' + path_of_working_directory_rce)

    # check if workingDirectoryRCE exist
    check_flag_working_directory_rce = os.path.isdir(path_of_working_directory_rce)
    if not check_flag_working_directory_rce:
        os.makedirs(path_of_working_directory_rce)

    ''' paths to origin unicado modules, software tools and aircraft projects '''
    # set repository directories to copy files
    path_to_software_tools = 'emptyPath'
    path_to_aircraft_design_tools = 'emptyPath'
    path_to_aircraft_projects = 'emptyPath'
    if os.path.isfile(user_path_string
                      + '/.rce/default/integration/tools/common/absolutPathToUNICADOrepositoryDirectory.txt'):
        files = os.listdir(path_of_origin_tool_directory)
        for fileName in files:
            check_if_file_is_directory = os.path.isdir(path_of_origin_tool_directory + fileName)
            if check_if_file_is_directory:
                check_git_folder = os.path.isdir(path_of_origin_tool_directory + fileName + '/.git')
                if check_git_folder:
                    check_config_file = os.path.isfile(path_of_origin_tool_directory + fileName + '/.git/config')
                    if check_config_file:
                        config = configparser.ConfigParser()
                        config.read(path_of_origin_tool_directory + fileName + '/.git/config')
                        url = config['remote "origin"']['url']
                        if url == 'ssh://git@unicado.ilr.rwth-aachen.de:2222/source/rADDITIONALSOFTWARE.git':
                            path_to_software_tools = path_of_origin_tool_directory + fileName + '/'

                        if url == 'ssh://git@unicado.ilr.rwth-aachen.de:2222/source/rAircraftDesign.git':
                            path_to_aircraft_design_tools = path_of_origin_tool_directory + fileName + '/'

                        if url == 'ssh://git@unicado.ilr.rwth-aachen.de:2222/source/rAIRCRAFTREFERENCES.git':
                            path_to_aircraft_projects = path_of_origin_tool_directory + fileName + '/'

    # check if the standalone version of unicado is installed
    elif os.path.isfile(user_path_string + '/.rce/default/integration/tools/common/standAloneInstallationFlag.dat'):
        path_to_software_tools = root_directory_of_unicado + 'originUnicadoSoftwareTools/'
        path_to_aircraft_projects = root_directory_of_unicado + 'originUnicadoProjects/'
        path_to_aircraft_design_tools = root_directory_of_unicado + 'originUnicadoDesignTools/'

    # else condition: unicado is not installed correctly
    else:
        print('UNICADO workflow is not installed correctly. Please reinstall UNICADOworkflow! Program aborted!')
        sys.exit(1)

    # check if workflow directory exist
    if not os.path.isdir(path_of_working_directory_rce + 'UNICADOworkflow'):
        shutil.copytree(path_of_origin_tool_directory + path_to_aircraft_design_tools + 'UNICADOworkflow',
                        path_of_working_directory_rce + 'UNICADOworkflow')

    ''' remove old workflow data from temporary workflow results '''
    if not os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/temporaryResults'):
        os.makedirs(path_of_working_directory_rce + current_workflow_name + '/temporaryResults')

    ''' generate list of lists for data exchange '''
    paths_and_names = paths_and_names + [['path_of_working_directory', path_of_working_directory],
                                         ['path_of_working_directory_rce', path_of_working_directory_rce],
                                         ['path_of_origin_tool_directory', path_of_origin_tool_directory],
                                         ['current_workflow_name', current_workflow_name],
                                         ['path_to_aircraft_projects', path_to_aircraft_projects],
                                         ['path_to_aircraft_design_tools', path_to_aircraft_design_tools],
                                         ['path_to_software_tools', path_to_software_tools],
                                         ['path_to_json_files',
                                          user_path_string + '/.rce/default/integration/tools/common/']]

    # path of temporary workflow working directory
    print(path_of_working_directory_rce + current_workflow_name)
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': Temporary workflow working directory: '
                         + path_of_working_directory_rce + current_workflow_name)

    ''' write log-file to system '''
    log_file_list.append(
        '************************************************ end generate paths '
        '************************************************')
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    return paths_and_names
