def read_requirements(paths_and_names):
    """ set_configuration_parameter read workflow configuration parameter from workflow configuration file.
        Set values to output lists for following workflow components.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The output list of lists "tlars" contains the following values:
            *  [0][0] string: 'm_payload_design',                [0][1] float:  'value of design payload mass'
            *  [1][0] string: 'm_payload_max',                   [1][1] float:  'value of maximum payload mass'
            *  [2][0] string: 'number_of_passengers',            [2][1] int:    'value of design number of passengers'
            *  [3][0] string: 'range_design',                    [3][1] float:  'value of aircraft design range'
            *  [4][0] string: 'take_off_field_length_design',    [4][1] float:  'value of design take off field length'
            *  [5][0] string: 'time_to_climb',                   [5][1] float:  'value of maximum time to climb'
            *  [6][0] string: 'height_cruise_design',            [6][1] float:  'value of design cruise height'
            *  [7][0] string: 'ma_cruise_design',                [7][1] float:  'value of design cruise mach number'
            *  [8][0] string: 'velocity_approach_design',        [8][1] float:  'value of design approach velocity'
            *  [9][0] string: 'landing_field_length_design',     [9][1] float:  'value of design landing field length'
            * [10][0] string: 'ma_max_operating',               [10][1] float:  'value of maximum operating mach number'
            * [11][0] string: 'velocity_max_operating',         [11][1] float:  'value of maximum operating velocity'
            * [12][0] string: 'altitude_max_operating',         [12][1] float:  'value of maximum operating altitude'
            * [13][0] string: 'altitude_max_operating_oei',     [13][1] float:  'value of maximum operating altitude with one engine inoperative'
            * [14][0] string: 'wing_span_limit',                [14][1] float:  'value of wing span limit'
            * [15][0] string: 'icao_aerodrome_reference_code',  [15][1] string: 'value of ICAO reference code'
            * [16][0] string: 'pavement_classification_number', [16][1] string: 'value of runway pavment classification number (PCN)'

        The output list of lists "climb_gradients" contains the following values:
            *  [0][0] string: 'climb_gradient_second_take_off_segment',     [0][1] float:  'value of Climb gradient in 2nd take-off segment'
            *  [1][0] string: 'climb_gradient_final_take_off_segment',      [1][1] float:  'value of climb gradient in final take-off segment'
            *  [2][0] string: 'climb_gradient_approach_oei',                [2][1] float:  'value of approach gradient with all engine operating'
            *  [3][0] string: 'climb_gradient_approach_aeo',                [3][1] float:  'value of approach gradient with one engine inoperative'

        :param: paths_and_names: input list of lists
        :return: tlars: output list of lists, climb_gradients: output list of lists
    """

    ''' imports for python '''
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' create list for log-file string '''
    log_file_list = ['',
                     '************************************************ read requirements '
                     '************************************************']

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    function_name = getframeinfo(currentframe()).function

    ''' open and read aircraft exchange file '''
    # try to open aircraft exchange file as element tree
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
        + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name, frame_info.lineno,
                                                             log_file_list, current_workflow_name)

    ''' read TLARS from aircraft exchange file '''
    total_number_passengers = int(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/design_specification/'
        'transport_task/passenger_definition/total_number_passengers/value').text)
    mass_per_passenger = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/design_specification/'
        'transport_task/passenger_definition/mass_per_passenger/value').text)
    luggage_mass_per_passenger = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/design_specification/'
        'transport_task/passenger_definition/luggage_mass_per_passenger/value').text)
    additional_cargo_mass = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/design_specification/'
        'transport_task/cargo_definition/additional_cargo_mass/value').text)
    m_payload_design = total_number_passengers * (mass_per_passenger + luggage_mass_per_passenger) + \
                       additional_cargo_mass
    m_payload_max = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/maximum_structrual_payload_mass/value').text)
    number_of_passengers = int(0)
    range_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/'
        'range/value').text)
    take_off_field_length_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/takeoff_distance/value').text)
    time_to_climb_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/'
        'time_to_climb/value').text)
    height_cruise_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/'
        'initial_cruise_altitude/value').text)
    ma_cruise_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/design_mission/'
        'initial_cruise_mach_number/value').text)
    velocity_approach_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/flight_envelope/'
        'maximum_approach_speed/value').text)
    landing_field_length_design = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/'
        'landing_field_length/value').text)
    ma_max_operating = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/flight_envelope/'
        'maximum_operating_mach_number/value').text)
    velocity_max_operating = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/flight_envelope/'
        'maximum_operating_velocity/value').text)
    altitude_max_operating = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/flight_envelope/'
        'maximum_operating_altitude/value').text)
    altitude_max_operating_oei = float(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/flight_envelope/'
        'maximum_one_engine_operating_altitude/value').text)
    #wing_span_limit = float(root_of_aircraft_exchange_tree.find(
     #   './Requirements/SizeLimits/SpanLimit').text)
    icao_aerodrome_reference_code = str(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/'
        'icao_aerodrome_reference_code/value').text)
    pavement_classification_number = str(root_of_aircraft_exchange_tree.find(
        './requirements_and_specifications/requirements/top_level_aircraft_requirements/'
        'pavement_classification_number/value').text)

    icao_field_length_codes_dict = {
        "1" : 800,
        "2" : 1200,
        "3" : 1800,
        "4" : float('inf')
    }

    icao_wing_span_codes_dict = {
        "A" : 15,
        "B" : 24,
        "C" : 36,
        "D" : 52,
        "E" : 65,
        "F" : 80
    }

    faa_airplane_design_group_tail_height_dict = {
        "I" : 6.1,
        "II" : 9.1,
        "III" : 13.7,
        "IV" : 18.3,
        "V" : 20.1,
        "VI" : 24.4
    }

    icao_approach_speed_codes_dict = { #given in [kts] indicated air speed at runway threshold
        "A" : 91,
        "B" : 120,
        "C" : 140,
        "D" : 165,
        "E" : 210
    }

    icao_aerodrome_reference_code_dict = {
        "fiel_length" : icao_field_length_codes_dict[icao_aerodrome_reference_code[:1]],
        "wing_span_limit" : icao_wing_span_codes_dict[icao_aerodrome_reference_code[1:2]],
        "tail_height_limit" : faa_airplane_design_group_tail_height_dict[icao_aerodrome_reference_code[2:-1]],
        "approach_speed_limit" : icao_approach_speed_codes_dict[icao_aerodrome_reference_code[-1:]]
    }

    wing_span_limit = float(icao_aerodrome_reference_code_dict["wing_span_limit"])

    ''' store TLARs to table TLARs '''
    tlars = [['m_payload_design', m_payload_design],
             ['m_payload_max', m_payload_max],
             ['number_of_passengers', number_of_passengers],
             ['range_design', range_design],
             ['take_off_field_length_design', take_off_field_length_design],
             ['time_to_climb', time_to_climb_design],
             ['height_cruise_design', height_cruise_design],
             ['ma_cruise_design', ma_cruise_design],
             ['velocity_approach_design', velocity_approach_design],
             ['landing_field_length_design', landing_field_length_design],
             ['ma_max_operating', ma_max_operating],
             ['velocity_max_operating', velocity_max_operating],
             ['altitude_max_operating', altitude_max_operating],
             ['altitude_max_operating_oei', altitude_max_operating_oei],
             ['wing_span_limit', wing_span_limit],
             ['icao_aerodrome_reference_code', icao_aerodrome_reference_code],
             ['pavement_classification_number', pavement_classification_number]]

    ''' read climb gradients '''
    #climb_gradient_second_take_off_segment = round(float(root_of_aircraft_exchange_tree.find(
    #    './Requirements/DesignMission/ClimbGradients/secondTOsegment').text), 1)
    #climb_gradient_final_take_off_segment = round(float(root_of_aircraft_exchange_tree.find(
    #    './Requirements/DesignMission/ClimbGradients/finalTOsegment').text), 1)
    #climb_gradient_approach_oei = round(float(root_of_aircraft_exchange_tree.find(
    #    './Requirements/DesignMission/ClimbGradients/approachAEO').text), 1)
    #climb_gradient_approach_aeo = round(float(root_of_aircraft_exchange_tree.find(
    #    './Requirements/DesignMission/ClimbGradients/approachOEI').text), 1)

    #climb_gradients = [['climb_gradient_second_take_off_segment', climb_gradient_second_take_off_segment],
    #                   ['climb_gradient_final_take_off_segment', climb_gradient_final_take_off_segment],
    #                   ['climb_gradient_approach_oei', climb_gradient_approach_oei],
    #                   ['climb_gradient_approach_aeo', climb_gradient_approach_aeo]]

    climb_gradients = [['climb_gradient_second_take_off_segment', float(2.4)],
                       ['climb_gradient_final_take_off_segment', float(1.2)],
                       ['climb_gradient_approach_oei', float(2.1)],
                       ['climb_gradient_approach_aeo', float(3.2)]]

    print('Requirements and climb gradients successfully read!')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Requirements and climb gradients successfully read!')

    ''' write log-file to system '''
    log_file_list.append('********************************************** end read requirements '
                         '**********************************************')
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    return tlars, climb_gradients
