def check_for_existing_geometry(path_of_working_directory_rce, aircraft_project, file_name, path_to_repository_file,
                                log_file_list, current_workflow_name='UNICADOworkflow'):
    """ checks if the necessary geometry data exist from the aircraft exchange file

        The input string path_of_working_directory_rce contains the system path to the working directory of rce.

        The input string aircraft_project contains the name of the current aircraft project.

        The input string file_name contains the name to the aircraft exchange file of current project.

        The input string path_to_repository_file contains the system path to the aircraft reference repository directory.

        The input list log_file_list contains the strings of workflow log-file from the caller function.

        The input string "current_workflow_name" contains the name of the current workflow execution.
            * If no input is given, default sting 'UNICADOworkflow' is used.

        The output list log_file_list contains the strings of workflow log-file from the caller function and the added strings from this function.

        :param: path_of_working_directory_rce: input string
        :param: aircraft_project: input string
        :param: file_name: input string
        :param: path_to_repository_file: input string
        :param: log_file_list: input list
        :param: current_workflow_name: input string
        :return: log_file_list: output list
    """

    ''' imports for python '''
    import os
    import sys
    import shutil
    from inspect import currentframe, getframeinfo
    from datetime import datetime
    from read_xml_file import read_xml_file
    from read_geometry_elements import read_geometry_elements

    log_file_flag = False
    function_name = getframeinfo(currentframe()).function

    ''' check for existing geometry data '''
    # check if the geometryData directory is inside the project folder
    #  -> if false: -> copy geometry data from repository folder
    if not (os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                          + '/geometryData')):
        # check if the geometryData directory exist in the repository directory
        #  -> if true: -> copy geometry data to project folder
        try:
            shutil.copytree(path_to_repository_file + 'geometryData',
                            path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                            + '/geometryData')
            print('Geometry data successfully copied from repository folder!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Geometry data successfully copied from repository folder!')
            log_file_flag = True

        # Exception handling: the geometryData directory is not existing in the repository directory
        #  -> raise an error and abort program
        except OSError:
            print('Error: Geometry data could not be copied, no geometryData folder found in repository directory! \n '
                  'Program aborted!')
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Error: Geometry data could not be copied, no geometryData folder found in '
                                 'repository directory! \n Program aborted!')
            log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
            for row in log_file_list:
                log_file.write(row + '\n')
            log_file.close()
            sys.exit(1)

    # Else condition: the geometryData directory is inside the project folder
    #  -> check if all necessary geometry elements exist
    else:
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + file_name
        # call function to read the aircraft exchange file as element tree
        root_of_aircraft_exchange_file, xml_tree = read_xml_file(path, path_of_working_directory_rce, file_name,
                                                                 function_name, frame_info.lineno, log_file_list,
                                                                 current_workflow_name)

        # call function to read used geometry elements from given element tree
        geometry_name = read_geometry_elements(root_of_aircraft_exchange_file)

        # loop across all used geometry elements to check if they exist inside the geometry data folder
        for geometry_entry in geometry_name:
            if not os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                  + '/' + geometry_entry):
                name_of_missing_file = geometry_entry[geometry_entry.rfind('/') + 1:]
                # check if the geometryData directory exist in the repository directory
                #  -> if true: -> copy missing geometry data file to project folder
                if os.path.isdir(path_to_repository_file + 'geometryData'):
                    try:
                        shutil.copy(path_to_repository_file + geometry_entry,
                                    path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                    + '/' + geometry_entry)
                        print('Missing geometry data file ' + name_of_missing_file
                              + ' successfully copied from repository folder!')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                             'Missing geometry data file ' + name_of_missing_file
                                             + ' successfully copied from repository folder!')
                        log_file_flag = True

                    # Exception handling: the missing geometry data file is not existing in the repository directory
                    #  -> raise an error and abort program
                    except OSError:
                        print('Error: Missing geometry data file ' + name_of_missing_file
                              + ' could not be copied, no such geometry file found in repository directory! \n '
                                'Program aborted!')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                             'Error: Missing geometry data file ' + name_of_missing_file
                                             + ' could not be copied, no such geometry file found in '
                                               'repository directory! \n Program aborted!')

                        log_file = open(path_of_working_directory_rce + current_workflow_name
                                        + '/workflowLogFile.log', 'a')
                        for row in log_file_list:
                            log_file.write(row + '\n')
                        log_file.close()
                        sys.exit(1)

    if not log_file_flag:
        print('All necessary geometry data files already exist in the geometryData folder of current project!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'All necessary geometry data files already exist in the geometryData folder of current '
                             'project!')

    return log_file_list
